<schema xmlns="http://purl.oclc.org/dsdl/schematron"
        xmlns:u="utils"
        xmlns:xs="http://www.w3.org/2001/XMLSchema"
        schemaVersion="iso"
        queryBinding="xslt2">

    <title>EHF ESPD 1.2 Request</title>

    <ns prefix="cac"
       uri="urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2"/>
    <ns prefix="cbc"
       uri="urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2"/>
    <ns prefix="ccv-cbc"
       uri="urn:isa:names:specification:ubl:schema:xsd:CCV-CommonBasicComponents-1"/>
    <ns prefix="cev-cac"
       uri="urn:isa:names:specification:ubl:schema:xsd:CEV-CommonAggregateComponents-1"/>
    <ns prefix="cev-cbc"
       uri="urn:isa:names:specification:ubl:schema:xsd:CEV-CommonBasicComponents-1"/>
    <ns prefix="cev"
       uri="urn:isa:names:specification:ubl:schema:xsd:CEV-CommonAggregateComponents-1"/>
    <ns prefix="espd"
       uri="urn:grow:names:specification:ubl:schema:xsd:ESPDResponse-1"/>
    <ns prefix="espd-req"
       uri="urn:grow:names:specification:ubl:schema:xsd:ESPDRequest-1"/>
    <ns prefix="ext"
       uri="urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2"/>
    <ns prefix="espd-cbc"
       uri="urn:grow:names:specification:ubl:schema:xsd:ESPD-CommonBasicComponents-1"/>
    <ns prefix="ccv"
       uri="urn:isa:names:specification:ubl:schema:xsd:CCV-CommonAggregateComponents-1"/>
    <ns prefix="espd-cac"
       uri="urn:grow:names:specification:ubl:schema:xsd:ESPD-CommonAggregateComponents-1"/>
    <ns prefix="xs" uri="http://www.w3.org/2001/XMLSchema"/>
    <ns prefix="u" uri="utils"/>
    <ns prefix="lots" uri="urn:fdc:difi.no:2017:vefa:espd:Lots-1"/>

    

    <function xmlns="http://www.w3.org/1999/XSL/Transform"
             name="u:mod11"
             as="xs:boolean">
        <param name="val"/>
        <variable name="length" select="string-length($val) - 1"/>
        <variable name="digits"
                select="reverse(for $i in string-to-codepoints(substring($val, 0, $length + 1)) return $i - 48)"/>
        <variable name="weightedSum"
                select="sum(for $i in (0 to $length - 1) return $digits[$i + 1] * (($i mod 6) + 2))"/>
        <value-of select="number($val) &gt; 0 and (11 - ($weightedSum mod 11)) mod 11 = number(substring($val, $length + 1, 1))"/>
    </function>

    <pattern>

      <rule context="ccv:Response">
        
    </rule>
      <rule context="cbc:* | ccv-cbc:* | cev-cbc:* | espd-cbc:*">
        <assert id="EHF-ESPD-R001" test=". != ''" flag="fatal">Document MUST not contain empty elements.</assert>
      </rule>
      <rule context="cac:* | cev:* | ccv:* | espd-cac:*">
        <assert id="EHF-ESPD-R002" test="count(*) != 0" flag="fatal">Document MUST not contain empty elements.</assert>
      </rule>

   </pattern>
    <pattern>

    

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'AMOUNT']/ccv:Response">
        <assert id="EHF-ESPD-R120" test="cbc:Amount" flag="fatal">Amount element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'CODE']/ccv:Response">
        <assert id="EHF-ESPD-R121" test="ccv-cbc:Code" flag="fatal">Code element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'CODE_COUNTRY']/ccv:Response">
        <assert id="EHF-ESPD-R122" test="ccv-cbc:Code" flag="fatal">Code element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'DATE']/ccv:Response">
        <assert id="EHF-ESPD-R123" test="cbc:Date" flag="fatal">Date element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'DESCRIPTION']/ccv:Response">
        <assert id="EHF-ESPD-R124" test="cbc:Description" flag="fatal">Description element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'EVIDENCE_URL']/ccv:Response">
        <assert id="EHF-ESPD-R125" test="cev-cac:Evidence" flag="fatal">Evidence element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'INDICATOR']/ccv:Response">
        <assert id="EHF-ESPD-R126" test="ccv-cbc:Indicator" flag="fatal">Indicator element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'PERCENTAGE']/ccv:Response">
        <assert id="EHF-ESPD-R127" test="cbc:Percent" flag="fatal">Percent element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'PERIOD']/ccv:Response">
        <assert id="EHF-ESPD-R128" test="cac:Period" flag="fatal">Period element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'QUANTITY_INTEGER']/ccv:Response">
        <assert id="EHF-ESPD-R129" test="cbc:Quantity[not(@unitCode)]" flag="fatal">Quantity element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'QUANTITY_YEAR']/ccv:Response">
        <assert id="EHF-ESPD-R130"
                 test="cbc:Quantity[@unitCode = 'YEAR']"
                 flag="fatal">Quantity element MUST be provided as response when specified.</assert>
      </rule>

      <rule context="ccv:Requirement[/espd:ESPDResponse][@responseDataType = 'QUANTITY']/ccv:Response">
        <assert id="EHF-ESPD-R131"
                 test="cbc:Quantity[@unitCode and @unitCode != 'YEAR']"
                 flag="fatal">Quantity element MUST be provided as response when specified.</assert>
      </rule>
        

    

      <rule context="cac:AdditionalDocumentReference[normalize-space(cbc:DocumentTypeCode) = 'TED_CN']">
        <assert id="EHF-ESPD-R211"
                 test="not(cbc:IssueDate) and not(cbc:IssueTime) and cac:Attachment/cac:ExternalReference/cbc:FileName and cac:Attachment/cac:ExternalReference/cbc:Description"
                 flag="fatal">TED reference MUST NOT contain issue date and issue time and MUST contain filename and description.</assert>
        <assert id="EHF-ESPD-R213"
                 test="matches(normalize-space(cbc:ID/text()), '^[0-9]{4}/S [0-9]{3}\-[0-9]{6}$')"
                 flag="fatal">TED reference MUST match '[][][][]/S [][][]-[][][][][][]' (e.g. 2015/S 252-461137).</assert>
        <assert id="EHF-ESPD-R214"
                 test="/espd-req:ESPDRequest or normalize-space(cbc:ID/text()) != '0000/S 000-000000'"
                 flag="fatal">TED reference MUST not be a temporary value.</assert>
      </rule>

      <rule context="cac:AdditionalDocumentReference[/espd:ESPDResponse][normalize-space(cbc:DocumentTypeCode) = 'ESPD_REQUEST']">
        <assert id="EHF-ESPD-R221" test="not(cac:Attachment/cbc:URI)" flag="fatal">NGOJ reference MUST NOT contain issue date, issue time and attachment.</assert>
        <assert id="EHF-ESPD-R222" test="cbc:IssueDate" flag="fatal">ESPD Request reference MUST contain an issue date.</assert>
      </rule>

      <rule context="cac:AdditionalDocumentReference[normalize-space(cbc:DocumentTypeCode) = 'NGOJ']">
        <assert id="EHF-ESPD-R231"
                 test="not(cac:Attachment) and not(cbc:IssueDate) and not(cbc:IssueTime)"
                 flag="fatal">Doffin reference MUST NOT contain issue date, issue time and attachment.</assert>
        <assert id="EHF-ESPD-R233"
                 test="matches(normalize-space(cbc:ID/text()), '^[0-9]{4}\-[0-9]{6}$')"
                 flag="fatal">Doffin reference MUST match 'YYYY-[][][][][][]' (e.g. 2017-461137).</assert>
      </rule>

      <rule context="cac:AdditionalDocumentReference[/espd:ESPDResponse][normalize-space(cbc:DocumentTypeCode) = 'LOTS']">
        
    </rule>

      <rule context="cac:AdditionalDocumentReference">
        
        <assert id="EHF-ESPD-R200" test="not(/espd-req:ESPDRequest)" flag="fatal">ESPD Request MUST contain only document references 'TED_CN' and 'NGOJ'.</assert>
        <assert id="EHF-ESPD-R201" test="not(/espd:ESPDResponse)" flag="fatal">ESPD Responst MUST contain only document references 'TED_CN', 'ESPD_REQUEST', 'NGOJ' and 'LOTS'.</assert>
      </rule>

    

      <rule context="cbc:IssueDate | cbc:BirthDate | cbc:Date">
        <assert id="EHF-ESPD-R020"
                 test="(normalize-space(text()) castable as xs:date) and string-length(normalize-space(text())) = 10"
                 flag="fatal">A date must be formatted YYYY-MM-DD.</assert>
      </rule>

      <rule context="cbc:IssueTime">
        <assert id="EHF-ESPD-R021"
                 test="(normalize-space(text()) castable as xs:time) and string-length(normalize-space(text())) = 8"
                 flag="fatal">A time must be formatted hh:mm:ss.</assert>
      </rule>

   </pattern>
    <pattern xmlns:ns2="http://www.schematron-quickfix.com/validator/process">
      <let name="clespd-CriteriaTypeCode"
           value="tokenize('CRITERION.EXCLUSION.CONVICTIONS.PARTICIPATION_IN_CRIMINAL_ORGANISATION CRITERION.EXCLUSION.CONVICTIONS.CORRUPTION CRITERION.EXCLUSION.CONVICTIONS.FRAUD CRITERION.EXCLUSION.CONVICTIONS.TERRORIST_OFFENCES CRITERION.EXCLUSION.CONVICTIONS.MONEY_LAUNDERING CRITERION.EXCLUSION.CONVICTIONS.CHILD_LABOUR-HUMAN_TRAFFICKING CRITERION.EXCLUSION.CONTRIBUTIONS.PAYMENT_OF_TAXES CRITERION.EXCLUSION.CONTRIBUTIONS.PAYMENT_OF_SOCIAL_SECURITY CRITERION.EXCLUSION.SOCIAL.ENVIRONMENTAL_LAW CRITERION.EXCLUSION.SOCIAL.SOCIAL_LAW CRITERION.EXCLUSION.SOCIAL.LABOUR_LAW CRITERION.EXCLUSION.BUSINESS.BANKRUPTCY CRITERION.EXCLUSION.BUSINESS.INSOLVENCY CRITERION.EXCLUSION.BUSINESS.CREDITORS_ARRANGEMENT CRITERION.EXCLUSION.BUSINESS.BANKRUPTCY_ANALOGOUS CRITERION.EXCLUSION.BUSINESS.LIQUIDATOR_ADMINISTERED CRITERION.EXCLUSION.BUSINESS.ACTIVITIES_SUSPENDED CRITERION.EXCLUSION.MISCONDUCT.MC_PROFESSIONAL CRITERION.EXCLUSION.MISCONDUCT.MARKET_DISTORTION CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.PROCEDURE_PARTICIPATION CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.PROCEDURE_PREPARATION CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.EARLY_TERMINATION CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.MISINTERPRETATION CRITERION.EXCLUSION.NATIONAL.NO.ACCEPTED.FINE CRITERION.EXCLUSION.NATIONAL.GRAVE.MISCONDUCT CRITERION.SELECTION.ALL_SATISFIED CRITERION.SELECTION.SUITABILITY.PROFESSIONAL_REGISTER_ENROLMENT CRITERION.SELECTION.SUITABILITY.TRADE_REGISTER_ENROLMENT CRITERION.SELECTION.SUITABILITY.AUTHORISATION CRITERION.SELECTION.SUITABILITY.MEMBERSHIP CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.GENERAL_YEARLY CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.AVERAGE_YEARLY CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SPECIFIC_YEARLY CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SPECIFIC_AVERAGE CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SET_UP CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.FINANCIAL_RATIO CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.RISK_INDEMNITY_INSURANCE CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.OTHER_REQUIREMENTS CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.WORKS_PERFORMANCE CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.SUPPLIES_DELIVERY_PERFORMANCE CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.SERVICES_DELIVERY_PERFORMANCE CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.TECHNICIANS_FOR_QUALITY_CONTROL CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.TECHNICIANS_FOR_CARRYING_WORKS CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.FACILITIES_FOR_QUALITY_ENSURING CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.FACILITIES_FOR_STUDY_RESEARCH CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.SUPPLY_CHAIN_MANAGEMENT CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.CHECKS.ALLOWANCE_OF_CHECKS CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.PROFESSIONAL_QUALIFICATIONS CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.ENVIRONMENTAL_MANAGEMENT_MEASURES CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.MANAGERIAL_STAFF CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.AVERAGE_ANNUAL_MANPOWER CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.EQUIPMENT CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.SUBCONTRACTING_PROPORTION CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.ARTEFACTS.NO_AUTHENTICATED_ARTEFACTS CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.ARTEFACTS.AUTHENTICATED_ARTEFACTS &#xA;            CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.QUALITY_ASSURANCE.QA_INSTITUTES_CERTIFICATE&#xA;         &#xA;            CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.QUALITY_ASSURANCE.QA_INDEPENDENT_CERTIFICATE&#xA;         &#xA;            CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.ENVIRONMENTAL_MANAGEMENT.ENV_INDEPENDENT_CERTIFICATE&#xA;         CRITERION.OTHER.EO_DATA.SHELTERED_WORKSHOP CRITERION.OTHER.EO_DATA.REGISTERED_IN_OFFICIAL_LIST CRITERION.OTHER.EO_DATA.TOGETHER_WITH_OTHERS CRITERION.OTHER.EO_DATA.RELIES_ON_OTHER_CAPACITIES CRITERION.OTHER.EO_DATA.SUBCONTRACTS_WITH_THIRD_PARTIES CRITERION.OTHER.EO_DATA.MEETS_THE_OBJECTIVE', '\s')"/>
      <let name="clespd-ICD"
           value="tokenize('GLN DK:P IT:FTI NL:KVK IT:SIA IT:SECETI DIGST DK:CPR DK:CVR DK:SE DK:VANS IT:VAT IT:CF NO:ORGNR NO:VAT HU:VAT EU:VAT EU:REID AT:VAT AT:GOV AT:CID IS:KT IBAN AT:KUR ES:VAT IT:IPA AD:VAT AL:VAT BA:VAT BE:VAT BG:VAT CH:VAT CY:VAT CZ:VAT DE:VAT EE:VAT GB:VAT GR:VAT HR:VAT IE:VAT LI:VAT LT:VAT LU:VAT LV:VAT MC:VAT ME:VAT MK:VAT MT:VAT NL:VAT PL:VAT PT:VAT RO:VAT RS:VAT SI:VAT SK:VAT SM:VAT TR:VAT VA:VAT NL:OIN SE:VAT BE:CBE FR:VAT', '\s')"/>
      <let name="clespd-ResponseDataType"
           value="tokenize('AMOUNT CODE CODE_COUNTRY DATE DESCRIPTION EVIDENCE_URL INDICATOR PERCENTAGE PERIOD QUANTITY_INTEGER QUANTITY_YEAR QUANTITY', '\s')"/>
      <let name="clespd-CriteriaOptional"
           value="tokenize('7e7db838-eeac-46d9-ab39-42927486f22d 6ee55a59-6adb-4c3a-b89f-e62a7ad7be7f 87b3fa26-3549-4f92-b8e0-3fd8f04bf5c7 9eeb6d5c-0eb8-48e8-a4c5-5087a7c095a4 73f10e36-ed7a-412e-995c-aa76463e3776 499efc97-2ac1-4af2-9e84-323c2ca67747 b16cb9fc-6cb7-4585-9302-9533b415cf48 074f6031-55f9-4e99-b9a4-c4363e8bc315 d3dfb714-f558-4512-bbc5-e456fa2339de 77f481ce-ffb6-483f-8e2b-c78db5e68292 e4d37adc-08cd-4f4d-a8d8-32b62b0a1f46 7604bd40-4462-4086-8763-a50da51a869c ab0e7f2e-6418-40e2-8870-6713123e41ad cdd3bb3e-34a5-43d5-b668-2aab86a73822 3a18a175-1863-4b1d-baef-588ce61960ca 5e506c16-26ab-4e32-bb78-b27f87dc0565 3aaca389-4a7b-406b-a4b9-080845d127e7 c599c130-b29f-461e-a187-4e16c7d40db7 4bf996d9-439c-40c6-9ab9-980a48cb55a1 90a2e100-44cc-45d3-9970-69d6714f1596 dc12a151-7fdf-4733-a8f0-30f667292e66 c8809aa1-29b6-4f27-ae2f-27e612e394db 07301031-2270-41af-8e7e-66fe0c777107 9460457e-b43d-48a9-acd1-615de6ddd33e 6346959b-e097-4ea1-89cd-d1b4c131ea4d 1f49b3f0-d50f-43f6-8b30-4bafab108b9b cc18c023-211d-484d-a32e-52f3f970285f 612a1625-118d-4ea4-a6db-413184e7c0a8 bdf0601d-2480-4250-b870-658d0ee95be6 7662b7a9-bcb8-4763-a0a7-7505d8e8470d a7669d7d-9297-43e1-9d10-691a1660187c d726bac9-e153-4e75-bfca-c5385587766d 8ed65e48-fd0d-444f-97bd-4f58da632999 2043338f-a38a-490b-b3ec-2607cb25a017 9b19e869-6c89-4cc4-bd6c-ac9ca8602165 ee51100f-8e3e-40c9-8f8b-57d5a15be1f2 0d62c6ed-f074-4fcf-8e9f-f691351d52ad 72c0c4b1-ca50-4667-9487-461f3eed4ed7 9c70375e-1264-407e-8b50-b9736bc08901', '\s')"/>
      <let name="clespd-CriterionJurisdictionLevel"
           value="tokenize('EU_REGULATION EU_DIRECTIVE EU_DECISION NATIONAL_LEGISLATION SUBNATIONAL_LEGISLATION', '\s')"/>
      <let name="clespd-CountryCodeIdentifier"
           value="tokenize('AD AE AF AG AI AL AM AO AQ AR AS AT AU AW AX AZ BA BB BD BE BF BG BH BI BJ BL BM BN BO BQ BR BS BT BV BW BY BZ CA CC CD CF CG CH CI CK CL CM CN CO CR CU CV CW CX CY CZ DE DJ DK DM DO DZ EC EE EG EH ER ES ET FI FJ FK FM FO FR GA GB GD GE GF GG GH GI GL GM GN GP GQ GR GS GT GU GW GY HK HM HN HR HT HU ID IE IL IM IN IO IQ IR IS IT JE JM JO JP KE KG KH KI KM KN KP KR KW KY KZ LA LB LC LI LK LR LS LT LU LV LY MA MC MD ME MF MG MH MK ML MM MN MO MP MQ MR MS MT MU MV MW MX MY MZ NA NC NE NF NG NI NL NO NP NR NU NZ OM PA PE PF PG PH PK PL PM PN PR PS PT PW PY QA RE RO RS RU RW SA SB SC SD SE SG SH SI SJ SK SL SM SN SO SR SS ST SV SX SY SZ TC TD TF TG TH TJ TK TL TM TN TO TR TT TV TW TZ UA UG UM US UY UZ VA VC VE VG VI VN VU WF WS XK YE YT ZA ZM ZW', '\s')"/>
      <let name="clespd-LanguageCodeEU"
           value="tokenize('PL PT EL EN ES ET FI RO GA FR SK SL SV HU IT LT LV MT BG NL DA CS DE HR', '\s')"/>
      <let name="clespd-DocRefContentType"
           value="tokenize('TED_CN ESPD_REQUEST NGOJ LOTS', '\s')"/>
      <let name="clespd-ProfileID" value="tokenize('', '\s')"/>
      <rule context="/espd-req:ESPDRequest">
         <assert test="cbc:CustomizationID" flag="fatal" id="EHF-ESPD-REQ-B00101">Element 'cbc:CustomizationID' MUST be provided.</assert>
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B00102">Element 'cbc:ID' MUST be provided.</assert>
         <assert test="cbc:IssueDate" flag="fatal" id="EHF-ESPD-REQ-B00103">Element 'cbc:IssueDate' MUST be provided.</assert>
         <assert test="cbc:ContractFolderID" flag="fatal" id="EHF-ESPD-REQ-B00104">Element 'cbc:ContractFolderID' MUST be provided.</assert>
         <assert test="cac:ContractingParty" flag="fatal" id="EHF-ESPD-REQ-B00105">Element 'cac:ContractingParty' MUST be provided.</assert>
         <assert test="cac:ProcurementProjectLot"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B00106">Element 'cac:ProcurementProjectLot' MUST be provided.</assert>
         <assert test="ccv:Criterion" flag="fatal" id="EHF-ESPD-REQ-B00107">Element 'ccv:Criterion' MUST be provided.</assert>
         <assert test="not(@*:schemaLocation)" flag="fatal" id="EHF-ESPD-REQ-B00108">Document MUST not contain schema location.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions">
         <assert test="ext:UBLExtension" flag="fatal" id="EHF-ESPD-REQ-B00201">Element 'ext:UBLExtension' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension">
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B00301">Element 'cbc:ID' MUST be provided.</assert>
         <assert test="cbc:Name" flag="fatal" id="EHF-ESPD-REQ-B00302">Element 'cbc:Name' MUST be provided.</assert>
         <assert test="ext:ExtensionContent" flag="fatal" id="EHF-ESPD-REQ-B00303">Element 'ext:ExtensionContent' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/cbc:ID">
         <assert test="normalize-space(text()) = 'urn:fdc:difi.no:2017:vefa:espd:Lots-1'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B00401">Element 'cbc:ID' MUST contain value 'urn:fdc:difi.no:2017:vefa:espd:Lots-1'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00402">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/cbc:Name">
         <assert test="normalize-space(text()) = 'Lots description'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B00501">Element 'cbc:Name' MUST contain value 'Lots description'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/cbc:Name/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00502">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent">
         <assert test="lots:Lots" flag="fatal" id="EHF-ESPD-REQ-B00601">Element 'lots:Lots' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots">
         <assert test="lots:VersionID" flag="fatal" id="EHF-ESPD-REQ-B00701">Element 'lots:VersionID' MUST be provided.</assert>
         <assert test="lots:Lot" flag="fatal" id="EHF-ESPD-REQ-B00702">Element 'lots:Lot' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:VersionID">
         <assert test="normalize-space(text()) = '1.0'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B00801">Element 'lots:VersionID' MUST contain value '1.0'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:VersionID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00802">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot">
         <assert test="lots:ID" flag="fatal" id="EHF-ESPD-REQ-B00901">Element 'lots:ID' MUST be provided.</assert>
         <assert test="lots:Title" flag="fatal" id="EHF-ESPD-REQ-B00902">Element 'lots:Title' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:ID"/>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B01001">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:Title"/>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:Title/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B01101">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:Description"/>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:Description/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B01201">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:OptionalCritierias">
         <assert test="lots:ID" flag="fatal" id="EHF-ESPD-REQ-B01301">Element 'lots:ID' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:OptionalCritierias/lots:ID">
         <assert test="(some $code in $clespd-CriteriaOptional satisfies $code = normalize-space(text()))"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B01401">Value MUST be part of code list 'Optional criterias'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:OptionalCritierias/lots:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B01402">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/lots:OptionalCritierias/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B01302">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/lots:Lot/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00903">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/lots:Lots/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00703">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00602">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/ext:UBLExtension/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00304">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ext:UBLExtensions/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00202">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:UBLVersionID">
         <assert test="normalize-space(text()) = '2.1'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B01501">Element 'cbc:UBLVersionID' MUST contain value '2.1'.</assert>
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'OASIS-UBL-TC'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B01502">Attribute 'schemeAgencyID' MUST contain value 'OASIS-UBL-TC'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B01503">Attribute 'schemeAgencyID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:UBLVersionID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B01504">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:CustomizationID">
         <assert test="normalize-space(text()) = 'urn:www.cenbii.eu:transaction:biitrns070:ver3.0:extended:urn:fdc:difi.no:2017:ehf:spec:1.2'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B01701">Element 'cbc:CustomizationID' MUST contain value 'urn:www.cenbii.eu:transaction:biitrns070:ver3.0:extended:urn:fdc:difi.no:2017:ehf:spec:1.2'.</assert>
         <assert test="not(@schemeName) or @schemeName = 'CustomizationID'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B01702">Attribute 'schemeName' MUST contain value 'CustomizationID'</assert>
         <assert test="@schemeName" flag="fatal" id="EHF-ESPD-REQ-B01703">Attribute 'schemeName' MUST be present.</assert>
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'BII'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B01704">Attribute 'schemeAgencyID' MUST contain value 'BII'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B01705">Attribute 'schemeAgencyID' MUST be present.</assert>
         <assert test="not(@schemeVersionID) or @schemeVersionID = '3.0'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B01706">Attribute 'schemeVersionID' MUST contain value '3.0'</assert>
         <assert test="@schemeVersionID" flag="fatal" id="EHF-ESPD-REQ-B01707">Attribute 'schemeVersionID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:CustomizationID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B01708">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:ProfileID">
         <assert test="(some $code in $clespd-ProfileID satisfies $code = normalize-space(text()))"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B02101">Value MUST be part of code list 'Profile identifiers'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:ProfileID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B02102">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:ID">
         <assert test="not(@schemeID) or @schemeID = 'ISO/IEC 9834-8:2008 - 4UUID'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B02201">Attribute 'schemeID' MUST contain value 'ISO/IEC 9834-8:2008 - 4UUID'</assert>
         <assert test="@schemeID" flag="fatal" id="EHF-ESPD-REQ-B02202">Attribute 'schemeID' MUST be present.</assert>
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B02203">Attribute 'schemeAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B02204">Attribute 'schemeAgencyID' MUST be present.</assert>
         <assert test="not(@schemeAgencyName) or @schemeAgencyName = 'DG GROW (European Commission)'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B02205">Attribute 'schemeAgencyName' MUST contain value 'DG GROW (European Commission)'</assert>
         <assert test="@schemeAgencyName" flag="fatal" id="EHF-ESPD-REQ-B02206">Attribute 'schemeAgencyName' MUST be present.</assert>
         <assert test="not(@schemeVersionID) or @schemeVersionID = '1.1'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B02207">Attribute 'schemeVersionID' MUST contain value '1.1'</assert>
         <assert test="@schemeVersionID" flag="fatal" id="EHF-ESPD-REQ-B02208">Attribute 'schemeVersionID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B02209">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:CopyIndicator"/>
      <rule context="/espd-req:ESPDRequest/cbc:CopyIndicator/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B02701">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:VersionID">
         <assert test="normalize-space(text()) = '2016.04.2'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B02801">Element 'cbc:VersionID' MUST contain value '2016.04.2'.</assert>
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B02802">Attribute 'schemeAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B02803">Attribute 'schemeAgencyID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:VersionID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B02804">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:IssueDate"/>
      <rule context="/espd-req:ESPDRequest/cbc:IssueDate/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03001">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:IssueTime"/>
      <rule context="/espd-req:ESPDRequest/cbc:IssueTime/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03101">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:ContractFolderID">
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'TeD'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B03201">Attribute 'schemeAgencyID' MUST contain value 'TeD'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B03202">Attribute 'schemeAgencyID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cbc:ContractFolderID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03203">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty">
         <assert test="cac:Party" flag="fatal" id="EHF-ESPD-REQ-B03401">Element 'cac:Party' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party">
         <assert test="cac:PartyIdentification"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B03501">Element 'cac:PartyIdentification' MUST be provided.</assert>
         <assert test="cac:PartyName" flag="fatal" id="EHF-ESPD-REQ-B03502">Element 'cac:PartyName' MUST be provided.</assert>
         <assert test="cac:PostalAddress" flag="fatal" id="EHF-ESPD-REQ-B03503">Element 'cac:PostalAddress' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cbc:EndpointID">
         <assert test="@schemeID" flag="fatal" id="EHF-ESPD-REQ-B03601">Attribute 'schemeID' MUST be present.</assert>
         <assert test="not(@schemeID) or (some $code in $clespd-ICD satisfies $code = @schemeID)"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B03602">Value MUST be part of code list 'ISO 6523 International Code Designator (ICD)'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cbc:EndpointID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03603">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyIdentification">
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B03801">Element 'cbc:ID' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyIdentification/cbc:ID">
         <assert test="@schemeID" flag="fatal" id="EHF-ESPD-REQ-B03901">Attribute 'schemeID' MUST be present.</assert>
         <assert test="not(@schemeID) or (some $code in $clespd-ICD satisfies $code = @schemeID)"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B03902">Value MUST be part of code list 'ISO 6523 International Code Designator (ICD)'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyIdentification/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03903">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyIdentification/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03802">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyName">
         <assert test="cbc:Name" flag="fatal" id="EHF-ESPD-REQ-B04101">Element 'cbc:Name' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyName/cbc:Name"/>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyName/cbc:Name/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B04201">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PartyName/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B04102">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PostalAddress">
         <assert test="cac:Country" flag="fatal" id="EHF-ESPD-REQ-B04301">Element 'cac:Country' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PostalAddress/cac:Country">
         <assert test="cbc:IdentificationCode" flag="fatal" id="EHF-ESPD-REQ-B04401">Element 'cbc:IdentificationCode' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode">
         <assert test="(some $code in $clespd-CountryCodeIdentifier satisfies $code = normalize-space(text()))"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B04501">Value MUST be part of code list 'ISO 3166 Alpha-2 Country codes'.</assert>
         <assert test="not(@listID) or @listID = 'CountryCodeIdentifier'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B04502">Attribute 'listID' MUST contain value 'CountryCodeIdentifier'</assert>
         <assert test="@listID" flag="fatal" id="EHF-ESPD-REQ-B04503">Attribute 'listID' MUST be present.</assert>
         <assert test="not(@listAgencyID) or @listAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B04504">Attribute 'listAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@listAgencyID" flag="fatal" id="EHF-ESPD-REQ-B04505">Attribute 'listAgencyID' MUST be present.</assert>
         <assert test="not(@listName) or @listName = 'CountryCodeIdentifier'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B04506">Attribute 'listName' MUST contain value 'CountryCodeIdentifier'</assert>
         <assert test="@listName" flag="fatal" id="EHF-ESPD-REQ-B04507">Attribute 'listName' MUST be present.</assert>
         <assert test="not(@listVersionID) or @listVersionID = '1.0.2'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B04508">Attribute 'listVersionID' MUST contain value '1.0.2'</assert>
         <assert test="@listVersionID" flag="fatal" id="EHF-ESPD-REQ-B04509">Attribute 'listVersionID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B04510">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PostalAddress/cac:Country/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B04402">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/cac:PostalAddress/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B04302">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/cac:Party/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03504">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ContractingParty/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B03402">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ProcurementProjectLot">
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B05001">Element 'cbc:ID' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ProcurementProjectLot/cbc:ID">
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05101">Attribute 'schemeAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B05102">Attribute 'schemeAgencyID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ProcurementProjectLot/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B05103">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:ProcurementProjectLot/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B05002">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion">
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B05301">Element 'cbc:ID' MUST be provided.</assert>
         <assert test="cbc:TypeCode" flag="fatal" id="EHF-ESPD-REQ-B05302">Element 'cbc:TypeCode' MUST be provided.</assert>
         <assert test="cbc:Name" flag="fatal" id="EHF-ESPD-REQ-B05303">Element 'cbc:Name' MUST be provided.</assert>
         <assert test="cbc:Description" flag="fatal" id="EHF-ESPD-REQ-B05304">Element 'cbc:Description' MUST be provided.</assert>
         <assert test="ccv:RequirementGroup" flag="fatal" id="EHF-ESPD-REQ-B05305">Element 'ccv:RequirementGroup' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:ID">
         <assert test="not(@schemeID) or @schemeID = 'CriteriaID'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05501">Attribute 'schemeID' MUST contain value 'CriteriaID'</assert>
         <assert test="@schemeID" flag="fatal" id="EHF-ESPD-REQ-B05502">Attribute 'schemeID' MUST be present.</assert>
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05503">Attribute 'schemeAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B05504">Attribute 'schemeAgencyID' MUST be present.</assert>
         <assert test="not(@schemeVersionID) or @schemeVersionID = '1.0'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05505">Attribute 'schemeVersionID' MUST contain value '1.0'</assert>
         <assert test="@schemeVersionID" flag="fatal" id="EHF-ESPD-REQ-B05506">Attribute 'schemeVersionID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B05507">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:TypeCode">
         <assert test="(some $code in $clespd-CriteriaTypeCode satisfies $code = normalize-space(text()))"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05901">Value MUST be part of code list 'Criteria Type Codes'.</assert>
         <assert test="not(@listID) or @listID = 'CriteriaTypeCode'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05902">Attribute 'listID' MUST contain value 'CriteriaTypeCode'</assert>
         <assert test="@listID" flag="fatal" id="EHF-ESPD-REQ-B05903">Attribute 'listID' MUST be present.</assert>
         <assert test="not(@listAgencyID) or @listAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05904">Attribute 'listAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@listAgencyID" flag="fatal" id="EHF-ESPD-REQ-B05905">Attribute 'listAgencyID' MUST be present.</assert>
         <assert test="not(@listVersionID) or @listVersionID = '1.0.2'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B05906">Attribute 'listVersionID' MUST contain value '1.0.2'</assert>
         <assert test="@listVersionID" flag="fatal" id="EHF-ESPD-REQ-B05907">Attribute 'listVersionID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:TypeCode/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B05908">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:Name"/>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:Name/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B06301">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:Description"/>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/cbc:Description/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B06401">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference">
         <assert test="ccv-cbc:Title" flag="fatal" id="EHF-ESPD-REQ-B06501">Element 'ccv-cbc:Title' MUST be provided.</assert>
         <assert test="ccv-cbc:JurisdictionLevelCode"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B06502">Element 'ccv-cbc:JurisdictionLevelCode' MUST be provided.</assert>
         <assert test="ccv-cbc:Article" flag="fatal" id="EHF-ESPD-REQ-B06503">Element 'ccv-cbc:Article' MUST be provided.</assert>
         <assert test="cbc:URI" flag="fatal" id="EHF-ESPD-REQ-B06504">Element 'cbc:URI' MUST be provided.</assert>
         <assert test="not(@langID) or (some $code in $clespd-LanguageCodeEU satisfies $code = @langID)"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B06505">Value MUST be part of code list 'ISO 639-1 Language Codes'.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/ccv-cbc:Title"/>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/ccv-cbc:Title/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B06701">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/cbc:Description"/>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/cbc:Description/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B06801">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/ccv-cbc:JurisdictionLevelCode">
         <assert test="(some $code in $clespd-CriterionJurisdictionLevel satisfies $code = normalize-space(text()))"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B06901">Value MUST be part of code list 'Criterion Jurisdiction Level'.</assert>
         <assert test="not(@listID) or @listID = 'CriterionJurisdictionLevel'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B06902">Attribute 'listID' MUST contain value 'CriterionJurisdictionLevel'</assert>
         <assert test="@listID" flag="fatal" id="EHF-ESPD-REQ-B06903">Attribute 'listID' MUST be present.</assert>
         <assert test="not(@listAgencyID) or @listAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B06904">Attribute 'listAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@listAgencyID" flag="fatal" id="EHF-ESPD-REQ-B06905">Attribute 'listAgencyID' MUST be present.</assert>
         <assert test="not(@listVersionID) or @listVersionID = '1.0.2'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B06906">Attribute 'listVersionID' MUST contain value '1.0.2'</assert>
         <assert test="@listVersionID" flag="fatal" id="EHF-ESPD-REQ-B06907">Attribute 'listVersionID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/ccv-cbc:JurisdictionLevelCode/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B06908">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/ccv-cbc:Article"/>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/ccv-cbc:Article/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B07301">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/cbc:URI"/>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/cbc:URI/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B07401">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/ccv:LegislationReference/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B06506">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="ccv:RequirementGroup">
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B07501">Element 'cbc:ID' MUST be provided.</assert>
      </rule>
      <rule context="ccv:RequirementGroup/cbc:ID">
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B07701">Attribute 'schemeAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B07702">Attribute 'schemeAgencyID' MUST be present.</assert>
         <assert test="not(@schemeVersionID) or @schemeVersionID = '1.0'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B07703">Attribute 'schemeVersionID' MUST contain value '1.0'</assert>
         <assert test="@schemeVersionID" flag="fatal" id="EHF-ESPD-REQ-B07704">Attribute 'schemeVersionID' MUST be present.</assert>
      </rule>
      <rule context="ccv:RequirementGroup/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B07705">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="ccv:Requirement">
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B08001">Element 'cbc:ID' MUST be provided.</assert>
         <assert test="cbc:Description" flag="fatal" id="EHF-ESPD-REQ-B08002">Element 'cbc:Description' MUST be provided.</assert>
         <assert test="@responseDataType" flag="fatal" id="EHF-ESPD-REQ-B08003">Attribute 'responseDataType' MUST be present.</assert>
         <assert test="not(@responseDataType) or (some $code in $clespd-ResponseDataType satisfies $code = @responseDataType)"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B08004">Value MUST be part of code list 'Response Data Types'.</assert>
      </rule>
      <rule context="ccv:Requirement/cbc:ID">
         <assert test="not(@schemeID) or @schemeID = 'CriterionRelatedIDs'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B08201">Attribute 'schemeID' MUST contain value 'CriterionRelatedIDs'</assert>
         <assert test="@schemeID" flag="fatal" id="EHF-ESPD-REQ-B08202">Attribute 'schemeID' MUST be present.</assert>
         <assert test="not(@schemeAgencyID) or @schemeAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B08203">Attribute 'schemeAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@schemeAgencyID" flag="fatal" id="EHF-ESPD-REQ-B08204">Attribute 'schemeAgencyID' MUST be present.</assert>
         <assert test="not(@schemeVersionID) or @schemeVersionID = '1.0'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B08205">Attribute 'schemeVersionID' MUST contain value '1.0'</assert>
         <assert test="@schemeVersionID" flag="fatal" id="EHF-ESPD-REQ-B08206">Attribute 'schemeVersionID' MUST be present.</assert>
      </rule>
      <rule context="ccv:Requirement/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B08207">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="ccv:Requirement/cbc:Description"/>
      <rule context="ccv:Requirement/cbc:Description/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B08601">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="ccv:Requirement/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B08005">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="ccv:RequirementGroup/ccv:RequirementGroup"/>
      <rule context="ccv:RequirementGroup/ccv:RequirementGroup/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B08701">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="ccv:RequirementGroup/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B07502">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/ccv:Criterion/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B05306">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference">
         <assert test="cbc:ID" flag="fatal" id="EHF-ESPD-REQ-B08801">Element 'cbc:ID' MUST be provided.</assert>
         <assert test="cbc:DocumentTypeCode" flag="fatal" id="EHF-ESPD-REQ-B08802">Element 'cbc:DocumentTypeCode' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:ID"/>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:ID/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B08901">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:IssueDate"/>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:IssueDate/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B09001">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:IssueTime"/>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:IssueTime/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B09101">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:DocumentTypeCode">
         <assert test="(some $code in $clespd-DocRefContentType satisfies $code = normalize-space(text()))"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B09201">Value MUST be part of code list 'Document Reference Content Types'.</assert>
         <assert test="not(@listID) or @listID = 'ReferencesTypeCodes'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B09202">Attribute 'listID' MUST contain value 'ReferencesTypeCodes'</assert>
         <assert test="@listID" flag="fatal" id="EHF-ESPD-REQ-B09203">Attribute 'listID' MUST be present.</assert>
         <assert test="not(@listAgencyID) or @listAgencyID = 'EU-COM-GROW'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B09204">Attribute 'listAgencyID' MUST contain value 'EU-COM-GROW'</assert>
         <assert test="@listAgencyID" flag="fatal" id="EHF-ESPD-REQ-B09205">Attribute 'listAgencyID' MUST be present.</assert>
         <assert test="not(@listVersionID) or @listVersionID = '1.0'"
                 flag="fatal"
                 id="EHF-ESPD-REQ-B09206">Attribute 'listVersionID' MUST contain value '1.0'</assert>
         <assert test="@listVersionID" flag="fatal" id="EHF-ESPD-REQ-B09207">Attribute 'listVersionID' MUST be present.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cbc:DocumentTypeCode/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B09208">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment">
         <assert test="cac:ExternalReference" flag="fatal" id="EHF-ESPD-REQ-B09601">Element 'cac:ExternalReference' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference">
         <assert test="cbc:Description" flag="fatal" id="EHF-ESPD-REQ-B09701">Element 'cbc:Description' MUST be provided.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:URI"/>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:URI/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B09801">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:FileName"/>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:FileName/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B09901">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:Description"/>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:Description/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B10001">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B09702">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/cac:Attachment/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B09602">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/cac:AdditionalDocumentReference/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B08803">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
      <rule context="/espd-req:ESPDRequest/*">
         <assert test="false()" flag="fatal" id="EHF-ESPD-REQ-B00109">Document MUST NOT contain elements not part of the data model.</assert>
      </rule>
   </pattern>
    <pattern>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '005eb9ed-1347-4ca3-bb29-9bc0db64e1ab']]">
         <assert id="EHF-ESPD-CT-C-0101"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONVICTIONS.PARTICIPATION_IN_CRIMINAL_ORGANISATION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONVICTIONS.PARTICIPATION_IN_CRIMINAL_ORGANISATION".</assert>
         <assert id="EHF-ESPD-CT-C-0102"
                 test="normalize-space(cbc:Name) = 'Participation in a criminal organisation'"
                 flag="fatal">Element 'Name' MUST have value "Participation in a criminal organisation".</assert>
         <assert id="EHF-ESPD-CT-C-0103"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for participation in a criminal organisation, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 2 of Council Framework Decision 2008/841/JHA of 24 October 2008 on the fight against organised crime (OJ L 300, 11.11.2008, p. 42).'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for participation in a criminal organisation, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 2 of Council Framework Decision 2008/841/JHA of 24 October 2008 on the fight against organised crime (OJ L 300, 11.11.2008, p. 42).".</assert>
         <assert id="EHF-ESPD-CT-C-0104"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7c637c0c-7703-4389-ba52-02997a055bd7'"
                 flag="fatal">Criterion '005eb9ed-1347-4ca3-bb29-9bc0db64e1ab' MUST have RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0122"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '005eb9ed-1347-4ca3-bb29-9bc0db64e1ab' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '005eb9ed-1347-4ca3-bb29-9bc0db64e1ab']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0111"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0112"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0113"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0114"
                 test="normalize-space(ccv-cbc:Article) = '57(1)'"
                 flag="fatal">Element 'Article' MUST have value "57(1)".</assert>
         <assert id="EHF-ESPD-CT-C0115"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'c27b7c4e-c837-4529-b867-ed55ce639db5']]">
         <assert id="EHF-ESPD-CT-C-0201"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONVICTIONS.CORRUPTION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONVICTIONS.CORRUPTION".</assert>
         <assert id="EHF-ESPD-CT-C-0202"
                 test="normalize-space(cbc:Name) = 'Corruption'"
                 flag="fatal">Element 'Name' MUST have value "Corruption".</assert>
         <assert id="EHF-ESPD-CT-C-0203"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for corruption, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 3 of the Convention on the fight against corruption involving officials of the European Communities or officials of Member States of the European Union, OJ C 195, 25.6.1997, p. 1, and in Article 2(1) of Council Framework Decision 2003/568/JHA of 22 July 2003 on combating corruption in the private sector (OJ L 192, 31.7.2003, p. 54). This exclusion ground also includes corruption as defined in the national law of the contracting authority (contracting entity) or the economic operator.'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for corruption, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 3 of the Convention on the fight against corruption involving officials of the European Communities or officials of Member States of the European Union, OJ C 195, 25.6.1997, p. 1, and in Article 2(1) of Council Framework Decision 2003/568/JHA of 22 July 2003 on combating corruption in the private sector (OJ L 192, 31.7.2003, p. 54). This exclusion ground also includes corruption as defined in the national law of the contracting authority (contracting entity) or the economic operator.".</assert>
         <assert id="EHF-ESPD-CT-C-0204"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7c637c0c-7703-4389-ba52-02997a055bd7'"
                 flag="fatal">Criterion 'c27b7c4e-c837-4529-b867-ed55ce639db5' MUST have RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0222"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion 'c27b7c4e-c837-4529-b867-ed55ce639db5' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'c27b7c4e-c837-4529-b867-ed55ce639db5']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0211"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0212"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0213"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0214"
                 test="normalize-space(ccv-cbc:Article) = '57(1)'"
                 flag="fatal">Element 'Article' MUST have value "57(1)".</assert>
         <assert id="EHF-ESPD-CT-C0215"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '297d2323-3ede-424e-94bc-a91561e6f320']]">
         <assert id="EHF-ESPD-CT-C-0301"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONVICTIONS.FRAUD'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONVICTIONS.FRAUD".</assert>
         <assert id="EHF-ESPD-CT-C-0302"
                 test="normalize-space(cbc:Name) = 'Fraud'"
                 flag="fatal">Element 'Name' MUST have value "Fraud".</assert>
         <assert id="EHF-ESPD-CT-C-0303"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for fraud, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? Within the meaning of Article 1 of the Convention on the protection of the European Communities'' financial interests (OJ C 316, 27.11.1995, p. 48).'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for fraud, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? Within the meaning of Article 1 of the Convention on the protection of the European Communities' financial interests (OJ C 316, 27.11.1995, p. 48).".</assert>
         <assert id="EHF-ESPD-CT-C-0304"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7c637c0c-7703-4389-ba52-02997a055bd7'"
                 flag="fatal">Criterion '297d2323-3ede-424e-94bc-a91561e6f320' MUST have RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0322"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '297d2323-3ede-424e-94bc-a91561e6f320' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '297d2323-3ede-424e-94bc-a91561e6f320']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0311"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0312"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0313"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0314"
                 test="normalize-space(ccv-cbc:Article) = '57(1)'"
                 flag="fatal">Element 'Article' MUST have value "57(1)".</assert>
         <assert id="EHF-ESPD-CT-C0315"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'd486fb70-86b3-4e75-97f2-0d71b5697c7d']]">
         <assert id="EHF-ESPD-CT-C-0401"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONVICTIONS.TERRORIST_OFFENCES'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONVICTIONS.TERRORIST_OFFENCES".</assert>
         <assert id="EHF-ESPD-CT-C-0402"
                 test="normalize-space(cbc:Name) = 'Terrorist offences or offences linked to terrorist activities'"
                 flag="fatal">Element 'Name' MUST have value "Terrorist offences or offences linked to terrorist activities".</assert>
         <assert id="EHF-ESPD-CT-C-0403"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for terrorist offences or offences linked to terrorist activities, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Articles 1 and 3 of Council Framework Decision of 13 June 2002 on combating terrorism (OJ L 164, 22.6.2002, p. 3). This exclusion ground also includes inciting or aiding or abetting or attempting to commit an offence, as referred to in Article 4 of that Framework Decision.'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for terrorist offences or offences linked to terrorist activities, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Articles 1 and 3 of Council Framework Decision of 13 June 2002 on combating terrorism (OJ L 164, 22.6.2002, p. 3). This exclusion ground also includes inciting or aiding or abetting or attempting to commit an offence, as referred to in Article 4 of that Framework Decision.".</assert>
         <assert id="EHF-ESPD-CT-C-0404"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7c637c0c-7703-4389-ba52-02997a055bd7'"
                 flag="fatal">Criterion 'd486fb70-86b3-4e75-97f2-0d71b5697c7d' MUST have RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0422"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion 'd486fb70-86b3-4e75-97f2-0d71b5697c7d' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'd486fb70-86b3-4e75-97f2-0d71b5697c7d']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0411"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0412"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0413"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0414"
                 test="normalize-space(ccv-cbc:Article) = '57(1)'"
                 flag="fatal">Element 'Article' MUST have value "57(1)".</assert>
         <assert id="EHF-ESPD-CT-C0415"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '47112079-6fec-47a3-988f-e561668c3aef']]">
         <assert id="EHF-ESPD-CT-C-0501"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONVICTIONS.MONEY_LAUNDERING'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONVICTIONS.MONEY_LAUNDERING".</assert>
         <assert id="EHF-ESPD-CT-C-0502"
                 test="normalize-space(cbc:Name) = 'Money laundering or terrorist financing'"
                 flag="fatal">Element 'Name' MUST have value "Money laundering or terrorist financing".</assert>
         <assert id="EHF-ESPD-CT-C-0503"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for money laundering or terrorist financing, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 1 of Directive 2005/60/EC of the European Parliament and of the Council of 26 October 2005 on the prevention of the use of the financial system for the purpose of money laundering and terrorist financing (OJ L 309, 25.11.2005, p. 15).'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for money laundering or terrorist financing, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 1 of Directive 2005/60/EC of the European Parliament and of the Council of 26 October 2005 on the prevention of the use of the financial system for the purpose of money laundering and terrorist financing (OJ L 309, 25.11.2005, p. 15).".</assert>
         <assert id="EHF-ESPD-CT-C-0504"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0521"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7c637c0c-7703-4389-ba52-02997a055bd7'"
                 flag="fatal">Criterion '47112079-6fec-47a3-988f-e561668c3aef' MUST have RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0522"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '47112079-6fec-47a3-988f-e561668c3aef' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '47112079-6fec-47a3-988f-e561668c3aef']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0511"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0512"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0513"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0514"
                 test="normalize-space(ccv-cbc:Article) = '57(1)'"
                 flag="fatal">Element 'Article' MUST have value "57(1)".</assert>
         <assert id="EHF-ESPD-CT-C0515"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'd789d01a-fe03-4ccd-9898-73f9cfa080d1']]">
         <assert id="EHF-ESPD-CT-C-0601"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONVICTIONS.CHILD_LABOUR-HUMAN_TRAFFICKING'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONVICTIONS.CHILD_LABOUR-HUMAN_TRAFFICKING".</assert>
         <assert id="EHF-ESPD-CT-C-0602"
                 test="normalize-space(cbc:Name) = 'Child labour and other forms of trafficking in human beings'"
                 flag="fatal">Element 'Name' MUST have value "Child labour and other forms of trafficking in human beings".</assert>
         <assert id="EHF-ESPD-CT-C-0603"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for child labour and other forms of trafficking in human beings, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 2 of Directive 2011/36/EU of the European Parliament and of the Council of 5 April 2011 on preventing and combating trafficking in human beings and protecting its victims, and replacing Council Framework Decision 2002/629/JHA (OJ L 101, 15.4.2011, p. 1).'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein been the subject of a conviction by final judgment for child labour and other forms of trafficking in human beings, by a conviction rendered at the most five years ago or in which an exclusion period set out directly in the conviction continues to be applicable? As defined in Article 2 of Directive 2011/36/EU of the European Parliament and of the Council of 5 April 2011 on preventing and combating trafficking in human beings and protecting its victims, and replacing Council Framework Decision 2002/629/JHA (OJ L 101, 15.4.2011, p. 1).".</assert>
         <assert id="EHF-ESPD-CT-C-0604"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7c637c0c-7703-4389-ba52-02997a055bd7'"
                 flag="fatal">Criterion 'd789d01a-fe03-4ccd-9898-73f9cfa080d1' MUST have RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0622"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion 'd789d01a-fe03-4ccd-9898-73f9cfa080d1' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'd789d01a-fe03-4ccd-9898-73f9cfa080d1']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0611"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0612"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0613"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0614"
                 test="normalize-space(ccv-cbc:Article) = '57(1)'"
                 flag="fatal">Element 'Article' MUST have value "57(1)".</assert>
         <assert id="EHF-ESPD-CT-C0615"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'b61bbeb7-690e-4a40-bc68-d6d4ecfaa3d4']]">
         <assert id="EHF-ESPD-CT-C-0701"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONTRIBUTIONS.PAYMENT_OF_TAXES'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONTRIBUTIONS.PAYMENT_OF_TAXES".</assert>
         <assert id="EHF-ESPD-CT-C-0702"
                 test="normalize-space(cbc:Name) = 'Payment of taxes'"
                 flag="fatal">Element 'Name' MUST have value "Payment of taxes".</assert>
         <assert id="EHF-ESPD-CT-C-0703"
                 test="normalize-space(cbc:Description) = 'Has the economic operator breached its obligations relating to the payment of taxes, both in the country in which it is established and in Member State of the contracting authority or contracting entity if other than the country of establishment?'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator breached its obligations relating to the payment of taxes, both in the country in which it is established and in Member State of the contracting authority or contracting entity if other than the country of establishment?".</assert>
         <assert id="EHF-ESPD-CT-C-0704"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '098fd3cc-466e-4233-af1a-affe09471bce'"
                 flag="fatal">Criterion 'b61bbeb7-690e-4a40-bc68-d6d4ecfaa3d4' MUST have RequirementGroup '098fd3cc-466e-4233-af1a-affe09471bce' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0722"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion 'b61bbeb7-690e-4a40-bc68-d6d4ecfaa3d4' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'b61bbeb7-690e-4a40-bc68-d6d4ecfaa3d4']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0711"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0712"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0713"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0714"
                 test="normalize-space(ccv-cbc:Article) = '57(2)'"
                 flag="fatal">Element 'Article' MUST have value "57(2)".</assert>
         <assert id="EHF-ESPD-CT-C0715"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '7d85e333-bbab-49c0-be8d-c36d71a72f5e']]">
         <assert id="EHF-ESPD-CT-C-0801"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONTRIBUTIONS.PAYMENT_OF_SOCIAL_SECURITY'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONTRIBUTIONS.PAYMENT_OF_SOCIAL_SECURITY".</assert>
         <assert id="EHF-ESPD-CT-C-0802"
                 test="normalize-space(cbc:Name) = 'Payment of social security contributions'"
                 flag="fatal">Element 'Name' MUST have value "Payment of social security contributions".</assert>
         <assert id="EHF-ESPD-CT-C-0803"
                 test="normalize-space(cbc:Description) = 'Has the economic operator breached its obligations relating to the payment social security contributions, both in the country in which it is established and in Member State of the contracting authority or contracting entity if other than the country of establishment?'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator breached its obligations relating to the payment social security contributions, both in the country in which it is established and in Member State of the contracting authority or contracting entity if other than the country of establishment?".</assert>
         <assert id="EHF-ESPD-CT-C-0804"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0821"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '098fd3cc-466e-4233-af1a-affe09471bce'"
                 flag="fatal">Criterion '7d85e333-bbab-49c0-be8d-c36d71a72f5e' MUST have RequirementGroup '098fd3cc-466e-4233-af1a-affe09471bce' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-0822"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '7d85e333-bbab-49c0-be8d-c36d71a72f5e' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '7d85e333-bbab-49c0-be8d-c36d71a72f5e']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0811"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0812"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0813"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0814"
                 test="normalize-space(ccv-cbc:Article) = '57(2)'"
                 flag="fatal">Element 'Article' MUST have value "57(2)".</assert>
         <assert id="EHF-ESPD-CT-C0815"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'a80ddb62-d25b-4e4e-ae22-3968460dc0a9']]">
         <assert id="EHF-ESPD-CT-C-0901"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.SOCIAL.ENVIRONMENTAL_LAW'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.SOCIAL.ENVIRONMENTAL_LAW".</assert>
         <assert id="EHF-ESPD-CT-C-0902"
                 test="normalize-space(cbc:Name) = 'Breaching of obligations in the fields of environmental law'"
                 flag="fatal">Element 'Name' MUST have value "Breaching of obligations in the fields of environmental law".</assert>
         <assert id="EHF-ESPD-CT-C-0903"
                 test="normalize-space(cbc:Description) = 'Has the economic operator, to its knowledge, breached its obligations in the fields of environmental law? As referred to for the purposes of this procurement in national law, in the relevant notice or the procurement documents or in Article 18(2) of Directive 2014/24/EU.'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator, to its knowledge, breached its obligations in the fields of environmental law? As referred to for the purposes of this procurement in national law, in the relevant notice or the procurement documents or in Article 18(2) of Directive 2014/24/EU.".</assert>
         <assert id="EHF-ESPD-CT-C-0904"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-0921"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '976b5acb-c00f-46ca-8f83-5ce6abfdfe43'"
                 flag="fatal">Criterion 'a80ddb62-d25b-4e4e-ae22-3968460dc0a9' MUST have RequirementGroup '976b5acb-c00f-46ca-8f83-5ce6abfdfe43' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'a80ddb62-d25b-4e4e-ae22-3968460dc0a9']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C0911"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C0912"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C0913"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C0914"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C0915"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'a261a395-ed17-4939-9c75-b9ff1109ca6e']]">
         <assert id="EHF-ESPD-CT-C-1001"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.SOCIAL.SOCIAL_LAW'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.SOCIAL.SOCIAL_LAW".</assert>
         <assert id="EHF-ESPD-CT-C-1002"
                 test="normalize-space(cbc:Name) = 'Breaching of obligations in the fields of social law'"
                 flag="fatal">Element 'Name' MUST have value "Breaching of obligations in the fields of social law".</assert>
         <assert id="EHF-ESPD-CT-C-1003"
                 test="normalize-space(cbc:Description) = 'Has the economic operator, to its knowledge, breached its obligations in the fields of social law? As referred to for the purposes of this procurement in national law, in the relevant notice or the procurement documents or in Article 18(2) of Directive 2014/24/EU.'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator, to its knowledge, breached its obligations in the fields of social law? As referred to for the purposes of this procurement in national law, in the relevant notice or the procurement documents or in Article 18(2) of Directive 2014/24/EU.".</assert>
         <assert id="EHF-ESPD-CT-C-1004"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '976b5acb-c00f-46ca-8f83-5ce6abfdfe43'"
                 flag="fatal">Criterion 'a261a395-ed17-4939-9c75-b9ff1109ca6e' MUST have RequirementGroup '976b5acb-c00f-46ca-8f83-5ce6abfdfe43' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'a261a395-ed17-4939-9c75-b9ff1109ca6e']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1011"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1012"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1013"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1014"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1015"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'a34b70d6-c43d-4726-9a88-8e2b438424bf']]">
         <assert id="EHF-ESPD-CT-C-1101"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.SOCIAL.LABOUR_LAW'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.SOCIAL.LABOUR_LAW".</assert>
         <assert id="EHF-ESPD-CT-C-1102"
                 test="normalize-space(cbc:Name) = 'Breaching of obligations in the fields of labour law'"
                 flag="fatal">Element 'Name' MUST have value "Breaching of obligations in the fields of labour law".</assert>
         <assert id="EHF-ESPD-CT-C-1103"
                 test="normalize-space(cbc:Description) = 'Has the economic operator, to its knowledge, breached its obligations in the fields of labour law? As referred to for the purposes of this procurement in national law, in the relevant notice or the procurement documents or in Article 18(2) of Directive 2014/24/EU.'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator, to its knowledge, breached its obligations in the fields of labour law? As referred to for the purposes of this procurement in national law, in the relevant notice or the procurement documents or in Article 18(2) of Directive 2014/24/EU.".</assert>
         <assert id="EHF-ESPD-CT-C-1104"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '976b5acb-c00f-46ca-8f83-5ce6abfdfe43'"
                 flag="fatal">Criterion 'a34b70d6-c43d-4726-9a88-8e2b438424bf' MUST have RequirementGroup '976b5acb-c00f-46ca-8f83-5ce6abfdfe43' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'a34b70d6-c43d-4726-9a88-8e2b438424bf']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1111"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1112"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1113"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1114"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1115"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'd3732c09-7d62-4edc-a172-241da6636e7c']]">
         <assert id="EHF-ESPD-CT-C-1201"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.BUSINESS.BANKRUPTCY'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.BUSINESS.BANKRUPTCY".</assert>
         <assert id="EHF-ESPD-CT-C-1202"
                 test="normalize-space(cbc:Name) = 'Bankruptcy'"
                 flag="fatal">Element 'Name' MUST have value "Bankruptcy".</assert>
         <assert id="EHF-ESPD-CT-C-1203"
                 test="normalize-space(cbc:Description) = 'Is the economic operator bankrupt? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.'"
                 flag="fatal">Element 'Description' MUST have value "Is the economic operator bankrupt? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.".</assert>
         <assert id="EHF-ESPD-CT-C-1204"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd91c11a1-f19e-4b83-8ade-c4be2bf00555'"
                 flag="fatal">Criterion 'd3732c09-7d62-4edc-a172-241da6636e7c' MUST have RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-1222"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion 'd3732c09-7d62-4edc-a172-241da6636e7c' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'd3732c09-7d62-4edc-a172-241da6636e7c']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1211"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1212"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1213"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1214"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1215"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '396f288a-e267-4c20-851a-ed4f7498f137']]">
         <assert id="EHF-ESPD-CT-C-1301"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.BUSINESS.INSOLVENCY'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.BUSINESS.INSOLVENCY".</assert>
         <assert id="EHF-ESPD-CT-C-1302"
                 test="normalize-space(cbc:Name) = 'Insolvency'"
                 flag="fatal">Element 'Name' MUST have value "Insolvency".</assert>
         <assert id="EHF-ESPD-CT-C-1303"
                 test="normalize-space(cbc:Description) = 'Is the economic operator the subject of insolvency or winding-up? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.'"
                 flag="fatal">Element 'Description' MUST have value "Is the economic operator the subject of insolvency or winding-up? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.".</assert>
         <assert id="EHF-ESPD-CT-C-1304"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd91c11a1-f19e-4b83-8ade-c4be2bf00555'"
                 flag="fatal">Criterion '396f288a-e267-4c20-851a-ed4f7498f137' MUST have RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-1322"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '396f288a-e267-4c20-851a-ed4f7498f137' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '396f288a-e267-4c20-851a-ed4f7498f137']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1311"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1312"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1313"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1314"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1315"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '68918c7a-f5bc-4a1a-a62f-ad8983600d48']]">
         <assert id="EHF-ESPD-CT-C-1401"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.BUSINESS.CREDITORS_ARRANGEMENT'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.BUSINESS.CREDITORS_ARRANGEMENT".</assert>
         <assert id="EHF-ESPD-CT-C-1402"
                 test="normalize-space(cbc:Name) = 'Arrangement with creditors'"
                 flag="fatal">Element 'Name' MUST have value "Arrangement with creditors".</assert>
         <assert id="EHF-ESPD-CT-C-1403"
                 test="normalize-space(cbc:Description) = 'Is the economic operator in arrangement with creditors? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.'"
                 flag="fatal">Element 'Description' MUST have value "Is the economic operator in arrangement with creditors? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.".</assert>
         <assert id="EHF-ESPD-CT-C-1404"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd91c11a1-f19e-4b83-8ade-c4be2bf00555'"
                 flag="fatal">Criterion '68918c7a-f5bc-4a1a-a62f-ad8983600d48' MUST have RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-1422"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '68918c7a-f5bc-4a1a-a62f-ad8983600d48' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '68918c7a-f5bc-4a1a-a62f-ad8983600d48']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1411"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1412"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1413"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1414"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1415"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'daffa2a9-9f8f-4568-8be8-7b8bf306d096']]">
         <assert id="EHF-ESPD-CT-C-1501"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.BUSINESS.BANKRUPTCY_ANALOGOUS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.BUSINESS.BANKRUPTCY_ANALOGOUS".</assert>
         <assert id="EHF-ESPD-CT-C-1502"
                 test="normalize-space(cbc:Name) = 'Analogous situation like bankruptcy under national law'"
                 flag="fatal">Element 'Name' MUST have value "Analogous situation like bankruptcy under national law".</assert>
         <assert id="EHF-ESPD-CT-C-1503"
                 test="normalize-space(cbc:Description) = 'Is the economic operator in any analogous situation like bankruptcy arising from a similar procedure under national laws and regulations? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.'"
                 flag="fatal">Element 'Description' MUST have value "Is the economic operator in any analogous situation like bankruptcy arising from a similar procedure under national laws and regulations? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.".</assert>
         <assert id="EHF-ESPD-CT-C-1504"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1521"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd91c11a1-f19e-4b83-8ade-c4be2bf00555'"
                 flag="fatal">Criterion 'daffa2a9-9f8f-4568-8be8-7b8bf306d096' MUST have RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-1522"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion 'daffa2a9-9f8f-4568-8be8-7b8bf306d096' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'daffa2a9-9f8f-4568-8be8-7b8bf306d096']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1511"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1512"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1513"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1514"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1515"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '8fda202a-0c37-41bb-9d7d-de3f49edbfcb']]">
         <assert id="EHF-ESPD-CT-C-1601"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.BUSINESS.LIQUIDATOR_ADMINISTERED'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.BUSINESS.LIQUIDATOR_ADMINISTERED".</assert>
         <assert id="EHF-ESPD-CT-C-1602"
                 test="normalize-space(cbc:Name) = 'Assets being administered by liquidator'"
                 flag="fatal">Element 'Name' MUST have value "Assets being administered by liquidator".</assert>
         <assert id="EHF-ESPD-CT-C-1603"
                 test="normalize-space(cbc:Description) = 'Are the assets of the economic operator being administered by a liquidator or by the court? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.'"
                 flag="fatal">Element 'Description' MUST have value "Are the assets of the economic operator being administered by a liquidator or by the court? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.".</assert>
         <assert id="EHF-ESPD-CT-C-1604"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd91c11a1-f19e-4b83-8ade-c4be2bf00555'"
                 flag="fatal">Criterion '8fda202a-0c37-41bb-9d7d-de3f49edbfcb' MUST have RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-1622"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '8fda202a-0c37-41bb-9d7d-de3f49edbfcb' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '8fda202a-0c37-41bb-9d7d-de3f49edbfcb']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1611"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1612"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1613"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1614"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1615"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '166536e2-77f7-455c-b018-70582474e4f6']]">
         <assert id="EHF-ESPD-CT-C-1701"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.BUSINESS.ACTIVITIES_SUSPENDED'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.BUSINESS.ACTIVITIES_SUSPENDED".</assert>
         <assert id="EHF-ESPD-CT-C-1702"
                 test="normalize-space(cbc:Name) = 'Business activities are suspended'"
                 flag="fatal">Element 'Name' MUST have value "Business activities are suspended".</assert>
         <assert id="EHF-ESPD-CT-C-1703"
                 test="normalize-space(cbc:Description) = 'Are the business activities of the economic operator suspended? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.'"
                 flag="fatal">Element 'Description' MUST have value "Are the business activities of the economic operator suspended? This information needs not be given if exclusion of economic operators in this case has been made mandatory under the applicable national law without any possibility of derogation where the economic operator is nevertheless able to perform the contract.".</assert>
         <assert id="EHF-ESPD-CT-C-1704"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd91c11a1-f19e-4b83-8ade-c4be2bf00555'"
                 flag="fatal">Criterion '166536e2-77f7-455c-b018-70582474e4f6' MUST have RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-1722"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '166536e2-77f7-455c-b018-70582474e4f6' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '166536e2-77f7-455c-b018-70582474e4f6']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1711"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1712"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1713"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1714"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1715"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '514d3fde-1e3e-4dcd-b02a-9f984d5bbda3']]">
         <assert id="EHF-ESPD-CT-C-1801"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.MISCONDUCT.MC_PROFESSIONAL'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.MISCONDUCT.MC_PROFESSIONAL".</assert>
         <assert id="EHF-ESPD-CT-C-1802"
                 test="normalize-space(cbc:Name) = 'Guilty of grave professional misconduct'"
                 flag="fatal">Element 'Name' MUST have value "Guilty of grave professional misconduct".</assert>
         <assert id="EHF-ESPD-CT-C-1803"
                 test="normalize-space(cbc:Description) = 'Is the economic operator guilty of grave professional misconduct? Where applicable, see definitions in national law, the relevant notice or the procurement documents.'"
                 flag="fatal">Element 'Description' MUST have value "Is the economic operator guilty of grave professional misconduct? Where applicable, see definitions in national law, the relevant notice or the procurement documents.".</assert>
         <assert id="EHF-ESPD-CT-C-1804"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1821"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8'"
                 flag="fatal">Criterion '514d3fde-1e3e-4dcd-b02a-9f984d5bbda3' MUST have RequirementGroup '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '514d3fde-1e3e-4dcd-b02a-9f984d5bbda3']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1811"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1812"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1813"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1814"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1815"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '56d13e3d-76e8-4f23-8af6-13e60a2ee356']]">
         <assert id="EHF-ESPD-CT-C-1901"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.MISCONDUCT.MARKET_DISTORTION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.MISCONDUCT.MARKET_DISTORTION".</assert>
         <assert id="EHF-ESPD-CT-C-1902"
                 test="normalize-space(cbc:Name) = 'Agreements with other economic operators aimed at distorting competition'"
                 flag="fatal">Element 'Name' MUST have value "Agreements with other economic operators aimed at distorting competition".</assert>
         <assert id="EHF-ESPD-CT-C-1903"
                 test="normalize-space(cbc:Description) = 'Has the economic operator entered into agreements with other economic operators aimed at distorting competition?'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator entered into agreements with other economic operators aimed at distorting competition?".</assert>
         <assert id="EHF-ESPD-CT-C-1904"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-1921"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8'"
                 flag="fatal">Criterion '56d13e3d-76e8-4f23-8af6-13e60a2ee356' MUST have RequirementGroup '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '56d13e3d-76e8-4f23-8af6-13e60a2ee356']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C1911"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C1912"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C1913"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C1914"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C1915"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'b1b5ac18-f393-4280-9659-1367943c1a2e']]">
         <assert id="EHF-ESPD-CT-C-2001"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.PROCEDURE_PARTICIPATION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.PROCEDURE_PARTICIPATION".</assert>
         <assert id="EHF-ESPD-CT-C-2002"
                 test="normalize-space(cbc:Name) = 'Conflict of interest due to its participation in the procurement procedure'"
                 flag="fatal">Element 'Name' MUST have value "Conflict of interest due to its participation in the procurement procedure".</assert>
         <assert id="EHF-ESPD-CT-C-2003"
                 test="normalize-space(cbc:Description) = 'Is the economic operator aware of any conflict of interest, as indicated in national law, the relevant notice or the procurement documents due to its participation in the procurement procedure?'"
                 flag="fatal">Element 'Description' MUST have value "Is the economic operator aware of any conflict of interest, as indicated in national law, the relevant notice or the procurement documents due to its participation in the procurement procedure?".</assert>
         <assert id="EHF-ESPD-CT-C-2004"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '30450436-f559-4dfa-98ba-f0842ed9d2a0'"
                 flag="fatal">Criterion 'b1b5ac18-f393-4280-9659-1367943c1a2e' MUST have RequirementGroup '30450436-f559-4dfa-98ba-f0842ed9d2a0' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'b1b5ac18-f393-4280-9659-1367943c1a2e']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2011"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2012"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2013"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2014"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C2015"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '61874050-5130-4f1c-a174-720939c7b483']]">
         <assert id="EHF-ESPD-CT-C-2101"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.PROCEDURE_PREPARATION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.PROCEDURE_PREPARATION".</assert>
         <assert id="EHF-ESPD-CT-C-2102"
                 test="normalize-space(cbc:Name) = 'Direct or indirect involvement in the preparation of this procurement procedure'"
                 flag="fatal">Element 'Name' MUST have value "Direct or indirect involvement in the preparation of this procurement procedure".</assert>
         <assert id="EHF-ESPD-CT-C-2103"
                 test="normalize-space(cbc:Description) = 'Has the economic operator or an undertaking related to it advised the contracting authority or contracting entity or otherwise been involved in the preparation of the procurement procedure?'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator or an undertaking related to it advised the contracting authority or contracting entity or otherwise been involved in the preparation of the procurement procedure?".</assert>
         <assert id="EHF-ESPD-CT-C-2104"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '77ae3f29-7c5f-4afa-af97-24afec48c5bf'"
                 flag="fatal">Criterion '61874050-5130-4f1c-a174-720939c7b483' MUST have RequirementGroup '77ae3f29-7c5f-4afa-af97-24afec48c5bf' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '61874050-5130-4f1c-a174-720939c7b483']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2111"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2112"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2113"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2114"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C2115"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '3293e92b-7f3e-42f1-bee6-a7641bb04251']]">
         <assert id="EHF-ESPD-CT-C-2201"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.EARLY_TERMINATION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.EARLY_TERMINATION".</assert>
         <assert id="EHF-ESPD-CT-C-2202"
                 test="normalize-space(cbc:Name) = 'Early termination, damages or other comparable sanctions'"
                 flag="fatal">Element 'Name' MUST have value "Early termination, damages or other comparable sanctions".</assert>
         <assert id="EHF-ESPD-CT-C-2203"
                 test="normalize-space(cbc:Description) = 'Has the economic operator experienced that a prior public contract, a prior contract with a contracting entity or a prior concession contract was terminated early, or that damages or other comparable sanctions were imposed in connection with that prior contract?'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator experienced that a prior public contract, a prior contract with a contracting entity or a prior concession contract was terminated early, or that damages or other comparable sanctions were imposed in connection with that prior contract?".</assert>
         <assert id="EHF-ESPD-CT-C-2204"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8'"
                 flag="fatal">Criterion '3293e92b-7f3e-42f1-bee6-a7641bb04251' MUST have RequirementGroup '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '3293e92b-7f3e-42f1-bee6-a7641bb04251']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2211"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2212"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2213"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2214"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C2215"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '696a75b2-6107-428f-8b74-82affb67e184']]">
         <assert id="EHF-ESPD-CT-C-2301"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.MISINTERPRETATION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.CONFLICT_OF_INTEREST.MISINTERPRETATION".</assert>
         <assert id="EHF-ESPD-CT-C-2302"
                 test="normalize-space(cbc:Name) = 'Guilty of misinterpretation, withheld information, unable to provide required documents and obtained confidential information of this procedure'"
                 flag="fatal">Element 'Name' MUST have value "Guilty of misinterpretation, withheld information, unable to provide required documents and obtained confidential information of this procedure".</assert>
         <assert id="EHF-ESPD-CT-C-2303"
                 test="normalize-space(cbc:Description) = 'Can the economic operator confirm the four exclusion grounds, that it has not been guilty of serious misrepresentation in supplying the information required for the verification of the absence of grounds for exclusion or the fulfilment of the selection criteria, that it has not withheld such information, it has been able, without delay, to submit the supporting documents required by a contracting authority or contracting entity, and it has not undertaken to unduly influence the decision making process of the contracting authority or contracting entity, to obtain confidential information that may confer upon it undue advantages in the procurement procedure or to negligently provide misleading information that may have a material influence on decisions concerning exclusion, selection or award?'"
                 flag="fatal">Element 'Description' MUST have value "Can the economic operator confirm the four exclusion grounds, that it has not been guilty of serious misrepresentation in supplying the information required for the verification of the absence of grounds for exclusion or the fulfilment of the selection criteria, that it has not withheld such information, it has been able, without delay, to submit the supporting documents required by a contracting authority or contracting entity, and it has not undertaken to unduly influence the decision making process of the contracting authority or contracting entity, to obtain confidential information that may confer upon it undue advantages in the procurement procedure or to negligently provide misleading information that may have a material influence on decisions concerning exclusion, selection or award?".</assert>
         <assert id="EHF-ESPD-CT-C-2304"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '30450436-f559-4dfa-98ba-f0842ed9d2a0'"
                 flag="fatal">Criterion '696a75b2-6107-428f-8b74-82affb67e184' MUST have RequirementGroup '30450436-f559-4dfa-98ba-f0842ed9d2a0' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '696a75b2-6107-428f-8b74-82affb67e184']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2311"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2312"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2313"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2314"
                 test="normalize-space(ccv-cbc:Article) = '57(4)'"
                 flag="fatal">Element 'Article' MUST have value "57(4)".</assert>
         <assert id="EHF-ESPD-CT-C2315"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '7e7db838-eeac-46d9-ab39-42927486f22d']]">
         <assert id="EHF-ESPD-CT-C-2401"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ALL_SATISFIED'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ALL_SATISFIED".</assert>
         <assert id="EHF-ESPD-CT-C-2402"
                 test="normalize-space(cbc:Name) = 'All selection criteria will be satisfied'"
                 flag="fatal">Element 'Name' MUST have value "All selection criteria will be satisfied".</assert>
         <assert id="EHF-ESPD-CT-C-2403"
                 test="normalize-space(cbc:Description) = 'It satisfies all the required selection criteria indicated in the relevant notice or in the procurement documents referred to in the notice.'"
                 flag="fatal">Element 'Description' MUST have value "It satisfies all the required selection criteria indicated in the relevant notice or in the procurement documents referred to in the notice.".</assert>
         <assert id="EHF-ESPD-CT-C-2404"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'f3a6836d-2de2-4cd1-81ca-fb06178d05c5'"
                 flag="fatal">Criterion '7e7db838-eeac-46d9-ab39-42927486f22d' MUST have RequirementGroup 'f3a6836d-2de2-4cd1-81ca-fb06178d05c5' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '6ee55a59-6adb-4c3a-b89f-e62a7ad7be7f']]">
         <assert id="EHF-ESPD-CT-C-2501"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.SUITABILITY.PROFESSIONAL_REGISTER_ENROLMENT'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.SUITABILITY.PROFESSIONAL_REGISTER_ENROLMENT".</assert>
         <assert id="EHF-ESPD-CT-C-2502"
                 test="normalize-space(cbc:Name) = 'Enrolment in a relevant professional register'"
                 flag="fatal">Element 'Name' MUST have value "Enrolment in a relevant professional register".</assert>
         <assert id="EHF-ESPD-CT-C-2503"
                 test="normalize-space(cbc:Description) = 'It is enrolled in relevant professional registers kept in the Member State of its establishment as described in Annex XI of Directive 2014/24/EU; economic operators from certain Member States may have to comply with other requirements set out in that Annex.'"
                 flag="fatal">Element 'Description' MUST have value "It is enrolled in relevant professional registers kept in the Member State of its establishment as described in Annex XI of Directive 2014/24/EU; economic operators from certain Member States may have to comply with other requirements set out in that Annex.".</assert>
         <assert id="EHF-ESPD-CT-C-2504"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2521"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '1768de86-a6c8-48e4-bd8e-de2f2f7424d0'"
                 flag="fatal">Criterion '6ee55a59-6adb-4c3a-b89f-e62a7ad7be7f' MUST have RequirementGroup '1768de86-a6c8-48e4-bd8e-de2f2f7424d0' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-2522"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '6ee55a59-6adb-4c3a-b89f-e62a7ad7be7f' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '6ee55a59-6adb-4c3a-b89f-e62a7ad7be7f']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2511"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2512"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2513"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2514"
                 test="normalize-space(ccv-cbc:Article) = '58(2)'"
                 flag="fatal">Element 'Article' MUST have value "58(2)".</assert>
         <assert id="EHF-ESPD-CT-C2515"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '87b3fa26-3549-4f92-b8e0-3fd8f04bf5c7']]">
         <assert id="EHF-ESPD-CT-C-2601"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.SUITABILITY.TRADE_REGISTER_ENROLMENT'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.SUITABILITY.TRADE_REGISTER_ENROLMENT".</assert>
         <assert id="EHF-ESPD-CT-C-2602"
                 test="normalize-space(cbc:Name) = 'Enrolment in a trade register'"
                 flag="fatal">Element 'Name' MUST have value "Enrolment in a trade register".</assert>
         <assert id="EHF-ESPD-CT-C-2603"
                 test="normalize-space(cbc:Description) = 'It is enrolled in trade registers kept in the Member State of its establishment as described in Annex XI of Directive 2014/24/EU; economic operators from certain Member States may have to comply with other requirements set out in that Annex.'"
                 flag="fatal">Element 'Description' MUST have value "It is enrolled in trade registers kept in the Member State of its establishment as described in Annex XI of Directive 2014/24/EU; economic operators from certain Member States may have to comply with other requirements set out in that Annex.".</assert>
         <assert id="EHF-ESPD-CT-C-2604"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '1768de86-a6c8-48e4-bd8e-de2f2f7424d0'"
                 flag="fatal">Criterion '87b3fa26-3549-4f92-b8e0-3fd8f04bf5c7' MUST have RequirementGroup '1768de86-a6c8-48e4-bd8e-de2f2f7424d0' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-2622"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '87b3fa26-3549-4f92-b8e0-3fd8f04bf5c7' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '87b3fa26-3549-4f92-b8e0-3fd8f04bf5c7']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2611"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2612"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2613"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2614"
                 test="normalize-space(ccv-cbc:Article) = '58(2)'"
                 flag="fatal">Element 'Article' MUST have value "58(2)".</assert>
         <assert id="EHF-ESPD-CT-C2615"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '9eeb6d5c-0eb8-48e8-a4c5-5087a7c095a4']]">
         <assert id="EHF-ESPD-CT-C-2701"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.SUITABILITY.AUTHORISATION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.SUITABILITY.AUTHORISATION".</assert>
         <assert id="EHF-ESPD-CT-C-2702"
                 test="normalize-space(cbc:Name) = 'For service contracts: authorisation of particular organisation needed'"
                 flag="fatal">Element 'Name' MUST have value "For service contracts: authorisation of particular organisation needed".</assert>
         <assert id="EHF-ESPD-CT-C-2703"
                 test="normalize-space(cbc:Description) = 'Is a particular authorisation of a particular organisation needed in order to be able to perform the service in question in the country of establishment of the economic operator?'"
                 flag="fatal">Element 'Description' MUST have value "Is a particular authorisation of a particular organisation needed in order to be able to perform the service in question in the country of establishment of the economic operator?".</assert>
         <assert id="EHF-ESPD-CT-C-2704"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'a109e144-f65e-469d-bcda-220f1af34b6c'"
                 flag="fatal">Criterion '9eeb6d5c-0eb8-48e8-a4c5-5087a7c095a4' MUST have RequirementGroup 'a109e144-f65e-469d-bcda-220f1af34b6c' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-2722"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '9eeb6d5c-0eb8-48e8-a4c5-5087a7c095a4' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '9eeb6d5c-0eb8-48e8-a4c5-5087a7c095a4']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2711"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2712"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2713"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2714"
                 test="normalize-space(ccv-cbc:Article) = '58(2)'"
                 flag="fatal">Element 'Article' MUST have value "58(2)".</assert>
         <assert id="EHF-ESPD-CT-C2715"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '73f10e36-ed7a-412e-995c-aa76463e3776']]">
         <assert id="EHF-ESPD-CT-C-2801"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.SUITABILITY.MEMBERSHIP'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.SUITABILITY.MEMBERSHIP".</assert>
         <assert id="EHF-ESPD-CT-C-2802"
                 test="normalize-space(cbc:Name) = 'For service contracts: membership of particular organisation needed'"
                 flag="fatal">Element 'Name' MUST have value "For service contracts: membership of particular organisation needed".</assert>
         <assert id="EHF-ESPD-CT-C-2803"
                 test="normalize-space(cbc:Description) = 'Is a particular membership of a particular organisation needed in order to be able to perform the service in question in the country of establishment of the economic operator?'"
                 flag="fatal">Element 'Description' MUST have value "Is a particular membership of a particular organisation needed in order to be able to perform the service in question in the country of establishment of the economic operator?".</assert>
         <assert id="EHF-ESPD-CT-C-2804"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-2821"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'a109e144-f65e-469d-bcda-220f1af34b6c'"
                 flag="fatal">Criterion '73f10e36-ed7a-412e-995c-aa76463e3776' MUST have RequirementGroup 'a109e144-f65e-469d-bcda-220f1af34b6c' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-2822"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '73f10e36-ed7a-412e-995c-aa76463e3776' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '73f10e36-ed7a-412e-995c-aa76463e3776']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2811"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2812"
                 test="normalize-space(cbc:Description) = 'Directive 2014/24/EU'"
                 flag="fatal">Element 'Description' MUST have value "Directive 2014/24/EU".</assert>
         <assert id="EHF-ESPD-CT-C2813"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2814"
                 test="normalize-space(ccv-cbc:Article) = '58(2)'"
                 flag="fatal">Element 'Article' MUST have value "58(2)".</assert>
         <assert id="EHF-ESPD-CT-C2815"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '499efc97-2ac1-4af2-9e84-323c2ca67747']]">
         <assert id="EHF-ESPD-CT-C-2901"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.GENERAL_YEARLY'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.GENERAL_YEARLY".</assert>
         <assert id="EHF-ESPD-CT-C-2902"
                 test="normalize-space(cbc:Name) = 'General yearly turnover'"
                 flag="fatal">Element 'Name' MUST have value "General yearly turnover".</assert>
         <assert id="EHF-ESPD-CT-C-2903"
                 test="normalize-space(cbc:Description) = 'Its general yearly turnover for the number of financial years required in the relevant notice, the procurement documents or the ESPD is as follows:'"
                 flag="fatal">Element 'Description' MUST have value "Its general yearly turnover for the number of financial years required in the relevant notice, the procurement documents or the ESPD is as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-2904"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16'])"/>
         <assert id="EHF-ESPD-CT-C-2921" test="$count &gt; 0" flag="fatal">Criterion '499efc97-2ac1-4af2-9e84-323c2ca67747' MUST have minimum one RequirementGroup 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-2922"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '499efc97-2ac1-4af2-9e84-323c2ca67747' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '499efc97-2ac1-4af2-9e84-323c2ca67747']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C2911"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2912"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C2913"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C2914"
                 test="normalize-space(ccv-cbc:Article) = '58(3)'"
                 flag="fatal">Element 'Article' MUST have value "58(3)".</assert>
         <assert id="EHF-ESPD-CT-C2915"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'b16cb9fc-6cb7-4585-9302-9533b415cf48']]">
         <assert id="EHF-ESPD-CT-C-3001"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.AVERAGE_YEARLY'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.AVERAGE_YEARLY".</assert>
         <assert id="EHF-ESPD-CT-C-3002"
                 test="normalize-space(cbc:Name) = 'Average yearly turnover'"
                 flag="fatal">Element 'Name' MUST have value "Average yearly turnover".</assert>
         <assert id="EHF-ESPD-CT-C-3003"
                 test="normalize-space(cbc:Description) = 'Its average yearly turnover for the number of years required in the relevant notice, the procurement documents or the ESPD is as follows:'"
                 flag="fatal">Element 'Description' MUST have value "Its average yearly turnover for the number of years required in the relevant notice, the procurement documents or the ESPD is as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-3004"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-3021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'e1886054-ada4-473c-9afc-2fde82c24cf4'"
                 flag="fatal">Criterion 'b16cb9fc-6cb7-4585-9302-9533b415cf48' MUST have RequirementGroup 'e1886054-ada4-473c-9afc-2fde82c24cf4' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3022"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'b16cb9fc-6cb7-4585-9302-9533b415cf48' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'b16cb9fc-6cb7-4585-9302-9533b415cf48']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3011"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3012"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3013"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3014"
                 test="normalize-space(ccv-cbc:Article) = '58(3)'"
                 flag="fatal">Element 'Article' MUST have value "58(3)".</assert>
         <assert id="EHF-ESPD-CT-C3015"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '074f6031-55f9-4e99-b9a4-c4363e8bc315']]">
         <assert id="EHF-ESPD-CT-C-3101"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SPECIFIC_YEARLY'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SPECIFIC_YEARLY".</assert>
         <assert id="EHF-ESPD-CT-C-3102"
                 test="normalize-space(cbc:Name) = 'Specific yearly turnover'"
                 flag="fatal">Element 'Name' MUST have value "Specific yearly turnover".</assert>
         <assert id="EHF-ESPD-CT-C-3103"
                 test="normalize-space(cbc:Description) = 'Its specific yearly turnover in the business area covered by the contract for the number of financial years required in the relevant notice, the procurement documents or the ESPD is as follows:'"
                 flag="fatal">Element 'Description' MUST have value "Its specific yearly turnover in the business area covered by the contract for the number of financial years required in the relevant notice, the procurement documents or the ESPD is as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-3104"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16'])"/>
         <assert id="EHF-ESPD-CT-C-3121" test="$count &gt; 0" flag="fatal">Criterion '074f6031-55f9-4e99-b9a4-c4363e8bc315' MUST have minimum one RequirementGroup 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3122"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '074f6031-55f9-4e99-b9a4-c4363e8bc315' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '074f6031-55f9-4e99-b9a4-c4363e8bc315']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3111"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3112"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3113"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3114"
                 test="normalize-space(ccv-cbc:Article) = '58(3)'"
                 flag="fatal">Element 'Article' MUST have value "58(3)".</assert>
         <assert id="EHF-ESPD-CT-C3115"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'd3dfb714-f558-4512-bbc5-e456fa2339de']]">
         <assert id="EHF-ESPD-CT-C-3201"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SPECIFIC_AVERAGE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SPECIFIC_AVERAGE".</assert>
         <assert id="EHF-ESPD-CT-C-3202"
                 test="normalize-space(cbc:Name) = 'Specific average turnover'"
                 flag="fatal">Element 'Name' MUST have value "Specific average turnover".</assert>
         <assert id="EHF-ESPD-CT-C-3203"
                 test="normalize-space(cbc:Description) = 'Its specific average yearly turnover in the business area covered by the contract for the number of years required in the relevant notice, the procurement documents or the ESPD is as follows:'"
                 flag="fatal">Element 'Description' MUST have value "Its specific average yearly turnover in the business area covered by the contract for the number of years required in the relevant notice, the procurement documents or the ESPD is as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-3204"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-3221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'e1886054-ada4-473c-9afc-2fde82c24cf4'"
                 flag="fatal">Criterion 'd3dfb714-f558-4512-bbc5-e456fa2339de' MUST have RequirementGroup 'e1886054-ada4-473c-9afc-2fde82c24cf4' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3222"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'd3dfb714-f558-4512-bbc5-e456fa2339de' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'd3dfb714-f558-4512-bbc5-e456fa2339de']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3211"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3212"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3213"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3214"
                 test="normalize-space(ccv-cbc:Article) = '58(3)'"
                 flag="fatal">Element 'Article' MUST have value "58(3)".</assert>
         <assert id="EHF-ESPD-CT-C3215"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '77f481ce-ffb6-483f-8e2b-c78db5e68292']]">
         <assert id="EHF-ESPD-CT-C-3301"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SET_UP'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.TURNOVER.SET_UP".</assert>
         <assert id="EHF-ESPD-CT-C-3302"
                 test="normalize-space(cbc:Name) = 'Set up of economic operator'"
                 flag="fatal">Element 'Name' MUST have value "Set up of economic operator".</assert>
         <assert id="EHF-ESPD-CT-C-3303"
                 test="normalize-space(cbc:Description) = 'In case the information concerning turnover (general or specific) is not available for the entire period required, please state the date on which the economic operator was set up or started trading:'"
                 flag="fatal">Element 'Description' MUST have value "In case the information concerning turnover (general or specific) is not available for the entire period required, please state the date on which the economic operator was set up or started trading:".</assert>
         <assert id="EHF-ESPD-CT-C-3304"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-3321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'e9aa7763-c167-4352-8060-1a3d7d3e2662'"
                 flag="fatal">Criterion '77f481ce-ffb6-483f-8e2b-c78db5e68292' MUST have RequirementGroup 'e9aa7763-c167-4352-8060-1a3d7d3e2662' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '77f481ce-ffb6-483f-8e2b-c78db5e68292']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3311"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3312"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3313"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3314"
                 test="normalize-space(ccv-cbc:Article) = '58(3)'"
                 flag="fatal">Element 'Article' MUST have value "58(3)".</assert>
         <assert id="EHF-ESPD-CT-C3315"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'e4d37adc-08cd-4f4d-a8d8-32b62b0a1f46']]">
         <assert id="EHF-ESPD-CT-C-3401"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.FINANCIAL_RATIO'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.FINANCIAL_RATIO".</assert>
         <assert id="EHF-ESPD-CT-C-3402"
                 test="normalize-space(cbc:Name) = 'Financial ratio'"
                 flag="fatal">Element 'Name' MUST have value "Financial ratio".</assert>
         <assert id="EHF-ESPD-CT-C-3403"
                 test="normalize-space(cbc:Description) = 'Concerning the financial ratios specified in the relevant notice, the procurement documents or the ESPD, the economic operator declares that the actual values for the required ratios are as follows:'"
                 flag="fatal">Element 'Description' MUST have value "Concerning the financial ratios specified in the relevant notice, the procurement documents or the ESPD, the economic operator declares that the actual values for the required ratios are as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-3404"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = '096686e1-82ca-4de0-8710-d74d90da0f0c'])"/>
         <assert id="EHF-ESPD-CT-C-3421" test="$count &gt; 0" flag="fatal">Criterion 'e4d37adc-08cd-4f4d-a8d8-32b62b0a1f46' MUST have minimum one RequirementGroup '096686e1-82ca-4de0-8710-d74d90da0f0c' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3422"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'e4d37adc-08cd-4f4d-a8d8-32b62b0a1f46' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'e4d37adc-08cd-4f4d-a8d8-32b62b0a1f46']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3411"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3412"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3413"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3414"
                 test="normalize-space(ccv-cbc:Article) = '58(3)'"
                 flag="fatal">Element 'Article' MUST have value "58(3)".</assert>
         <assert id="EHF-ESPD-CT-C3415"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '7604bd40-4462-4086-8763-a50da51a869c']]">
         <assert id="EHF-ESPD-CT-C-3501"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.RISK_INDEMNITY_INSURANCE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.RISK_INDEMNITY_INSURANCE".</assert>
         <assert id="EHF-ESPD-CT-C-3502"
                 test="normalize-space(cbc:Name) = 'Professional risk indemnity insurance'"
                 flag="fatal">Element 'Name' MUST have value "Professional risk indemnity insurance".</assert>
         <assert id="EHF-ESPD-CT-C-3503"
                 test="normalize-space(cbc:Description) = 'The insured amount in its professional risk indemnity insurance is the following:'"
                 flag="fatal">Element 'Description' MUST have value "The insured amount in its professional risk indemnity insurance is the following:".</assert>
         <assert id="EHF-ESPD-CT-C-3504"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-3521"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '42dc8062-974d-4201-91ba-7f2ea90338fd'"
                 flag="fatal">Criterion '7604bd40-4462-4086-8763-a50da51a869c' MUST have RequirementGroup '42dc8062-974d-4201-91ba-7f2ea90338fd' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3522"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '7604bd40-4462-4086-8763-a50da51a869c' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '7604bd40-4462-4086-8763-a50da51a869c']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3511"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3512"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3513"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3514"
                 test="normalize-space(ccv-cbc:Article) = '58(3)'"
                 flag="fatal">Element 'Article' MUST have value "58(3)".</assert>
         <assert id="EHF-ESPD-CT-C3515"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'ab0e7f2e-6418-40e2-8870-6713123e41ad']]">
         <assert id="EHF-ESPD-CT-C-3601"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.OTHER_REQUIREMENTS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.ECONOMIC_FINANCIAL_STANDING.OTHER_REQUIREMENTS".</assert>
         <assert id="EHF-ESPD-CT-C-3602"
                 test="normalize-space(cbc:Name) = 'Other economic or financial requirements'"
                 flag="fatal">Element 'Name' MUST have value "Other economic or financial requirements".</assert>
         <assert id="EHF-ESPD-CT-C-3603"
                 test="normalize-space(cbc:Description) = 'Concerning the other economic or financial requirements, if any, that may have been specified in the relevant notice or the procurement documents, the economic operator declares that:'"
                 flag="fatal">Element 'Description' MUST have value "Concerning the other economic or financial requirements, if any, that may have been specified in the relevant notice or the procurement documents, the economic operator declares that:".</assert>
         <assert id="EHF-ESPD-CT-C-3604"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-3621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion 'ab0e7f2e-6418-40e2-8870-6713123e41ad' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3622"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'ab0e7f2e-6418-40e2-8870-6713123e41ad' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'cdd3bb3e-34a5-43d5-b668-2aab86a73822']]">
         <assert id="EHF-ESPD-CT-C-3701"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.WORKS_PERFORMANCE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.WORKS_PERFORMANCE".</assert>
         <assert id="EHF-ESPD-CT-C-3702"
                 test="normalize-space(cbc:Name) = 'For works contracts: performance of works of the specified type'"
                 flag="fatal">Element 'Name' MUST have value "For works contracts: performance of works of the specified type".</assert>
         <assert id="EHF-ESPD-CT-C-3703"
                 test="normalize-space(cbc:Description) = 'For public works contracts only: During the reference period, the economic operator has performed the following works of the specified type. Contracting authorities may require up to five years and allow experience dating from more than five years.'"
                 flag="fatal">Element 'Description' MUST have value "For public works contracts only: During the reference period, the economic operator has performed the following works of the specified type. Contracting authorities may require up to five years and allow experience dating from more than five years.".</assert>
         <assert id="EHF-ESPD-CT-C-3704"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = '96f00020-0a25-402e-b850-2378e83b5695'])"/>
         <assert id="EHF-ESPD-CT-C-3721" test="$count &gt; 0" flag="fatal">Criterion 'cdd3bb3e-34a5-43d5-b668-2aab86a73822' MUST have minimum one RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3722"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'cdd3bb3e-34a5-43d5-b668-2aab86a73822' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'cdd3bb3e-34a5-43d5-b668-2aab86a73822']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3711"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3712"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3713"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3714"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C3715"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '3a18a175-1863-4b1d-baef-588ce61960ca']]">
         <assert id="EHF-ESPD-CT-C-3801"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.SUPPLIES_DELIVERY_PERFORMANCE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.SUPPLIES_DELIVERY_PERFORMANCE".</assert>
         <assert id="EHF-ESPD-CT-C-3802"
                 test="normalize-space(cbc:Name) = 'For supply contracts: performance of deliveries of the specified type'"
                 flag="fatal">Element 'Name' MUST have value "For supply contracts: performance of deliveries of the specified type".</assert>
         <assert id="EHF-ESPD-CT-C-3803"
                 test="normalize-space(cbc:Description) = 'For public supply contracts only: During the reference period, the economic operator has delivered the following principal deliveries of the type specified. Contracting authorities may require up to three years and allow experience dating from more than three years.'"
                 flag="fatal">Element 'Description' MUST have value "For public supply contracts only: During the reference period, the economic operator has delivered the following principal deliveries of the type specified. Contracting authorities may require up to three years and allow experience dating from more than three years.".</assert>
         <assert id="EHF-ESPD-CT-C-3804"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = '96f00020-0a25-402e-b850-2378e83b5695'])"/>
         <assert id="EHF-ESPD-CT-C-3821" test="$count &gt; 0" flag="fatal">Criterion '3a18a175-1863-4b1d-baef-588ce61960ca' MUST have minimum one RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3822"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '3a18a175-1863-4b1d-baef-588ce61960ca' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '3a18a175-1863-4b1d-baef-588ce61960ca']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3811"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3812"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3813"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3814"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C3815"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '5e506c16-26ab-4e32-bb78-b27f87dc0565']]">
         <assert id="EHF-ESPD-CT-C-3901"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.SERVICES_DELIVERY_PERFORMANCE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.REFERENCES.SERVICES_DELIVERY_PERFORMANCE".</assert>
         <assert id="EHF-ESPD-CT-C-3902"
                 test="normalize-space(cbc:Name) = 'For service contracts: performance of services of the specified type'"
                 flag="fatal">Element 'Name' MUST have value "For service contracts: performance of services of the specified type".</assert>
         <assert id="EHF-ESPD-CT-C-3903"
                 test="normalize-space(cbc:Description) = 'For public service contracts only: During the reference period, the economic operator has provided the following main services of the type specified. Contracting authorities may require up to three years and allow experience dating from more than three years.'"
                 flag="fatal">Element 'Description' MUST have value "For public service contracts only: During the reference period, the economic operator has provided the following main services of the type specified. Contracting authorities may require up to three years and allow experience dating from more than three years.".</assert>
         <assert id="EHF-ESPD-CT-C-3904"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = '96f00020-0a25-402e-b850-2378e83b5695'])"/>
         <assert id="EHF-ESPD-CT-C-3921" test="$count &gt; 0" flag="fatal">Criterion '5e506c16-26ab-4e32-bb78-b27f87dc0565' MUST have minimum one RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-3922"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '5e506c16-26ab-4e32-bb78-b27f87dc0565' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '5e506c16-26ab-4e32-bb78-b27f87dc0565']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C3911"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3912"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C3913"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C3914"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C3915"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '3aaca389-4a7b-406b-a4b9-080845d127e7']]">
         <assert id="EHF-ESPD-CT-C-4001"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.TECHNICIANS_FOR_QUALITY_CONTROL'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.TECHNICIANS_FOR_QUALITY_CONTROL".</assert>
         <assert id="EHF-ESPD-CT-C-4002"
                 test="normalize-space(cbc:Name) = 'Technicians or technical bodies for quality control'"
                 flag="fatal">Element 'Name' MUST have value "Technicians or technical bodies for quality control".</assert>
         <assert id="EHF-ESPD-CT-C-4003"
                 test="normalize-space(cbc:Description) = 'It can call upon the following technicians or technical bodies, especially those responsible for quality control. For technicians or technical bodies not belonging directly to the economic operator''s undertaking but on whose capacities the economic operator relies as set out under Part II, Section C, separate ESPD forms must be filled in.'"
                 flag="fatal">Element 'Description' MUST have value "It can call upon the following technicians or technical bodies, especially those responsible for quality control. For technicians or technical bodies not belonging directly to the economic operator's undertaking but on whose capacities the economic operator relies as set out under Part II, Section C, separate ESPD forms must be filled in.".</assert>
         <assert id="EHF-ESPD-CT-C-4004"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion '3aaca389-4a7b-406b-a4b9-080845d127e7' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4022"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '3aaca389-4a7b-406b-a4b9-080845d127e7' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '3aaca389-4a7b-406b-a4b9-080845d127e7']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4011"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4012"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4013"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4014"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4015"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'c599c130-b29f-461e-a187-4e16c7d40db7']]">
         <assert id="EHF-ESPD-CT-C-4101"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.TECHNICIANS_FOR_CARRYING_WORKS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.TECHNICIANS_FOR_CARRYING_WORKS".</assert>
         <assert id="EHF-ESPD-CT-C-4102"
                 test="normalize-space(cbc:Name) = 'For works contracts: technicians or technical bodies to carry out the work'"
                 flag="fatal">Element 'Name' MUST have value "For works contracts: technicians or technical bodies to carry out the work".</assert>
         <assert id="EHF-ESPD-CT-C-4103"
                 test="normalize-space(cbc:Description) = 'In the case of public works contracts, the economic operator will be able to call on the following technicians or technical bodies to carry out the work:'"
                 flag="fatal">Element 'Description' MUST have value "In the case of public works contracts, the economic operator will be able to call on the following technicians or technical bodies to carry out the work:".</assert>
         <assert id="EHF-ESPD-CT-C-4104"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion 'c599c130-b29f-461e-a187-4e16c7d40db7' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4122"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'c599c130-b29f-461e-a187-4e16c7d40db7' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'c599c130-b29f-461e-a187-4e16c7d40db7']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4111"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4112"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4113"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4114"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4115"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '4bf996d9-439c-40c6-9ab9-980a48cb55a1']]">
         <assert id="EHF-ESPD-CT-C-4201"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.FACILITIES_FOR_QUALITY_ENSURING'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.FACILITIES_FOR_QUALITY_ENSURING".</assert>
         <assert id="EHF-ESPD-CT-C-4202"
                 test="normalize-space(cbc:Name) = 'Technical facilities and measures for ensuring quality'"
                 flag="fatal">Element 'Name' MUST have value "Technical facilities and measures for ensuring quality".</assert>
         <assert id="EHF-ESPD-CT-C-4203"
                 test="normalize-space(cbc:Description) = 'It uses the following technical facilities and measures for ensuring quality and its study and research facilities are as follows:'"
                 flag="fatal">Element 'Description' MUST have value "It uses the following technical facilities and measures for ensuring quality and its study and research facilities are as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-4204"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion '4bf996d9-439c-40c6-9ab9-980a48cb55a1' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4222"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '4bf996d9-439c-40c6-9ab9-980a48cb55a1' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '4bf996d9-439c-40c6-9ab9-980a48cb55a1']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4211"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4212"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4213"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4214"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4215"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '90a2e100-44cc-45d3-9970-69d6714f1596']]">
         <assert id="EHF-ESPD-CT-C-4301"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.FACILITIES_FOR_STUDY_RESEARCH'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.FACILITIES_FOR_STUDY_RESEARCH".</assert>
         <assert id="EHF-ESPD-CT-C-4302"
                 test="normalize-space(cbc:Name) = 'Study and research facilities'"
                 flag="fatal">Element 'Name' MUST have value "Study and research facilities".</assert>
         <assert id="EHF-ESPD-CT-C-4303"
                 test="normalize-space(cbc:Description) = 'It uses the following study and research facilities are as follows:'"
                 flag="fatal">Element 'Description' MUST have value "It uses the following study and research facilities are as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-4304"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion '90a2e100-44cc-45d3-9970-69d6714f1596' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4322"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '90a2e100-44cc-45d3-9970-69d6714f1596' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '90a2e100-44cc-45d3-9970-69d6714f1596']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4311"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4312"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4313"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4314"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4315"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'dc12a151-7fdf-4733-a8f0-30f667292e66']]">
         <assert id="EHF-ESPD-CT-C-4401"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.SUPPLY_CHAIN_MANAGEMENT'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.SUPPLY_CHAIN_MANAGEMENT".</assert>
         <assert id="EHF-ESPD-CT-C-4402"
                 test="normalize-space(cbc:Name) = 'Supply chain management'"
                 flag="fatal">Element 'Name' MUST have value "Supply chain management".</assert>
         <assert id="EHF-ESPD-CT-C-4403"
                 test="normalize-space(cbc:Description) = 'It will be able to apply the following supply chain management and tracking systems when performing the contract:'"
                 flag="fatal">Element 'Description' MUST have value "It will be able to apply the following supply chain management and tracking systems when performing the contract:".</assert>
         <assert id="EHF-ESPD-CT-C-4404"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion 'dc12a151-7fdf-4733-a8f0-30f667292e66' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4422"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'dc12a151-7fdf-4733-a8f0-30f667292e66' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'dc12a151-7fdf-4733-a8f0-30f667292e66']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4411"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4412"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4413"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4414"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4415"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'c8809aa1-29b6-4f27-ae2f-27e612e394db']]">
         <assert id="EHF-ESPD-CT-C-4501"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.CHECKS.ALLOWANCE_OF_CHECKS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.CHECKS.ALLOWANCE_OF_CHECKS".</assert>
         <assert id="EHF-ESPD-CT-C-4502"
                 test="normalize-space(cbc:Name) = 'Allowance of checks'"
                 flag="fatal">Element 'Name' MUST have value "Allowance of checks".</assert>
         <assert id="EHF-ESPD-CT-C-4503"
                 test="normalize-space(cbc:Description) = 'For complex products or services to be supplied or, exceptionally, for products or services which are required for a special purpose: The economic operator will allow checks to be conducted on the production capacities or the technical capacity of the economic operator and, where necessary, on the means of study and research which are available to it and on the quality control measures? The check is to be performed by the contracting authority or, in case the latter consents to this, on its behalf by a competent official body of the country in which the supplier or service provider is established.'"
                 flag="fatal">Element 'Description' MUST have value "For complex products or services to be supplied or, exceptionally, for products or services which are required for a special purpose: The economic operator will allow checks to be conducted on the production capacities or the technical capacity of the economic operator and, where necessary, on the means of study and research which are available to it and on the quality control measures? The check is to be performed by the contracting authority or, in case the latter consents to this, on its behalf by a competent official body of the country in which the supplier or service provider is established.".</assert>
         <assert id="EHF-ESPD-CT-C-4504"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4521"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd7721546-9106-43a7-8d31-2fe08a862b00'"
                 flag="fatal">Criterion 'c8809aa1-29b6-4f27-ae2f-27e612e394db' MUST have RequirementGroup 'd7721546-9106-43a7-8d31-2fe08a862b00' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'c8809aa1-29b6-4f27-ae2f-27e612e394db']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4511"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4512"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4513"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4514"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4515"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '07301031-2270-41af-8e7e-66fe0c777107']]">
         <assert id="EHF-ESPD-CT-C-4601"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.PROFESSIONAL_QUALIFICATIONS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.PROFESSIONAL_QUALIFICATIONS".</assert>
         <assert id="EHF-ESPD-CT-C-4602"
                 test="normalize-space(cbc:Name) = 'Educational and professional qualifications'"
                 flag="fatal">Element 'Name' MUST have value "Educational and professional qualifications".</assert>
         <assert id="EHF-ESPD-CT-C-4603"
                 test="normalize-space(cbc:Description) = 'The following educational and professional qualifications are held by the service provider or the contractor itself, and/or (depending on the requirements set out in the relevant notice or the procurement documents by its managerial staff.'"
                 flag="fatal">Element 'Description' MUST have value "The following educational and professional qualifications are held by the service provider or the contractor itself, and/or (depending on the requirements set out in the relevant notice or the procurement documents by its managerial staff.".</assert>
         <assert id="EHF-ESPD-CT-C-4604"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion '07301031-2270-41af-8e7e-66fe0c777107' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4622"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '07301031-2270-41af-8e7e-66fe0c777107' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '07301031-2270-41af-8e7e-66fe0c777107']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4611"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4612"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4613"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4614"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4615"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '9460457e-b43d-48a9-acd1-615de6ddd33e']]">
         <assert id="EHF-ESPD-CT-C-4701"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.ENVIRONMENTAL_MANAGEMENT_MEASURES'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.ENVIRONMENTAL_MANAGEMENT_MEASURES".</assert>
         <assert id="EHF-ESPD-CT-C-4702"
                 test="normalize-space(cbc:Name) = 'Environmental management measures'"
                 flag="fatal">Element 'Name' MUST have value "Environmental management measures".</assert>
         <assert id="EHF-ESPD-CT-C-4703"
                 test="normalize-space(cbc:Description) = 'The economic operator will be able to apply the following environmental management measures when performing the contract:'"
                 flag="fatal">Element 'Description' MUST have value "The economic operator will be able to apply the following environmental management measures when performing the contract:".</assert>
         <assert id="EHF-ESPD-CT-C-4704"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-4721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion '9460457e-b43d-48a9-acd1-615de6ddd33e' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4722"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '9460457e-b43d-48a9-acd1-615de6ddd33e' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '9460457e-b43d-48a9-acd1-615de6ddd33e']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4711"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4712"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4713"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4714"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4715"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '6346959b-e097-4ea1-89cd-d1b4c131ea4d']]">
         <assert id="EHF-ESPD-CT-C-4801"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.MANAGERIAL_STAFF'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.MANAGERIAL_STAFF".</assert>
         <assert id="EHF-ESPD-CT-C-4802"
                 test="normalize-space(cbc:Name) = 'Number of managerial staff'"
                 flag="fatal">Element 'Name' MUST have value "Number of managerial staff".</assert>
         <assert id="EHF-ESPD-CT-C-4803"
                 test="normalize-space(cbc:Description) = 'The economic operator’s number of managerial staff for the last three years were as follows:'"
                 flag="fatal">Element 'Description' MUST have value "The economic operator’s number of managerial staff for the last three years were as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-4804"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = '96defecc-7d32-4957-82e9-aad5f3c5b736'])"/>
         <assert id="EHF-ESPD-CT-C-4821" test="$count &gt; 0" flag="fatal">Criterion '6346959b-e097-4ea1-89cd-d1b4c131ea4d' MUST have minimum one RequirementGroup '96defecc-7d32-4957-82e9-aad5f3c5b736' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4822"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '6346959b-e097-4ea1-89cd-d1b4c131ea4d' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '6346959b-e097-4ea1-89cd-d1b4c131ea4d']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4811"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4812"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4813"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4814"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4815"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '1f49b3f0-d50f-43f6-8b30-4bafab108b9b']]">
         <assert id="EHF-ESPD-CT-C-4901"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.AVERAGE_ANNUAL_MANPOWER'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.AVERAGE_ANNUAL_MANPOWER".</assert>
         <assert id="EHF-ESPD-CT-C-4902"
                 test="normalize-space(cbc:Name) = 'Average annual manpower'"
                 flag="fatal">Element 'Name' MUST have value "Average annual manpower".</assert>
         <assert id="EHF-ESPD-CT-C-4903"
                 test="normalize-space(cbc:Description) = 'The economic operator’s average annual manpower for the last three years were as follows:'"
                 flag="fatal">Element 'Description' MUST have value "The economic operator’s average annual manpower for the last three years were as follows:".</assert>
         <assert id="EHF-ESPD-CT-C-4904"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = '96defecc-7d32-4957-82e9-aad5f3c5b736'])"/>
         <assert id="EHF-ESPD-CT-C-4921" test="$count &gt; 0" flag="fatal">Criterion '1f49b3f0-d50f-43f6-8b30-4bafab108b9b' MUST have minimum one RequirementGroup '96defecc-7d32-4957-82e9-aad5f3c5b736' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-4922"
                 test="ccv:RequirementGroup[2 + $count - 1] and normalize-space(ccv:RequirementGroup[2 + $count - 1][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '1f49b3f0-d50f-43f6-8b30-4bafab108b9b' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number <value-of select="2 + $count - 1"/>.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '1f49b3f0-d50f-43f6-8b30-4bafab108b9b']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C4911"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4912"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C4913"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C4914"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C4915"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'cc18c023-211d-484d-a32e-52f3f970285f']]">
         <assert id="EHF-ESPD-CT-C-5001"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.EQUIPMENT'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.TECHNICAL.EQUIPMENT".</assert>
         <assert id="EHF-ESPD-CT-C-5002"
                 test="normalize-space(cbc:Name) = 'Tools, plant or technical equipment'"
                 flag="fatal">Element 'Name' MUST have value "Tools, plant or technical equipment".</assert>
         <assert id="EHF-ESPD-CT-C-5003"
                 test="normalize-space(cbc:Description) = 'The following tools, plant or technical equipment will be available to it for performing the contract:'"
                 flag="fatal">Element 'Description' MUST have value "The following tools, plant or technical equipment will be available to it for performing the contract:".</assert>
         <assert id="EHF-ESPD-CT-C-5004"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb'"
                 flag="fatal">Criterion 'cc18c023-211d-484d-a32e-52f3f970285f' MUST have RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-5022"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'cc18c023-211d-484d-a32e-52f3f970285f' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'cc18c023-211d-484d-a32e-52f3f970285f']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C5011"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5012"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5013"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C5014"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C5015"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '612a1625-118d-4ea4-a6db-413184e7c0a8']]">
         <assert id="EHF-ESPD-CT-C-5101"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.SUBCONTRACTING_PROPORTION'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.SUBCONTRACTING_PROPORTION".</assert>
         <assert id="EHF-ESPD-CT-C-5102"
                 test="normalize-space(cbc:Name) = 'Subcontracting proportion'"
                 flag="fatal">Element 'Name' MUST have value "Subcontracting proportion".</assert>
         <assert id="EHF-ESPD-CT-C-5103"
                 test="normalize-space(cbc:Description) = 'The economic operator intends possibly to subcontract the following proportion (i.e. percentage) of the contract. Please note that if the economic operator has decided to subcontract a part of the contract and relies on the subcontractor’s capacities to perform that part, then please fill in a separate ESPD for such subcontractors, see Part II, Section C above.'"
                 flag="fatal">Element 'Description' MUST have value "The economic operator intends possibly to subcontract the following proportion (i.e. percentage) of the contract. Please note that if the economic operator has decided to subcontract a part of the contract and relies on the subcontractor’s capacities to perform that part, then please fill in a separate ESPD for such subcontractors, see Part II, Section C above.".</assert>
         <assert id="EHF-ESPD-CT-C-5104"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '575f7550-8a2d-4bad-b9d8-be07ab570076'"
                 flag="fatal">Criterion '612a1625-118d-4ea4-a6db-413184e7c0a8' MUST have RequirementGroup '575f7550-8a2d-4bad-b9d8-be07ab570076' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '612a1625-118d-4ea4-a6db-413184e7c0a8']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C5111"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5112"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5113"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C5114"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C5115"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'bdf0601d-2480-4250-b870-658d0ee95be6']]">
         <assert id="EHF-ESPD-CT-C-5201"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.ARTEFACTS.NO_AUTHENTICATED_ARTEFACTS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.ARTEFACTS.NO_AUTHENTICATED_ARTEFACTS".</assert>
         <assert id="EHF-ESPD-CT-C-5202"
                 test="normalize-space(cbc:Name) = 'For supply contracts: samples, descriptions or photographs without certification of authenticity'"
                 flag="fatal">Element 'Name' MUST have value "For supply contracts: samples, descriptions or photographs without certification of authenticity".</assert>
         <assert id="EHF-ESPD-CT-C-5203"
                 test="normalize-space(cbc:Description) = 'For public supply contracts: The economic operator will supply the required samples, descriptions or photographs of the products to be supplied, which do not need to be accompanied by certifications of authenticity.'"
                 flag="fatal">Element 'Description' MUST have value "For public supply contracts: The economic operator will supply the required samples, descriptions or photographs of the products to be supplied, which do not need to be accompanied by certifications of authenticity.".</assert>
         <assert id="EHF-ESPD-CT-C-5204"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'cb73544d-e8bb-4cc6-819b-b8e04f1e240e'"
                 flag="fatal">Criterion 'bdf0601d-2480-4250-b870-658d0ee95be6' MUST have RequirementGroup 'cb73544d-e8bb-4cc6-819b-b8e04f1e240e' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-5222"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'bdf0601d-2480-4250-b870-658d0ee95be6' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'bdf0601d-2480-4250-b870-658d0ee95be6']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C5211"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5212"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5213"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C5214"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C5215"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '7662b7a9-bcb8-4763-a0a7-7505d8e8470d']]">
         <assert id="EHF-ESPD-CT-C-5301"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.ARTEFACTS.AUTHENTICATED_ARTEFACTS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.MANAGEMENT.ARTEFACTS.AUTHENTICATED_ARTEFACTS".</assert>
         <assert id="EHF-ESPD-CT-C-5302"
                 test="normalize-space(cbc:Name) = 'For supply contracts: samples, descriptions or photographs with certification of authenticity'"
                 flag="fatal">Element 'Name' MUST have value "For supply contracts: samples, descriptions or photographs with certification of authenticity".</assert>
         <assert id="EHF-ESPD-CT-C-5303"
                 test="normalize-space(cbc:Description) = 'For public supply contracts: The economic operator will supply the required samples, descriptions or photographs of the products to be supplied and will provide certifications of authenticity where applicable.'"
                 flag="fatal">Element 'Description' MUST have value "For public supply contracts: The economic operator will supply the required samples, descriptions or photographs of the products to be supplied and will provide certifications of authenticity where applicable.".</assert>
         <assert id="EHF-ESPD-CT-C-5304"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'cb73544d-e8bb-4cc6-819b-b8e04f1e240e'"
                 flag="fatal">Criterion '7662b7a9-bcb8-4763-a0a7-7505d8e8470d' MUST have RequirementGroup 'cb73544d-e8bb-4cc6-819b-b8e04f1e240e' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-5322"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '7662b7a9-bcb8-4763-a0a7-7505d8e8470d' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '7662b7a9-bcb8-4763-a0a7-7505d8e8470d']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C5311"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5312"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5313"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C5314"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C5315"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'a7669d7d-9297-43e1-9d10-691a1660187c']]">
         <assert id="EHF-ESPD-CT-C-5401"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.QUALITY_ASSURANCE.QA_INSTITUTES_CERTIFICATE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.QUALITY_ASSURANCE.QA_INSTITUTES_CERTIFICATE".</assert>
         <assert id="EHF-ESPD-CT-C-5402"
                 test="normalize-space(cbc:Name) = 'For supply contracts: certificates by quality control institutes'"
                 flag="fatal">Element 'Name' MUST have value "For supply contracts: certificates by quality control institutes".</assert>
         <assert id="EHF-ESPD-CT-C-5403"
                 test="normalize-space(cbc:Description) = 'Can the economic operator provide the required certificates drawn up by official quality control institutes or agencies of recognised competence attesting the conformity of products clearly identified by references to the technical specifications or standards, which are set out in the relevant notice or the procurement documents?'"
                 flag="fatal">Element 'Description' MUST have value "Can the economic operator provide the required certificates drawn up by official quality control institutes or agencies of recognised competence attesting the conformity of products clearly identified by references to the technical specifications or standards, which are set out in the relevant notice or the procurement documents?".</assert>
         <assert id="EHF-ESPD-CT-C-5404"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '4887c3d7-05fc-4e3e-b066-f338910f0c4c'"
                 flag="fatal">Criterion 'a7669d7d-9297-43e1-9d10-691a1660187c' MUST have RequirementGroup '4887c3d7-05fc-4e3e-b066-f338910f0c4c' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-5422"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'a7669d7d-9297-43e1-9d10-691a1660187c' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'a7669d7d-9297-43e1-9d10-691a1660187c']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C5411"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5412"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5413"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C5414"
                 test="normalize-space(ccv-cbc:Article) = '58(4)'"
                 flag="fatal">Element 'Article' MUST have value "58(4)".</assert>
         <assert id="EHF-ESPD-CT-C5415"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'd726bac9-e153-4e75-bfca-c5385587766d']]">
         <assert id="EHF-ESPD-CT-C-5501"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.QUALITY_ASSURANCE.QA_INDEPENDENT_CERTIFICATE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.QUALITY_ASSURANCE.QA_INDEPENDENT_CERTIFICATE".</assert>
         <assert id="EHF-ESPD-CT-C-5502"
                 test="normalize-space(cbc:Name) = 'Certificates by independent bodies about arderquality assurance standards'"
                 flag="fatal">Element 'Name' MUST have value "Certificates by independent bodies about arderquality assurance standards".</assert>
         <assert id="EHF-ESPD-CT-C-5503"
                 test="normalize-space(cbc:Description) = 'Will the economic operator be able to produce certificates drawn up by independent bodies attesting that the economic operator complies with the required quality assurance standards, including accessibility for disabled persons?'"
                 flag="fatal">Element 'Description' MUST have value "Will the economic operator be able to produce certificates drawn up by independent bodies attesting that the economic operator complies with the required quality assurance standards, including accessibility for disabled persons?".</assert>
         <assert id="EHF-ESPD-CT-C-5504"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5521"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '0e88f63c-5642-4a17-833b-ae5800e1750a'"
                 flag="fatal">Criterion 'd726bac9-e153-4e75-bfca-c5385587766d' MUST have RequirementGroup '0e88f63c-5642-4a17-833b-ae5800e1750a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-5522"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion 'd726bac9-e153-4e75-bfca-c5385587766d' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = 'd726bac9-e153-4e75-bfca-c5385587766d']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C5511"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5512"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5513"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C5514"
                 test="normalize-space(ccv-cbc:Article) = '62(2)'"
                 flag="fatal">Element 'Article' MUST have value "62(2)".</assert>
         <assert id="EHF-ESPD-CT-C5515"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '8ed65e48-fd0d-444f-97bd-4f58da632999']]">
         <assert id="EHF-ESPD-CT-C-5601"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.ENVIRONMENTAL_MANAGEMENT.ENV_INDEPENDENT_CERTIFICATE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.SELECTION.TECHNICAL_PROFESSIONAL_ABILITY.CERTIFICATES.ENVIRONMENTAL_MANAGEMENT.ENV_INDEPENDENT_CERTIFICATE".</assert>
         <assert id="EHF-ESPD-CT-C-5602"
                 test="normalize-space(cbc:Name) = 'Certificates by independent bodies about environmental management systems or standards'"
                 flag="fatal">Element 'Name' MUST have value "Certificates by independent bodies about environmental management systems or standards".</assert>
         <assert id="EHF-ESPD-CT-C-5603"
                 test="normalize-space(cbc:Description) = 'Will the economic operator be able to produce certificates drawn up by independent bodies attesting that the economic operator complies with the required environmental management systems or standards?'"
                 flag="fatal">Element 'Description' MUST have value "Will the economic operator be able to produce certificates drawn up by independent bodies attesting that the economic operator complies with the required environmental management systems or standards?".</assert>
         <assert id="EHF-ESPD-CT-C-5604"
                 test="ccv:LegislationReference"
                 flag="fatal">Element 'LegislationReference' MUST be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '82a59ce2-9c59-4075-af08-843ad89a45ec'"
                 flag="fatal">Criterion '8ed65e48-fd0d-444f-97bd-4f58da632999' MUST have RequirementGroup '82a59ce2-9c59-4075-af08-843ad89a45ec' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-5622"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '9026e403-3eb6-4705-a9e9-e21a1efc867d'"
                 flag="fatal">Criterion '8ed65e48-fd0d-444f-97bd-4f58da632999' MUST have RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[text() = '8ed65e48-fd0d-444f-97bd-4f58da632999']]/ccv:LegislationReference">
         <assert id="EHF-ESPD-CT-C5611"
                 test="normalize-space(ccv-cbc:Title) = 'DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Title' MUST have value "DIRECTIVE 2014/24/EU OF THE EUROPEAN PARLIAMENT AND OF THE COUNCIL of 26 February 2014 on public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5612"
                 test="normalize-space(cbc:Description) = 'On public procurement and repealing Directive 2004/18/EC'"
                 flag="fatal">Element 'Description' MUST have value "On public procurement and repealing Directive 2004/18/EC".</assert>
         <assert id="EHF-ESPD-CT-C5613"
                 test="normalize-space(ccv-cbc:JurisdictionLevelCode) = 'EU_DIRECTIVE'"
                 flag="fatal">Element 'JurisdictionLevelCode' MUST have value "EU_DIRECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C5614"
                 test="normalize-space(ccv-cbc:Article) = '62(2)'"
                 flag="fatal">Element 'Article' MUST have value "62(2)".</assert>
         <assert id="EHF-ESPD-CT-C5615"
                 test="normalize-space(cbc:URI) = 'http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024'"
                 flag="fatal">Element 'URI' MUST have value "http://eur-lex.europa.eu/legal-content/EN/TXT/?uri=celex:32014L0024".</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '2043338f-a38a-490b-b3ec-2607cb25a017']]">
         <assert id="EHF-ESPD-CT-C-5701"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.OTHER.EO_DATA.SHELTERED_WORKSHOP'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.OTHER.EO_DATA.SHELTERED_WORKSHOP".</assert>
         <assert id="EHF-ESPD-CT-C-5702"
                 test="normalize-space(cbc:Name) = 'Procurement reserved'"
                 flag="fatal">Element 'Name' MUST have value "Procurement reserved".</assert>
         <assert id="EHF-ESPD-CT-C-5703"
                 test="normalize-space(cbc:Description) = 'Only in case the procurement is reserved: is the economic operator a sheltered workshop, a ''social business'' or will it provide for the performance of the contract in the context of sheltered employment programmes?'"
                 flag="fatal">Element 'Description' MUST have value "Only in case the procurement is reserved: is the economic operator a sheltered workshop, a 'social business' or will it provide for the performance of the contract in the context of sheltered employment programmes?".</assert>
         <assert id="EHF-ESPD-CT-C-5704"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '6febbe4a-e715-427c-a2b1-19cfabadaef0'"
                 flag="fatal">Criterion '2043338f-a38a-490b-b3ec-2607cb25a017' MUST have RequirementGroup '6febbe4a-e715-427c-a2b1-19cfabadaef0' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '9b19e869-6c89-4cc4-bd6c-ac9ca8602165']]">
         <assert id="EHF-ESPD-CT-C-5801"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.OTHER.EO_DATA.REGISTERED_IN_OFFICIAL_LIST'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.OTHER.EO_DATA.REGISTERED_IN_OFFICIAL_LIST".</assert>
         <assert id="EHF-ESPD-CT-C-5802"
                 test="normalize-space(cbc:Name) = 'EO registered'"
                 flag="fatal">Element 'Name' MUST have value "EO registered".</assert>
         <assert id="EHF-ESPD-CT-C-5803"
                 test="normalize-space(cbc:Description) = 'If applicable, is the economic operator registered on an official list of approved economic operators or does it have an equivalent certificate (e.g. under a national (pre)qualification system)?'"
                 flag="fatal">Element 'Description' MUST have value "If applicable, is the economic operator registered on an official list of approved economic operators or does it have an equivalent certificate (e.g. under a national (pre)qualification system)?".</assert>
         <assert id="EHF-ESPD-CT-C-5804"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5821"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '64162276-7014-408f-a9af-080426bfe1fd'"
                 flag="fatal">Criterion '9b19e869-6c89-4cc4-bd6c-ac9ca8602165' MUST have RequirementGroup '64162276-7014-408f-a9af-080426bfe1fd' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'ee51100f-8e3e-40c9-8f8b-57d5a15be1f2']]">
         <assert id="EHF-ESPD-CT-C-5901"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.OTHER.EO_DATA.TOGETHER_WITH_OTHERS'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.OTHER.EO_DATA.TOGETHER_WITH_OTHERS".</assert>
         <assert id="EHF-ESPD-CT-C-5902"
                 test="normalize-space(cbc:Name) = 'EO participating in procurement procedure'"
                 flag="fatal">Element 'Name' MUST have value "EO participating in procurement procedure".</assert>
         <assert id="EHF-ESPD-CT-C-5903"
                 test="normalize-space(cbc:Description) = 'Is the economic operator participating in the procurement procedure together with others?'"
                 flag="fatal">Element 'Description' MUST have value "Is the economic operator participating in the procurement procedure together with others?".</assert>
         <assert id="EHF-ESPD-CT-C-5904"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-5921"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd939f2c6-ba25-4dc4-889c-11d1853add19'"
                 flag="fatal">Criterion 'ee51100f-8e3e-40c9-8f8b-57d5a15be1f2' MUST have RequirementGroup 'd939f2c6-ba25-4dc4-889c-11d1853add19' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '0d62c6ed-f074-4fcf-8e9f-f691351d52ad']]">
         <assert id="EHF-ESPD-CT-C-6001"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.OTHER.EO_DATA.RELIES_ON_OTHER_CAPACITIES'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.OTHER.EO_DATA.RELIES_ON_OTHER_CAPACITIES".</assert>
         <assert id="EHF-ESPD-CT-C-6002"
                 test="normalize-space(cbc:Name) = 'EO relies capacities'"
                 flag="fatal">Element 'Name' MUST have value "EO relies capacities".</assert>
         <assert id="EHF-ESPD-CT-C-6003"
                 test="normalize-space(cbc:Description) = 'Does the economic operator rely on the capacities of other entities in order to meet the selection criteria set out under Part IV and the criteria and rules (if any) set out under Part V below?'"
                 flag="fatal">Element 'Description' MUST have value "Does the economic operator rely on the capacities of other entities in order to meet the selection criteria set out under Part IV and the criteria and rules (if any) set out under Part V below?".</assert>
         <assert id="EHF-ESPD-CT-C-6004"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-6021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'e688f7d6-dcef-4726-bc61-052e63ead60f'"
                 flag="fatal">Criterion '0d62c6ed-f074-4fcf-8e9f-f691351d52ad' MUST have RequirementGroup 'e688f7d6-dcef-4726-bc61-052e63ead60f' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '72c0c4b1-ca50-4667-9487-461f3eed4ed7']]">
         <assert id="EHF-ESPD-CT-C-6101"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.OTHER.EO_DATA.SUBCONTRACTS_WITH_THIRD_PARTIES'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.OTHER.EO_DATA.SUBCONTRACTS_WITH_THIRD_PARTIES".</assert>
         <assert id="EHF-ESPD-CT-C-6102"
                 test="normalize-space(cbc:Name) = 'Subcontracting third parties'"
                 flag="fatal">Element 'Name' MUST have value "Subcontracting third parties".</assert>
         <assert id="EHF-ESPD-CT-C-6103"
                 test="normalize-space(cbc:Description) = 'Does the economic operator intend to subcontract any share of the contract to third parties?'"
                 flag="fatal">Element 'Description' MUST have value "Does the economic operator intend to subcontract any share of the contract to third parties?".</assert>
         <assert id="EHF-ESPD-CT-C-6104"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-6121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd5fe5a71-7fd3-4910-b6f4-5cd2a4d23524'"
                 flag="fatal">Criterion '72c0c4b1-ca50-4667-9487-461f3eed4ed7' MUST have RequirementGroup 'd5fe5a71-7fd3-4910-b6f4-5cd2a4d23524' as child number 1.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '9c70375e-1264-407e-8b50-b9736bc08901']]">
         <assert id="EHF-ESPD-CT-C-6201"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.OTHER.EO_DATA.MEETS_THE_OBJECTIVE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.OTHER.EO_DATA.MEETS_THE_OBJECTIVE".</assert>
         <assert id="EHF-ESPD-CT-C-6202"
                 test="normalize-space(cbc:Name) = 'It meets the objective and non discriminatory criteria or rules to be applied in order to limit the number of candidates in the following way: In case certain certificates or other forms of documentary evidence are required, please indicate for each whether the economic operator has the required documents:'"
                 flag="fatal">Element 'Name' MUST have value "It meets the objective and non discriminatory criteria or rules to be applied in order to limit the number of candidates in the following way: In case certain certificates or other forms of documentary evidence are required, please indicate for each whether the economic operator has the required documents:".</assert>
         <assert id="EHF-ESPD-CT-C-6203"
                 test="normalize-space(cbc:Description) = 'If some of these certificates or forms of documentary evidence are available electronically, please indicate for each:'"
                 flag="fatal">Element 'Description' MUST have value "If some of these certificates or forms of documentary evidence are available electronically, please indicate for each:".</assert>
         <assert id="EHF-ESPD-CT-C-6204"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-6221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '3e5c2859-68a7-4312-92e4-01ae79c00cb8'"
                 flag="fatal">Criterion '9c70375e-1264-407e-8b50-b9736bc08901' MUST have RequirementGroup '3e5c2859-68a7-4312-92e4-01ae79c00cb8' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-6222"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = 'ab335516-73a4-41f7-977b-a98c13a51060'"
                 flag="fatal">Criterion '9c70375e-1264-407e-8b50-b9736bc08901' MUST have RequirementGroup 'ab335516-73a4-41f7-977b-a98c13a51060' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = 'aef56865-3cdc-42a8-87ed-7e5e93088279']]">
         <assert id="EHF-ESPD-CT-C-6301"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.NATIONAL.NO.ACCEPTED.FINE'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.NATIONAL.NO.ACCEPTED.FINE".</assert>
         <assert id="EHF-ESPD-CT-C-6302"
                 test="normalize-space(cbc:Name) = 'Accepted fine for criminal behaviour'"
                 flag="fatal">Element 'Name' MUST have value "Accepted fine for criminal behaviour".</assert>
         <assert id="EHF-ESPD-CT-C-6303"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein accepted a fine for the circumstances listed above, within the meaning of Regulations Regarding Public Procurement FOR-2016-08-12-974 § 24-2 (2) a-f?'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein accepted a fine for the circumstances listed above, within the meaning of Regulations Regarding Public Procurement FOR-2016-08-12-974 § 24-2 (2) a-f?".</assert>
         <assert id="EHF-ESPD-CT-C-6304"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-6321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '976b5acb-c00f-46ca-8f83-5ce6abfdfe43'"
                 flag="fatal">Criterion 'aef56865-3cdc-42a8-87ed-7e5e93088279' MUST have RequirementGroup '976b5acb-c00f-46ca-8f83-5ce6abfdfe43' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-6322"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion 'aef56865-3cdc-42a8-87ed-7e5e93088279' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:Criterion[cbc:ID[normalize-space(text()) = '588e9cbb-aaaf-48de-b5df-46254e5d2742']]">
         <assert id="EHF-ESPD-CT-C-6401"
                 test="normalize-space(cbc:TypeCode) = 'CRITERION.EXCLUSION.NATIONAL.GRAVE.MISCONDUCT'"
                 flag="fatal">Element 'TypeCode' MUST have value "CRITERION.EXCLUSION.NATIONAL.GRAVE.MISCONDUCT".</assert>
         <assert id="EHF-ESPD-CT-C-6402"
                 test="normalize-space(cbc:Name) = 'Grave misconduct'"
                 flag="fatal">Element 'Name' MUST have value "Grave misconduct".</assert>
         <assert id="EHF-ESPD-CT-C-6403"
                 test="normalize-space(cbc:Description) = 'Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein commited significant breaches of his professonial integrety, within the meaning of Regulations Regarding Public Procurement FOR-2016-08-12-974 § 24-2 (3) i?'"
                 flag="fatal">Element 'Description' MUST have value "Has the economic operator itself or any person who is a member of its administrative, management or supervisory body or has powers of representation, decision or control therein commited significant breaches of his professonial integrety, within the meaning of Regulations Regarding Public Procurement FOR-2016-08-12-974 § 24-2 (3) i?".</assert>
         <assert id="EHF-ESPD-CT-C-6404"
                 test="not(ccv:LegislationReference)"
                 flag="fatal">Element 'LegislationReference' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-C-6421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '976b5acb-c00f-46ca-8f83-5ce6abfdfe43'"
                 flag="fatal">Criterion '588e9cbb-aaaf-48de-b5df-46254e5d2742' MUST have RequirementGroup '976b5acb-c00f-46ca-8f83-5ce6abfdfe43' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-C-6422"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '7458d42a-e581-4640-9283-34ceb3ad4345'"
                 flag="fatal">Criterion '588e9cbb-aaaf-48de-b5df-46254e5d2742' MUST have RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '7c637c0c-7703-4389-ba52-02997a055bd7']]">
         <assert id="EHF-ESPD-CT-RG0101" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG0102"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG0103"
                 test="count(ccv:RequirementGroup) &gt;= 1"
                 flag="fatal">Requirement group MUST contain minimum 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG0111"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a'"
                 flag="fatal">RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' MUST have Requirement '974c8196-9d1c-419c-9ca9-45bb9f5fd59a' as child number 1.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = 'f5276600-a2b6-4ff6-a90e-b31fe19dae41'])"/>
         <assert id="EHF-ESPD-CT-RG0121" test="$count &gt; 0" flag="fatal">RequirementGroup '7c637c0c-7703-4389-ba52-02997a055bd7' MUST have minimum one RequirementGroup 'f5276600-a2b6-4ff6-a90e-b31fe19dae41' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'f3a6836d-2de2-4cd1-81ca-fb06178d05c5']]">
         <assert id="EHF-ESPD-CT-RG0201" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG0202"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG0203"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG0211"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15335c12-ad77-4728-b5ad-3c06a60d65a4'"
                 flag="fatal">RequirementGroup 'f3a6836d-2de2-4cd1-81ca-fb06178d05c5' MUST have Requirement '15335c12-ad77-4728-b5ad-3c06a60d65a4' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'f5276600-a2b6-4ff6-a90e-b31fe19dae41']]">
         <assert id="EHF-ESPD-CT-RG0301"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG0302"
                 test="count(ccv:Requirement) = 4"
                 flag="fatal">Requirement group MUST contain 4 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG0303"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG0311"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'ecf40999-7b64-4e10-b960-7f8ff8674cf6'"
                 flag="fatal">RequirementGroup 'f5276600-a2b6-4ff6-a90e-b31fe19dae41' MUST have Requirement 'ecf40999-7b64-4e10-b960-7f8ff8674cf6' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG0312"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '7d35fb7c-da5b-4830-b598-4f347a04dceb'"
                 flag="fatal">RequirementGroup 'f5276600-a2b6-4ff6-a90e-b31fe19dae41' MUST have Requirement '7d35fb7c-da5b-4830-b598-4f347a04dceb' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG0313"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = 'c5012430-14da-454c-9d01-34cedc6a7ded'"
                 flag="fatal">RequirementGroup 'f5276600-a2b6-4ff6-a90e-b31fe19dae41' MUST have Requirement 'c5012430-14da-454c-9d01-34cedc6a7ded' as child number 3.</assert>
         <assert id="EHF-ESPD-CT-RG0314"
                 test="ccv:Requirement[4] and normalize-space(ccv:Requirement[4][current()]/cbc:ID/text()) = '9ca9096f-edd2-4f19-b6b1-b55c83a2d5c8'"
                 flag="fatal">RequirementGroup 'f5276600-a2b6-4ff6-a90e-b31fe19dae41' MUST have Requirement '9ca9096f-edd2-4f19-b6b1-b55c83a2d5c8' as child number 4.</assert>
         <assert id="EHF-ESPD-CT-RG0321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '5f9f09f7-f701-432c-9fdc-c22c124a74c9'"
                 flag="fatal">RequirementGroup 'f5276600-a2b6-4ff6-a90e-b31fe19dae41' MUST have RequirementGroup '5f9f09f7-f701-432c-9fdc-c22c124a74c9' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '5f9f09f7-f701-432c-9fdc-c22c124a74c9']]">
         <assert id="EHF-ESPD-CT-RG0401" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG0402"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG0403"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG0411"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '20c5361b-7599-4ee6-b030-7f8323174d1e'"
                 flag="fatal">RequirementGroup '5f9f09f7-f701-432c-9fdc-c22c124a74c9' MUST have Requirement '20c5361b-7599-4ee6-b030-7f8323174d1e' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG0421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '74e6c7b4-757b-4b40-ada6-fad6a997c310'"
                 flag="fatal">RequirementGroup '5f9f09f7-f701-432c-9fdc-c22c124a74c9' MUST have RequirementGroup '74e6c7b4-757b-4b40-ada6-fad6a997c310' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '74e6c7b4-757b-4b40-ada6-fad6a997c310']]">
         <assert id="EHF-ESPD-CT-RG0501"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG0502"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG0503"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG0511"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '7b07904f-e080-401a-a3a1-9a3efeeda54b'"
                 flag="fatal">RequirementGroup '74e6c7b4-757b-4b40-ada6-fad6a997c310' MUST have Requirement '7b07904f-e080-401a-a3a1-9a3efeeda54b' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '7458d42a-e581-4640-9283-34ceb3ad4345']]">
         <assert id="EHF-ESPD-CT-RG0601" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG0602"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG0603"
                 test="count(ccv:RequirementGroup) &gt;= 1"
                 flag="fatal">Requirement group MUST contain minimum 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG0611"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'c1347b74-1872-4060-a6db-f4044edcd7c4'"
                 flag="fatal">RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' MUST have Requirement 'c1347b74-1872-4060-a6db-f4044edcd7c4' as child number 1.</assert>
         <let name="count"
              value="count(ccv:RequirementGroup[cbc:ID[normalize-space(text())] = '41dd2e9b-1bfd-44c7-93ee-56bd74a4334b'])"/>
         <assert id="EHF-ESPD-CT-RG0621" test="$count &gt; 0" flag="fatal">RequirementGroup '7458d42a-e581-4640-9283-34ceb3ad4345' MUST have minimum one RequirementGroup '41dd2e9b-1bfd-44c7-93ee-56bd74a4334b' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '41dd2e9b-1bfd-44c7-93ee-56bd74a4334b']]">
         <assert id="EHF-ESPD-CT-RG0701"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG0702"
                 test="count(ccv:Requirement) = 3"
                 flag="fatal">Requirement group MUST contain 3 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG0703"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG0711"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'f4313bb6-21b6-499e-bdff-debe10e11d2c'"
                 flag="fatal">RequirementGroup '41dd2e9b-1bfd-44c7-93ee-56bd74a4334b' MUST have Requirement 'f4313bb6-21b6-499e-bdff-debe10e11d2c' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG0712"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '1f1cd18e-3e01-4ca2-af4c-e2981924ba8d'"
                 flag="fatal">RequirementGroup '41dd2e9b-1bfd-44c7-93ee-56bd74a4334b' MUST have Requirement '1f1cd18e-3e01-4ca2-af4c-e2981924ba8d' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG0713"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = 'c3ccfa31-0c5e-4e3a-a3fd-db9fb83d78d4'"
                 flag="fatal">RequirementGroup '41dd2e9b-1bfd-44c7-93ee-56bd74a4334b' MUST have Requirement 'c3ccfa31-0c5e-4e3a-a3fd-db9fb83d78d4' as child number 3.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '098fd3cc-466e-4233-af1a-affe09471bce']]">
         <assert id="EHF-ESPD-CT-RG0801" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG0802"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG0803"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG0811"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a'"
                 flag="fatal">RequirementGroup '098fd3cc-466e-4233-af1a-affe09471bce' MUST have Requirement '974c8196-9d1c-419c-9ca9-45bb9f5fd59a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG0821"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'f8499787-f9f8-4355-95e2-9784426f4d7b'"
                 flag="fatal">RequirementGroup '098fd3cc-466e-4233-af1a-affe09471bce' MUST have RequirementGroup 'f8499787-f9f8-4355-95e2-9784426f4d7b' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'f8499787-f9f8-4355-95e2-9784426f4d7b']]">
         <assert id="EHF-ESPD-CT-RG0901"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG0902"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG0903"
                 test="count(ccv:RequirementGroup) = 3"
                 flag="fatal">Requirement group MUST contain 3 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG0911"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '6c87d3d4-e8eb-4253-b385-6373020ab886'"
                 flag="fatal">RequirementGroup 'f8499787-f9f8-4355-95e2-9784426f4d7b' MUST have Requirement '6c87d3d4-e8eb-4253-b385-6373020ab886' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG0912"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '9052cc59-cfe5-41c6-a314-02a7f378ffe8'"
                 flag="fatal">RequirementGroup 'f8499787-f9f8-4355-95e2-9784426f4d7b' MUST have Requirement '9052cc59-cfe5-41c6-a314-02a7f378ffe8' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG0921"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7c2aec9f-4876-4c33-89e6-2ab6d6cf5d02'"
                 flag="fatal">RequirementGroup 'f8499787-f9f8-4355-95e2-9784426f4d7b' MUST have RequirementGroup '7c2aec9f-4876-4c33-89e6-2ab6d6cf5d02' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG0922"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = 'c882afa4-6971-4b00-8970-0c283eb122cc'"
                 flag="fatal">RequirementGroup 'f8499787-f9f8-4355-95e2-9784426f4d7b' MUST have RequirementGroup 'c882afa4-6971-4b00-8970-0c283eb122cc' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG0923"
                 test="ccv:RequirementGroup[3] and normalize-space(ccv:RequirementGroup[3][current()]/cbc:ID/text()) = 'fc57e473-d63e-4a04-b589-dcf81cab8052'"
                 flag="fatal">RequirementGroup 'f8499787-f9f8-4355-95e2-9784426f4d7b' MUST have RequirementGroup 'fc57e473-d63e-4a04-b589-dcf81cab8052' as child number 3.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '7c2aec9f-4876-4c33-89e6-2ab6d6cf5d02']]">
         <assert id="EHF-ESPD-CT-RG1001" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG1002"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1003"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG1011"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '9b4497e6-a166-46f9-8581-7fc39ff975c4'"
                 flag="fatal">RequirementGroup '7c2aec9f-4876-4c33-89e6-2ab6d6cf5d02' MUST have Requirement '9b4497e6-a166-46f9-8581-7fc39ff975c4' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '3cb7abf1-662a-4756-b61c-7bc716c1fafc'"
                 flag="fatal">RequirementGroup '7c2aec9f-4876-4c33-89e6-2ab6d6cf5d02' MUST have RequirementGroup '3cb7abf1-662a-4756-b61c-7bc716c1fafc' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '3cb7abf1-662a-4756-b61c-7bc716c1fafc']]">
         <assert id="EHF-ESPD-CT-RG1101"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG1102"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1103"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG1111"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '201f11c3-1fa2-4464-acc0-f021266fd881'"
                 flag="fatal">RequirementGroup '3cb7abf1-662a-4756-b61c-7bc716c1fafc' MUST have Requirement '201f11c3-1fa2-4464-acc0-f021266fd881' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'c882afa4-6971-4b00-8970-0c283eb122cc']]">
         <assert id="EHF-ESPD-CT-RG1201" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG1202"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1203"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG1211"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '08b0c984-c5e6-4143-8493-868c39745637'"
                 flag="fatal">RequirementGroup 'c882afa4-6971-4b00-8970-0c283eb122cc' MUST have Requirement '08b0c984-c5e6-4143-8493-868c39745637' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '815422d6-f8a1-418a-8bf0-3524f7c8f721'"
                 flag="fatal">RequirementGroup 'c882afa4-6971-4b00-8970-0c283eb122cc' MUST have RequirementGroup '815422d6-f8a1-418a-8bf0-3524f7c8f721' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '815422d6-f8a1-418a-8bf0-3524f7c8f721']]">
         <assert id="EHF-ESPD-CT-RG1301"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG1302"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG1303"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG1311"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'ecf40999-7b64-4e10-b960-7f8ff8674cf6'"
                 flag="fatal">RequirementGroup '815422d6-f8a1-418a-8bf0-3524f7c8f721' MUST have Requirement 'ecf40999-7b64-4e10-b960-7f8ff8674cf6' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1312"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '9ca9096f-edd2-4f19-b6b1-b55c83a2d5c8'"
                 flag="fatal">RequirementGroup '815422d6-f8a1-418a-8bf0-3524f7c8f721' MUST have Requirement '9ca9096f-edd2-4f19-b6b1-b55c83a2d5c8' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'fc57e473-d63e-4a04-b589-dcf81cab8052']]">
         <assert id="EHF-ESPD-CT-RG1401" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG1402"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1403"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG1411"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '70f8697b-8953-411a-a489-4ff62e5250d2'"
                 flag="fatal">RequirementGroup 'fc57e473-d63e-4a04-b589-dcf81cab8052' MUST have Requirement '70f8697b-8953-411a-a489-4ff62e5250d2' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '6c3609e1-9add-4fa9-9409-62ce72ae4548'"
                 flag="fatal">RequirementGroup 'fc57e473-d63e-4a04-b589-dcf81cab8052' MUST have RequirementGroup '6c3609e1-9add-4fa9-9409-62ce72ae4548' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '6c3609e1-9add-4fa9-9409-62ce72ae4548']]">
         <assert id="EHF-ESPD-CT-RG1501"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG1502"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1503"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG1511"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '55905dd0-38f0-4f93-8c74-5ae05a21afc5'"
                 flag="fatal">RequirementGroup '6c3609e1-9add-4fa9-9409-62ce72ae4548' MUST have Requirement '55905dd0-38f0-4f93-8c74-5ae05a21afc5' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '976b5acb-c00f-46ca-8f83-5ce6abfdfe43']]">
         <assert id="EHF-ESPD-CT-RG1601" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG1602"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1603"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG1611"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a'"
                 flag="fatal">RequirementGroup '976b5acb-c00f-46ca-8f83-5ce6abfdfe43' MUST have Requirement '974c8196-9d1c-419c-9ca9-45bb9f5fd59a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '64a2102c-4af1-4ecb-97b3-0c41907ec0f6'"
                 flag="fatal">RequirementGroup '976b5acb-c00f-46ca-8f83-5ce6abfdfe43' MUST have RequirementGroup '64a2102c-4af1-4ecb-97b3-0c41907ec0f6' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '64a2102c-4af1-4ecb-97b3-0c41907ec0f6']]">
         <assert id="EHF-ESPD-CT-RG1701"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG1702"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1703"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG1711"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'e098da8e-4717-4500-965f-f882d5b4e1ad'"
                 flag="fatal">RequirementGroup '64a2102c-4af1-4ecb-97b3-0c41907ec0f6' MUST have Requirement 'e098da8e-4717-4500-965f-f882d5b4e1ad' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '5f9f09f7-f701-432c-9fdc-c22c124a74c9'"
                 flag="fatal">RequirementGroup '64a2102c-4af1-4ecb-97b3-0c41907ec0f6' MUST have RequirementGroup '5f9f09f7-f701-432c-9fdc-c22c124a74c9' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'd91c11a1-f19e-4b83-8ade-c4be2bf00555']]">
         <assert id="EHF-ESPD-CT-RG1801" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG1802"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG1803"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG1811"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a'"
                 flag="fatal">RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' MUST have Requirement '974c8196-9d1c-419c-9ca9-45bb9f5fd59a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1821"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'aeef523b-c8fc-4dba-9c34-03e34812567b'"
                 flag="fatal">RequirementGroup 'd91c11a1-f19e-4b83-8ade-c4be2bf00555' MUST have RequirementGroup 'aeef523b-c8fc-4dba-9c34-03e34812567b' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'aeef523b-c8fc-4dba-9c34-03e34812567b']]">
         <assert id="EHF-ESPD-CT-RG1901"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG1902"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG1903"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG1911"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'e098da8e-4717-4500-965f-f882d5b4e1ad'"
                 flag="fatal">RequirementGroup 'aeef523b-c8fc-4dba-9c34-03e34812567b' MUST have Requirement 'e098da8e-4717-4500-965f-f882d5b4e1ad' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG1912"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '4e3f468a-86c4-4c99-bd15-c8b221229348'"
                 flag="fatal">RequirementGroup 'aeef523b-c8fc-4dba-9c34-03e34812567b' MUST have Requirement '4e3f468a-86c4-4c99-bd15-c8b221229348' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8']]">
         <assert id="EHF-ESPD-CT-RG2001" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG2002"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2003"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG2011"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a'"
                 flag="fatal">RequirementGroup '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8' MUST have Requirement '974c8196-9d1c-419c-9ca9-45bb9f5fd59a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG2021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '2cbcf978-765c-40aa-996b-b1d082485cef'"
                 flag="fatal">RequirementGroup '67362ec7-cec3-4cb8-a38e-5d7a2a31e6d8' MUST have RequirementGroup '2cbcf978-765c-40aa-996b-b1d082485cef' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '2cbcf978-765c-40aa-996b-b1d082485cef']]">
         <assert id="EHF-ESPD-CT-RG2101"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG2102"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2103"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG2111"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'e098da8e-4717-4500-965f-f882d5b4e1ad'"
                 flag="fatal">RequirementGroup '2cbcf978-765c-40aa-996b-b1d082485cef' MUST have Requirement 'e098da8e-4717-4500-965f-f882d5b4e1ad' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG2121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '5f9f09f7-f701-432c-9fdc-c22c124a74c9'"
                 flag="fatal">RequirementGroup '2cbcf978-765c-40aa-996b-b1d082485cef' MUST have RequirementGroup '5f9f09f7-f701-432c-9fdc-c22c124a74c9' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '30450436-f559-4dfa-98ba-f0842ed9d2a0']]">
         <assert id="EHF-ESPD-CT-RG2201" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG2202"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2203"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG2211"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a'"
                 flag="fatal">RequirementGroup '30450436-f559-4dfa-98ba-f0842ed9d2a0' MUST have Requirement '974c8196-9d1c-419c-9ca9-45bb9f5fd59a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG2221"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '73f0fe4c-4ed9-4343-8096-d898cf200146'"
                 flag="fatal">RequirementGroup '30450436-f559-4dfa-98ba-f0842ed9d2a0' MUST have RequirementGroup '73f0fe4c-4ed9-4343-8096-d898cf200146' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '73f0fe4c-4ed9-4343-8096-d898cf200146']]">
         <assert id="EHF-ESPD-CT-RG2301"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG2302"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2303"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG2311"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'e098da8e-4717-4500-965f-f882d5b4e1ad'"
                 flag="fatal">RequirementGroup '73f0fe4c-4ed9-4343-8096-d898cf200146' MUST have Requirement 'e098da8e-4717-4500-965f-f882d5b4e1ad' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '77ae3f29-7c5f-4afa-af97-24afec48c5bf']]">
         <assert id="EHF-ESPD-CT-RG2401" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG2402"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2403"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG2411"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a'"
                 flag="fatal">RequirementGroup '77ae3f29-7c5f-4afa-af97-24afec48c5bf' MUST have Requirement '974c8196-9d1c-419c-9ca9-45bb9f5fd59a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG2421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '73f0fe4c-4ed9-4343-8096-d898cf200146'"
                 flag="fatal">RequirementGroup '77ae3f29-7c5f-4afa-af97-24afec48c5bf' MUST have RequirementGroup '73f0fe4c-4ed9-4343-8096-d898cf200146' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '1768de86-a6c8-48e4-bd8e-de2f2f7424d0']]">
         <assert id="EHF-ESPD-CT-RG2501" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG2502"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2503"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG2511"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15335c12-ad77-4728-b5ad-3c06a60d65a4'"
                 flag="fatal">RequirementGroup '1768de86-a6c8-48e4-bd8e-de2f2f7424d0' MUST have Requirement '15335c12-ad77-4728-b5ad-3c06a60d65a4' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '9026e403-3eb6-4705-a9e9-e21a1efc867d']]">
         <assert id="EHF-ESPD-CT-RG2601" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG2602"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2603"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG2611"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '9dae5670-cb75-4c97-901b-96ddac5a633a'"
                 flag="fatal">RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' MUST have Requirement '9dae5670-cb75-4c97-901b-96ddac5a633a' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG2621"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '0a166f0a-0c5f-42b0-81e9-0fc9fa598a48'"
                 flag="fatal">RequirementGroup '9026e403-3eb6-4705-a9e9-e21a1efc867d' MUST have RequirementGroup '0a166f0a-0c5f-42b0-81e9-0fc9fa598a48' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '0a166f0a-0c5f-42b0-81e9-0fc9fa598a48']]">
         <assert id="EHF-ESPD-CT-RG2701"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG2702"
                 test="count(ccv:Requirement) = 3"
                 flag="fatal">Requirement group MUST contain 3 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG2703"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG2711"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '03bb1954-13ae-47d8-8ef8-b7fe0f22d700'"
                 flag="fatal">RequirementGroup '0a166f0a-0c5f-42b0-81e9-0fc9fa598a48' MUST have Requirement '03bb1954-13ae-47d8-8ef8-b7fe0f22d700' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG2712"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = 'e2d863a0-60cb-4e58-8c14-4c1595af48b7'"
                 flag="fatal">RequirementGroup '0a166f0a-0c5f-42b0-81e9-0fc9fa598a48' MUST have Requirement 'e2d863a0-60cb-4e58-8c14-4c1595af48b7' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG2713"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = '5cbf74d9-a1e2-4233-921d-8b298842ee7d'"
                 flag="fatal">RequirementGroup '0a166f0a-0c5f-42b0-81e9-0fc9fa598a48' MUST have Requirement '5cbf74d9-a1e2-4233-921d-8b298842ee7d' as child number 3.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'a109e144-f65e-469d-bcda-220f1af34b6c']]">
         <assert id="EHF-ESPD-CT-RG2801" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG2802"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2803"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG2811"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15335c12-ad77-4728-b5ad-3c06a60d65a4'"
                 flag="fatal">RequirementGroup 'a109e144-f65e-469d-bcda-220f1af34b6c' MUST have Requirement '15335c12-ad77-4728-b5ad-3c06a60d65a4' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG2821"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '7696fb3f-9722-43b8-9b91-ad59bb4b8ad2'"
                 flag="fatal">RequirementGroup 'a109e144-f65e-469d-bcda-220f1af34b6c' MUST have RequirementGroup '7696fb3f-9722-43b8-9b91-ad59bb4b8ad2' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '7696fb3f-9722-43b8-9b91-ad59bb4b8ad2']]">
         <assert id="EHF-ESPD-CT-RG2901"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG2902"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG2903"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG2911"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '51391308-0bf6-423c-95e2-d5a54aa31fb8'"
                 flag="fatal">RequirementGroup '7696fb3f-9722-43b8-9b91-ad59bb4b8ad2' MUST have Requirement '51391308-0bf6-423c-95e2-d5a54aa31fb8' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16']]">
         <assert id="EHF-ESPD-CT-RG3001" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3002"
                 test="count(ccv:Requirement) = 3"
                 flag="fatal">Requirement group MUST contain 3 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG3003"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3011"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '42ec8116-31a7-4118-8612-5b04f5c8bde7'"
                 flag="fatal">RequirementGroup 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16' MUST have Requirement '42ec8116-31a7-4118-8612-5b04f5c8bde7' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG3012"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '3641b897-f9f0-4d90-909a-b6d4c4b1d645'"
                 flag="fatal">RequirementGroup 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16' MUST have Requirement '3641b897-f9f0-4d90-909a-b6d4c4b1d645' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG3013"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = '42db0eaa-d2dd-48cb-83ac-38d73cab9b50'"
                 flag="fatal">RequirementGroup 'c0cd9c1c-e90a-4ff9-bce3-ac0fe31abf16' MUST have Requirement '42db0eaa-d2dd-48cb-83ac-38d73cab9b50' as child number 3.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'e1886054-ada4-473c-9afc-2fde82c24cf4']]">
         <assert id="EHF-ESPD-CT-RG3101" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3102"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG3103"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3111"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'b98ffd05-6572-4b07-a521-693a1754ed46'"
                 flag="fatal">RequirementGroup 'e1886054-ada4-473c-9afc-2fde82c24cf4' MUST have Requirement 'b98ffd05-6572-4b07-a521-693a1754ed46' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG3112"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '217637ba-6bdb-4c73-a38f-27fe0e71d9be'"
                 flag="fatal">RequirementGroup 'e1886054-ada4-473c-9afc-2fde82c24cf4' MUST have Requirement '217637ba-6bdb-4c73-a38f-27fe0e71d9be' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'e9aa7763-c167-4352-8060-1a3d7d3e2662']]">
         <assert id="EHF-ESPD-CT-RG3201" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3202"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG3203"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3211"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'a18b2c98-8552-45ca-9751-d4c94c05847a'"
                 flag="fatal">RequirementGroup 'e9aa7763-c167-4352-8060-1a3d7d3e2662' MUST have Requirement 'a18b2c98-8552-45ca-9751-d4c94c05847a' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '096686e1-82ca-4de0-8710-d74d90da0f0c']]">
         <assert id="EHF-ESPD-CT-RG3301" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3302"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG3303"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3311"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'ab05ff3b-f3e1-4441-9b43-ee9912e29e92'"
                 flag="fatal">RequirementGroup '096686e1-82ca-4de0-8710-d74d90da0f0c' MUST have Requirement 'ab05ff3b-f3e1-4441-9b43-ee9912e29e92' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG3312"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '5461b973-7067-457e-93cc-8338da2c3eef'"
                 flag="fatal">RequirementGroup '096686e1-82ca-4de0-8710-d74d90da0f0c' MUST have Requirement '5461b973-7067-457e-93cc-8338da2c3eef' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '42dc8062-974d-4201-91ba-7f2ea90338fd']]">
         <assert id="EHF-ESPD-CT-RG3401" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3402"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG3403"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3411"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '42db0eaa-d2dd-48cb-83ac-38d73cab9b50'"
                 flag="fatal">RequirementGroup '42dc8062-974d-4201-91ba-7f2ea90338fd' MUST have Requirement '42db0eaa-d2dd-48cb-83ac-38d73cab9b50' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '96f00020-0a25-402e-b850-2378e83b5695']]">
         <assert id="EHF-ESPD-CT-RG3501" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3502"
                 test="count(ccv:Requirement) = 5"
                 flag="fatal">Requirement group MUST contain 5 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG3503"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3511"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'ab05ff3b-f3e1-4441-9b43-ee9912e29e92'"
                 flag="fatal">RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' MUST have Requirement 'ab05ff3b-f3e1-4441-9b43-ee9912e29e92' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG3512"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '42db0eaa-d2dd-48cb-83ac-38d73cab9b50'"
                 flag="fatal">RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' MUST have Requirement '42db0eaa-d2dd-48cb-83ac-38d73cab9b50' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG3513"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = '42ec8116-31a7-4118-8612-5b04f5c8bde7'"
                 flag="fatal">RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' MUST have Requirement '42ec8116-31a7-4118-8612-5b04f5c8bde7' as child number 3.</assert>
         <assert id="EHF-ESPD-CT-RG3514"
                 test="ccv:Requirement[4] and normalize-space(ccv:Requirement[4][current()]/cbc:ID/text()) = '3641b897-f9f0-4d90-909a-b6d4c4b1d645'"
                 flag="fatal">RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' MUST have Requirement '3641b897-f9f0-4d90-909a-b6d4c4b1d645' as child number 4.</assert>
         <assert id="EHF-ESPD-CT-RG3515"
                 test="ccv:Requirement[5] and normalize-space(ccv:Requirement[5][current()]/cbc:ID/text()) = 'a92536ab-6783-40bb-a037-5d31f421fd85'"
                 flag="fatal">RequirementGroup '96f00020-0a25-402e-b850-2378e83b5695' MUST have Requirement 'a92536ab-6783-40bb-a037-5d31f421fd85' as child number 5.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '488ca189-bcdb-4bf4-80c7-3ad507fd89fb']]">
         <assert id="EHF-ESPD-CT-RG3601" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3602"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG3603"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3611"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '51391308-0bf6-423c-95e2-d5a54aa31fb8'"
                 flag="fatal">RequirementGroup '488ca189-bcdb-4bf4-80c7-3ad507fd89fb' MUST have Requirement '51391308-0bf6-423c-95e2-d5a54aa31fb8' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'd7721546-9106-43a7-8d31-2fe08a862b00']]">
         <assert id="EHF-ESPD-CT-RG3701" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3702"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG3703"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3711"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '23a27c0e-c4f7-42cd-b0fd-a7cedfbf77a7'"
                 flag="fatal">RequirementGroup 'd7721546-9106-43a7-8d31-2fe08a862b00' MUST have Requirement '23a27c0e-c4f7-42cd-b0fd-a7cedfbf77a7' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '96defecc-7d32-4957-82e9-aad5f3c5b736']]">
         <assert id="EHF-ESPD-CT-RG3801" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3802"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG3803"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3811"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '5aacceb3-280e-42f1-b2da-3d8ac7877fe9'"
                 flag="fatal">RequirementGroup '96defecc-7d32-4957-82e9-aad5f3c5b736' MUST have Requirement '5aacceb3-280e-42f1-b2da-3d8ac7877fe9' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG3812"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '42037f41-53af-44df-b6b8-2395cee98087'"
                 flag="fatal">RequirementGroup '96defecc-7d32-4957-82e9-aad5f3c5b736' MUST have Requirement '42037f41-53af-44df-b6b8-2395cee98087' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '575f7550-8a2d-4bad-b9d8-be07ab570076']]">
         <assert id="EHF-ESPD-CT-RG3901" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG3902"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG3903"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG3911"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15778db8-0d84-42ba-931b-774c1b3d3f9f'"
                 flag="fatal">RequirementGroup '575f7550-8a2d-4bad-b9d8-be07ab570076' MUST have Requirement '15778db8-0d84-42ba-931b-774c1b3d3f9f' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'cb73544d-e8bb-4cc6-819b-b8e04f1e240e']]">
         <assert id="EHF-ESPD-CT-RG4001" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG4002"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4003"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG4011"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15335c12-ad77-4728-b5ad-3c06a60d65a4'"
                 flag="fatal">RequirementGroup 'cb73544d-e8bb-4cc6-819b-b8e04f1e240e' MUST have Requirement '15335c12-ad77-4728-b5ad-3c06a60d65a4' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '4887c3d7-05fc-4e3e-b066-f338910f0c4c']]">
         <assert id="EHF-ESPD-CT-RG4101" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG4102"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4103"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG4111"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15335c12-ad77-4728-b5ad-3c06a60d65a4'"
                 flag="fatal">RequirementGroup '4887c3d7-05fc-4e3e-b066-f338910f0c4c' MUST have Requirement '15335c12-ad77-4728-b5ad-3c06a60d65a4' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG4121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '83f2f79e-0455-4918-89ff-d7829e8bf758'"
                 flag="fatal">RequirementGroup '4887c3d7-05fc-4e3e-b066-f338910f0c4c' MUST have RequirementGroup '83f2f79e-0455-4918-89ff-d7829e8bf758' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '83f2f79e-0455-4918-89ff-d7829e8bf758']]">
         <assert id="EHF-ESPD-CT-RG4201"
                 test="@pi = 'GROUP_FULFILLED.ON_FALSE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_FALSE".</assert>
         <assert id="EHF-ESPD-CT-RG4202"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4203"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG4211"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'b9dec4cb-2f6f-47d7-a023-e9099b19b338'"
                 flag="fatal">RequirementGroup '83f2f79e-0455-4918-89ff-d7829e8bf758' MUST have Requirement 'b9dec4cb-2f6f-47d7-a023-e9099b19b338' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '0e88f63c-5642-4a17-833b-ae5800e1750a']]">
         <assert id="EHF-ESPD-CT-RG4301" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG4302"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4303"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG4311"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15335c12-ad77-4728-b5ad-3c06a60d65a4'"
                 flag="fatal">RequirementGroup '0e88f63c-5642-4a17-833b-ae5800e1750a' MUST have Requirement '15335c12-ad77-4728-b5ad-3c06a60d65a4' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG4321"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '76c7cf31-be3a-4a7e-8c35-a65ae60cd674'"
                 flag="fatal">RequirementGroup '0e88f63c-5642-4a17-833b-ae5800e1750a' MUST have RequirementGroup '76c7cf31-be3a-4a7e-8c35-a65ae60cd674' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '76c7cf31-be3a-4a7e-8c35-a65ae60cd674']]">
         <assert id="EHF-ESPD-CT-RG4401"
                 test="@pi = 'GROUP_FULFILLED.ON_FALSE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_FALSE".</assert>
         <assert id="EHF-ESPD-CT-RG4402"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4403"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG4411"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '8c5d1e13-54f7-4895-a65c-b8e09253130c'"
                 flag="fatal">RequirementGroup '76c7cf31-be3a-4a7e-8c35-a65ae60cd674' MUST have Requirement '8c5d1e13-54f7-4895-a65c-b8e09253130c' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '82a59ce2-9c59-4075-af08-843ad89a45ec']]">
         <assert id="EHF-ESPD-CT-RG4501" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG4502"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4503"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG4511"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '15335c12-ad77-4728-b5ad-3c06a60d65a4'"
                 flag="fatal">RequirementGroup '82a59ce2-9c59-4075-af08-843ad89a45ec' MUST have Requirement '15335c12-ad77-4728-b5ad-3c06a60d65a4' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG4521"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'd664788a-df88-49a0-9dfa-2dd217355724'"
                 flag="fatal">RequirementGroup '82a59ce2-9c59-4075-af08-843ad89a45ec' MUST have RequirementGroup 'd664788a-df88-49a0-9dfa-2dd217355724' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'd664788a-df88-49a0-9dfa-2dd217355724']]">
         <assert id="EHF-ESPD-CT-RG4601"
                 test="@pi = 'GROUP_FULFILLED.ON_FALSE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_FALSE".</assert>
         <assert id="EHF-ESPD-CT-RG4602"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4603"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG4611"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'b0aace10-fd73-46d1-ae78-289ee5cd42ca'"
                 flag="fatal">RequirementGroup 'd664788a-df88-49a0-9dfa-2dd217355724' MUST have Requirement 'b0aace10-fd73-46d1-ae78-289ee5cd42ca' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '6febbe4a-e715-427c-a2b1-19cfabadaef0']]">
         <assert id="EHF-ESPD-CT-RG4701" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG4702"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG4703"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG4711"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '7f18c64e-ae09-4646-9400-f3666d50af51'"
                 flag="fatal">RequirementGroup '6febbe4a-e715-427c-a2b1-19cfabadaef0' MUST have Requirement '7f18c64e-ae09-4646-9400-f3666d50af51' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG4721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'a5e33369-e2b5-45f7-9969-ddb1c3ae17c8'"
                 flag="fatal">RequirementGroup '6febbe4a-e715-427c-a2b1-19cfabadaef0' MUST have RequirementGroup 'a5e33369-e2b5-45f7-9969-ddb1c3ae17c8' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'a5e33369-e2b5-45f7-9969-ddb1c3ae17c8']]">
         <assert id="EHF-ESPD-CT-RG4801"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG4802"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG4803"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG4811"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '4e552658-d532-4770-943b-b90efcc9788d'"
                 flag="fatal">RequirementGroup 'a5e33369-e2b5-45f7-9969-ddb1c3ae17c8' MUST have Requirement '4e552658-d532-4770-943b-b90efcc9788d' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG4812"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = 'e01d0929-c7a9-455a-aaf9-e1f7cd966336'"
                 flag="fatal">RequirementGroup 'a5e33369-e2b5-45f7-9969-ddb1c3ae17c8' MUST have Requirement 'e01d0929-c7a9-455a-aaf9-e1f7cd966336' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '64162276-7014-408f-a9af-080426bfe1fd']]">
         <assert id="EHF-ESPD-CT-RG4901" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG4902"
                 test="count(ccv:Requirement) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG4903"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG4921"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'ecb5127b-9018-4fb8-8327-a6a7a2c73195'"
                 flag="fatal">RequirementGroup '64162276-7014-408f-a9af-080426bfe1fd' MUST have RequirementGroup 'ecb5127b-9018-4fb8-8327-a6a7a2c73195' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'ecb5127b-9018-4fb8-8327-a6a7a2c73195']]">
         <assert id="EHF-ESPD-CT-RG5001"
                 test="@pi = 'GROUP_FULFILLED.ON_FALSE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_FALSE".</assert>
         <assert id="EHF-ESPD-CT-RG5002"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG5003"
                 test="count(ccv:RequirementGroup) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG5011"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '7f18c64e-ae09-4646-9400-f3666d50af51'"
                 flag="fatal">RequirementGroup 'ecb5127b-9018-4fb8-8327-a6a7a2c73195' MUST have Requirement '7f18c64e-ae09-4646-9400-f3666d50af51' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5021"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'dc4acf0c-c761-40d0-b031-4ee1f224be5c'"
                 flag="fatal">RequirementGroup 'ecb5127b-9018-4fb8-8327-a6a7a2c73195' MUST have RequirementGroup 'dc4acf0c-c761-40d0-b031-4ee1f224be5c' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5022"
                 test="ccv:RequirementGroup[2] and normalize-space(ccv:RequirementGroup[2][current()]/cbc:ID/text()) = '59e6f3ef-15cd-4e21-82ac-ea497ccd44e2'"
                 flag="fatal">RequirementGroup 'ecb5127b-9018-4fb8-8327-a6a7a2c73195' MUST have RequirementGroup '59e6f3ef-15cd-4e21-82ac-ea497ccd44e2' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'dc4acf0c-c761-40d0-b031-4ee1f224be5c']]">
         <assert id="EHF-ESPD-CT-RG5101"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG5102"
                 test="count(ccv:Requirement) = 3"
                 flag="fatal">Requirement group MUST contain 3 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG5103"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG5111"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '30064ad3-fc11-4579-8528-fdd0b9a5ba75'"
                 flag="fatal">RequirementGroup 'dc4acf0c-c761-40d0-b031-4ee1f224be5c' MUST have Requirement '30064ad3-fc11-4579-8528-fdd0b9a5ba75' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5112"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = 'b3403349-cbc0-4d84-879e-fc0f2d90ecbd'"
                 flag="fatal">RequirementGroup 'dc4acf0c-c761-40d0-b031-4ee1f224be5c' MUST have Requirement 'b3403349-cbc0-4d84-879e-fc0f2d90ecbd' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG5113"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = '792ff522-6f3f-4a62-ab6e-a8b272bc290e'"
                 flag="fatal">RequirementGroup 'dc4acf0c-c761-40d0-b031-4ee1f224be5c' MUST have Requirement '792ff522-6f3f-4a62-ab6e-a8b272bc290e' as child number 3.</assert>
         <assert id="EHF-ESPD-CT-RG5121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '92e44d3b-af8e-4a29-91a8-24d27aa27fee'"
                 flag="fatal">RequirementGroup 'dc4acf0c-c761-40d0-b031-4ee1f224be5c' MUST have RequirementGroup '92e44d3b-af8e-4a29-91a8-24d27aa27fee' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '92e44d3b-af8e-4a29-91a8-24d27aa27fee']]">
         <assert id="EHF-ESPD-CT-RG5201" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG5202"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG5203"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG5211"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'd9996ef5-49f9-4cf8-a2f5-31c9f4efd894'"
                 flag="fatal">RequirementGroup '92e44d3b-af8e-4a29-91a8-24d27aa27fee' MUST have Requirement 'd9996ef5-49f9-4cf8-a2f5-31c9f4efd894' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '59e6f3ef-15cd-4e21-82ac-ea497ccd44e2']]">
         <assert id="EHF-ESPD-CT-RG5301"
                 test="@pi = 'GROUP_FULFILLED.ON_FALSE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_FALSE".</assert>
         <assert id="EHF-ESPD-CT-RG5302"
                 test="count(ccv:Requirement) = 2"
                 flag="fatal">Requirement group MUST contain 2 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG5303"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG5311"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '0e71abd3-198e-49c5-8128-5708617bb191'"
                 flag="fatal">RequirementGroup '59e6f3ef-15cd-4e21-82ac-ea497ccd44e2' MUST have Requirement '0e71abd3-198e-49c5-8128-5708617bb191' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5312"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = 'caa72cea-5443-49fb-84ba-ab6c64427f77'"
                 flag="fatal">RequirementGroup '59e6f3ef-15cd-4e21-82ac-ea497ccd44e2' MUST have Requirement 'caa72cea-5443-49fb-84ba-ab6c64427f77' as child number 2.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'd939f2c6-ba25-4dc4-889c-11d1853add19']]">
         <assert id="EHF-ESPD-CT-RG5401" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG5402"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG5403"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG5411"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '7f18c64e-ae09-4646-9400-f3666d50af51'"
                 flag="fatal">RequirementGroup 'd939f2c6-ba25-4dc4-889c-11d1853add19' MUST have Requirement '7f18c64e-ae09-4646-9400-f3666d50af51' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5421"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'f5663c5a-d311-4ae4-be14-1575754be5f2'"
                 flag="fatal">RequirementGroup 'd939f2c6-ba25-4dc4-889c-11d1853add19' MUST have RequirementGroup 'f5663c5a-d311-4ae4-be14-1575754be5f2' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'f5663c5a-d311-4ae4-be14-1575754be5f2']]">
         <assert id="EHF-ESPD-CT-RG5501"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG5502"
                 test="count(ccv:Requirement) = 3"
                 flag="fatal">Requirement group MUST contain 3 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG5503"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG5511"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '907fd62b-02f1-452c-81a8-785bedb0c536'"
                 flag="fatal">RequirementGroup 'f5663c5a-d311-4ae4-be14-1575754be5f2' MUST have Requirement '907fd62b-02f1-452c-81a8-785bedb0c536' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5512"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '7c267f95-a3a7-49ef-abd9-e121dcd641a9'"
                 flag="fatal">RequirementGroup 'f5663c5a-d311-4ae4-be14-1575754be5f2' MUST have Requirement '7c267f95-a3a7-49ef-abd9-e121dcd641a9' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG5513"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = '96f38793-4469-4153-aba6-c613282cdbdc'"
                 flag="fatal">RequirementGroup 'f5663c5a-d311-4ae4-be14-1575754be5f2' MUST have Requirement '96f38793-4469-4153-aba6-c613282cdbdc' as child number 3.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'e688f7d6-dcef-4726-bc61-052e63ead60f']]">
         <assert id="EHF-ESPD-CT-RG5601" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG5602"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG5603"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG5611"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '7f18c64e-ae09-4646-9400-f3666d50af51'"
                 flag="fatal">RequirementGroup 'e688f7d6-dcef-4726-bc61-052e63ead60f' MUST have Requirement '7f18c64e-ae09-4646-9400-f3666d50af51' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'd5fe5a71-7fd3-4910-b6f4-5cd2a4d23524']]">
         <assert id="EHF-ESPD-CT-RG5701" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG5702"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG5703"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG5711"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '7f18c64e-ae09-4646-9400-f3666d50af51'"
                 flag="fatal">RequirementGroup 'd5fe5a71-7fd3-4910-b6f4-5cd2a4d23524' MUST have Requirement '7f18c64e-ae09-4646-9400-f3666d50af51' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5721"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = 'b638edf6-4f00-4e24-92c4-cf96846f2c17'"
                 flag="fatal">RequirementGroup 'd5fe5a71-7fd3-4910-b6f4-5cd2a4d23524' MUST have RequirementGroup 'b638edf6-4f00-4e24-92c4-cf96846f2c17' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'b638edf6-4f00-4e24-92c4-cf96846f2c17']]">
         <assert id="EHF-ESPD-CT-RG5801"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG5802"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG5803"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG5811"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '999c7fe2-61cd-4e86-b76f-e280304dc8c9'"
                 flag="fatal">RequirementGroup 'b638edf6-4f00-4e24-92c4-cf96846f2c17' MUST have Requirement '999c7fe2-61cd-4e86-b76f-e280304dc8c9' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '3e5c2859-68a7-4312-92e4-01ae79c00cb8']]">
         <assert id="EHF-ESPD-CT-RG5901" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG5902"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG5903"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG5911"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '7f18c64e-ae09-4646-9400-f3666d50af51'"
                 flag="fatal">RequirementGroup '3e5c2859-68a7-4312-92e4-01ae79c00cb8' MUST have Requirement '7f18c64e-ae09-4646-9400-f3666d50af51' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG5921"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '6066950e-3049-4b4e-86e7-2454f1fb3780'"
                 flag="fatal">RequirementGroup '3e5c2859-68a7-4312-92e4-01ae79c00cb8' MUST have RequirementGroup '6066950e-3049-4b4e-86e7-2454f1fb3780' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '6066950e-3049-4b4e-86e7-2454f1fb3780']]">
         <assert id="EHF-ESPD-CT-RG6001"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG6002"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG6003"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG6011"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '323f19b5-3308-4873-b2d1-767963cc81e9'"
                 flag="fatal">RequirementGroup '6066950e-3049-4b4e-86e7-2454f1fb3780' MUST have Requirement '323f19b5-3308-4873-b2d1-767963cc81e9' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = 'ab335516-73a4-41f7-977b-a98c13a51060']]">
         <assert id="EHF-ESPD-CT-RG6101" test="not(@pi)" flag="fatal">Attribute 'pi' MUST NOT be provided.</assert>
         <assert id="EHF-ESPD-CT-RG6102"
                 test="count(ccv:Requirement) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement.</assert>
         <assert id="EHF-ESPD-CT-RG6103"
                 test="count(ccv:RequirementGroup) = 1"
                 flag="fatal">Requirement group MUST contain 1 requirement group.</assert>
         <assert id="EHF-ESPD-CT-RG6111"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = '0622bbd1-7378-45e1-8fb9-25429740ac22'"
                 flag="fatal">RequirementGroup 'ab335516-73a4-41f7-977b-a98c13a51060' MUST have Requirement '0622bbd1-7378-45e1-8fb9-25429740ac22' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG6121"
                 test="ccv:RequirementGroup[1] and normalize-space(ccv:RequirementGroup[1][current()]/cbc:ID/text()) = '8e7e890c-d117-44c8-aa48-cc236d26b475'"
                 flag="fatal">RequirementGroup 'ab335516-73a4-41f7-977b-a98c13a51060' MUST have RequirementGroup '8e7e890c-d117-44c8-aa48-cc236d26b475' as child number 1.</assert>
      </rule>
      <rule context="ccv:RequirementGroup[cbc:ID[text() = '8e7e890c-d117-44c8-aa48-cc236d26b475']]">
         <assert id="EHF-ESPD-CT-RG6201"
                 test="@pi = 'GROUP_FULFILLED.ON_TRUE'"
                 flag="fatal">Attribute 'pi' MUST have value "GROUP_FULFILLED.ON_TRUE".</assert>
         <assert id="EHF-ESPD-CT-RG6202"
                 test="count(ccv:Requirement) = 3"
                 flag="fatal">Requirement group MUST contain 3 requirements.</assert>
         <assert id="EHF-ESPD-CT-RG6203"
                 test="count(ccv:RequirementGroup) = 0"
                 flag="fatal">Requirement group MUST contain 0 requirement groups.</assert>
         <assert id="EHF-ESPD-CT-RG6211"
                 test="ccv:Requirement[1] and normalize-space(ccv:Requirement[1][current()]/cbc:ID/text()) = 'ee1ee1cd-3791-4855-8b8b-28d4f4c5c007'"
                 flag="fatal">RequirementGroup '8e7e890c-d117-44c8-aa48-cc236d26b475' MUST have Requirement 'ee1ee1cd-3791-4855-8b8b-28d4f4c5c007' as child number 1.</assert>
         <assert id="EHF-ESPD-CT-RG6212"
                 test="ccv:Requirement[2] and normalize-space(ccv:Requirement[2][current()]/cbc:ID/text()) = '1e55ff14-c643-4abc-91d7-2f4dfcdf2409'"
                 flag="fatal">RequirementGroup '8e7e890c-d117-44c8-aa48-cc236d26b475' MUST have Requirement '1e55ff14-c643-4abc-91d7-2f4dfcdf2409' as child number 2.</assert>
         <assert id="EHF-ESPD-CT-RG6213"
                 test="ccv:Requirement[3] and normalize-space(ccv:Requirement[3][current()]/cbc:ID/text()) = 'd8e1e818-d67b-4bb9-9aeb-4c10943a8342'"
                 flag="fatal">RequirementGroup '8e7e890c-d117-44c8-aa48-cc236d26b475' MUST have Requirement 'd8e1e818-d67b-4bb9-9aeb-4c10943a8342' as child number 3.</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '974c8196-9d1c-419c-9ca9-45bb9f5fd59a']]">
         <assert id="EHF-ESPD-CT-R0101"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R0102"
                 test="normalize-space(cbc:Description) = 'Your answer?'"
                 flag="fatal">Description MUST be "Your answer?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'ecf40999-7b64-4e10-b960-7f8ff8674cf6']]">
         <assert id="EHF-ESPD-CT-R0201"
                 test="@responseDataType = 'DATE'"
                 flag="fatal">Response data type MUST be "DATE".</assert>
         <assert id="EHF-ESPD-CT-R0202"
                 test="normalize-space(cbc:Description) = 'Date of conviction'"
                 flag="fatal">Description MUST be "Date of conviction".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '7d35fb7c-da5b-4830-b598-4f347a04dceb']]">
         <assert id="EHF-ESPD-CT-R0301"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R0302"
                 test="normalize-space(cbc:Description) = 'Reason'"
                 flag="fatal">Description MUST be "Reason".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'c5012430-14da-454c-9d01-34cedc6a7ded']]">
         <assert id="EHF-ESPD-CT-R0401"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R0402"
                 test="normalize-space(cbc:Description) = 'Who has been convicted'"
                 flag="fatal">Description MUST be "Who has been convicted".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '9ca9096f-edd2-4f19-b6b1-b55c83a2d5c8']]">
         <assert id="EHF-ESPD-CT-R0501"
                 test="@responseDataType = 'PERIOD'"
                 flag="fatal">Response data type MUST be "PERIOD".</assert>
         <assert id="EHF-ESPD-CT-R0502"
                 test="normalize-space(cbc:Description) = 'Length of the period of exclusion'"
                 flag="fatal">Description MUST be "Length of the period of exclusion".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '20c5361b-7599-4ee6-b030-7f8323174d1e']]">
         <assert id="EHF-ESPD-CT-R0601"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R0602"
                 test="normalize-space(cbc:Description) = 'Have you taken measures to demonstrate your reliability (&#34;Self-Cleaning&#34;)?'"
                 flag="fatal">Description MUST be "Have you taken measures to demonstrate your reliability ("Self-Cleaning")?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '7b07904f-e080-401a-a3a1-9a3efeeda54b']]">
         <assert id="EHF-ESPD-CT-R0701"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R0702"
                 test="normalize-space(cbc:Description) = 'Please describe them'"
                 flag="fatal">Description MUST be "Please describe them".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'c1347b74-1872-4060-a6db-f4044edcd7c4']]">
         <assert id="EHF-ESPD-CT-R0801"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R0802"
                 test="normalize-space(cbc:Description) = 'Is this information available electronically?'"
                 flag="fatal">Description MUST be "Is this information available electronically?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'f4313bb6-21b6-499e-bdff-debe10e11d2c']]">
         <assert id="EHF-ESPD-CT-R0901"
                 test="@responseDataType = 'EVIDENCE_URL'"
                 flag="fatal">Response data type MUST be "EVIDENCE_URL".</assert>
         <assert id="EHF-ESPD-CT-R0902"
                 test="normalize-space(cbc:Description) = 'URL'"
                 flag="fatal">Description MUST be "URL".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '1f1cd18e-3e01-4ca2-af4c-e2981924ba8d']]">
         <assert id="EHF-ESPD-CT-R1001"
                 test="@responseDataType = 'CODE'"
                 flag="fatal">Response data type MUST be "CODE".</assert>
         <assert id="EHF-ESPD-CT-R1002"
                 test="normalize-space(cbc:Description) = 'Code'"
                 flag="fatal">Description MUST be "Code".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'c3ccfa31-0c5e-4e3a-a3fd-db9fb83d78d4']]">
         <assert id="EHF-ESPD-CT-R1101"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R1102"
                 test="normalize-space(cbc:Description) = 'Issuer'"
                 flag="fatal">Description MUST be "Issuer".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '6c87d3d4-e8eb-4253-b385-6373020ab886']]">
         <assert id="EHF-ESPD-CT-R1201"
                 test="@responseDataType = 'CODE_COUNTRY'"
                 flag="fatal">Response data type MUST be "CODE_COUNTRY".</assert>
         <assert id="EHF-ESPD-CT-R1202"
                 test="normalize-space(cbc:Description) = 'Country or member state concerned'"
                 flag="fatal">Description MUST be "Country or member state concerned".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '9052cc59-cfe5-41c6-a314-02a7f378ffe8']]">
         <assert id="EHF-ESPD-CT-R1301"
                 test="@responseDataType = 'AMOUNT'"
                 flag="fatal">Response data type MUST be "AMOUNT".</assert>
         <assert id="EHF-ESPD-CT-R1302"
                 test="normalize-space(cbc:Description) = 'Amount concerned'"
                 flag="fatal">Description MUST be "Amount concerned".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '9b4497e6-a166-46f9-8581-7fc39ff975c4']]">
         <assert id="EHF-ESPD-CT-R1401"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R1402"
                 test="normalize-space(cbc:Description) = 'Has this breach of obligations been established by means other than a judicial or administrative decision?'"
                 flag="fatal">Description MUST be "Has this breach of obligations been established by means other than a judicial or administrative decision?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '201f11c3-1fa2-4464-acc0-f021266fd881']]">
         <assert id="EHF-ESPD-CT-R1501"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R1502"
                 test="normalize-space(cbc:Description) = 'Please describe which means were used'"
                 flag="fatal">Description MUST be "Please describe which means were used".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '08b0c984-c5e6-4143-8493-868c39745637']]">
         <assert id="EHF-ESPD-CT-R1601"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R1602"
                 test="normalize-space(cbc:Description) = 'If this breach of obligations was established through a judicial or administrative decision, was this decision final and binding?'"
                 flag="fatal">Description MUST be "If this breach of obligations was established through a judicial or administrative decision, was this decision final and binding?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '70f8697b-8953-411a-a489-4ff62e5250d2']]">
         <assert id="EHF-ESPD-CT-R1701"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R1702"
                 test="normalize-space(cbc:Description) = 'Has the economic operator fulfilled its obligations by paying or entering into a binding arrangement with a view to paying the taxes or social security contributions due, including, where applicable, any interest accrued or fines?'"
                 flag="fatal">Description MUST be "Has the economic operator fulfilled its obligations by paying or entering into a binding arrangement with a view to paying the taxes or social security contributions due, including, where applicable, any interest accrued or fines?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '55905dd0-38f0-4f93-8c74-5ae05a21afc5']]">
         <assert id="EHF-ESPD-CT-R1801"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R1802"
                 test="normalize-space(cbc:Description) = 'Please describe them'"
                 flag="fatal">Description MUST be "Please describe them".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'e098da8e-4717-4500-965f-f882d5b4e1ad']]">
         <assert id="EHF-ESPD-CT-R1901"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R1902"
                 test="normalize-space(cbc:Description) = 'Please describe them'"
                 flag="fatal">Description MUST be "Please describe them".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '4e3f468a-86c4-4c99-bd15-c8b221229348']]">
         <assert id="EHF-ESPD-CT-R2001"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R2002"
                 test="normalize-space(cbc:Description) = 'Indicate reasons for being nevertheless to perform the contract'"
                 flag="fatal">Description MUST be "Indicate reasons for being nevertheless to perform the contract".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '15335c12-ad77-4728-b5ad-3c06a60d65a4']]">
         <assert id="EHF-ESPD-CT-R2101"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R2102"
                 test="normalize-space(cbc:Description) = 'Your answer?'"
                 flag="fatal">Description MUST be "Your answer?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '9dae5670-cb75-4c97-901b-96ddac5a633a']]">
         <assert id="EHF-ESPD-CT-R2201"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R2202"
                 test="normalize-space(cbc:Description) = 'Is this information available electronically?'"
                 flag="fatal">Description MUST be "Is this information available electronically?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '03bb1954-13ae-47d8-8ef8-b7fe0f22d700']]">
         <assert id="EHF-ESPD-CT-R2301"
                 test="@responseDataType = 'EVIDENCE_URL'"
                 flag="fatal">Response data type MUST be "EVIDENCE_URL".</assert>
         <assert id="EHF-ESPD-CT-R2302"
                 test="normalize-space(cbc:Description) = 'URL'"
                 flag="fatal">Description MUST be "URL".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'e2d863a0-60cb-4e58-8c14-4c1595af48b7']]">
         <assert id="EHF-ESPD-CT-R2401"
                 test="@responseDataType = 'CODE'"
                 flag="fatal">Response data type MUST be "CODE".</assert>
         <assert id="EHF-ESPD-CT-R2402"
                 test="normalize-space(cbc:Description) = 'Code'"
                 flag="fatal">Description MUST be "Code".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '5cbf74d9-a1e2-4233-921d-8b298842ee7d']]">
         <assert id="EHF-ESPD-CT-R2501"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R2502"
                 test="normalize-space(cbc:Description) = 'Issuer'"
                 flag="fatal">Description MUST be "Issuer".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '51391308-0bf6-423c-95e2-d5a54aa31fb8']]">
         <assert id="EHF-ESPD-CT-R2601"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R2602"
                 test="normalize-space(cbc:Description) = 'Please describe them'"
                 flag="fatal">Description MUST be "Please describe them".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '42ec8116-31a7-4118-8612-5b04f5c8bde7']]">
         <assert id="EHF-ESPD-CT-R2701"
                 test="@responseDataType = 'DATE'"
                 flag="fatal">Response data type MUST be "DATE".</assert>
         <assert id="EHF-ESPD-CT-R2702"
                 test="normalize-space(cbc:Description) = 'Start Date'"
                 flag="fatal">Description MUST be "Start Date".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '3641b897-f9f0-4d90-909a-b6d4c4b1d645']]">
         <assert id="EHF-ESPD-CT-R2801"
                 test="@responseDataType = 'DATE'"
                 flag="fatal">Response data type MUST be "DATE".</assert>
         <assert id="EHF-ESPD-CT-R2802"
                 test="normalize-space(cbc:Description) = 'End Date'"
                 flag="fatal">Description MUST be "End Date".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '42db0eaa-d2dd-48cb-83ac-38d73cab9b50']]">
         <assert id="EHF-ESPD-CT-R2901"
                 test="@responseDataType = 'AMOUNT'"
                 flag="fatal">Response data type MUST be "AMOUNT".</assert>
         <assert id="EHF-ESPD-CT-R2902"
                 test="normalize-space(cbc:Description) = 'Amount'"
                 flag="fatal">Description MUST be "Amount".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'b98ffd05-6572-4b07-a521-693a1754ed46']]">
         <assert id="EHF-ESPD-CT-R3001"
                 test="@responseDataType = 'QUANTITY_INTEGER'"
                 flag="fatal">Response data type MUST be "QUANTITY_INTEGER".</assert>
         <assert id="EHF-ESPD-CT-R3002"
                 test="normalize-space(cbc:Description) = 'Number of years'"
                 flag="fatal">Description MUST be "Number of years".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '217637ba-6bdb-4c73-a38f-27fe0e71d9be']]">
         <assert id="EHF-ESPD-CT-R3101"
                 test="@responseDataType = 'AMOUNT'"
                 flag="fatal">Response data type MUST be "AMOUNT".</assert>
         <assert id="EHF-ESPD-CT-R3102"
                 test="normalize-space(cbc:Description) = 'Average turnover'"
                 flag="fatal">Description MUST be "Average turnover".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'a18b2c98-8552-45ca-9751-d4c94c05847a']]">
         <assert id="EHF-ESPD-CT-R3201"
                 test="@responseDataType = 'QUANTITY_YEAR'"
                 flag="fatal">Response data type MUST be "QUANTITY_YEAR".</assert>
         <assert id="EHF-ESPD-CT-R3202"
                 test="normalize-space(cbc:Description) = 'Please specify'"
                 flag="fatal">Description MUST be "Please specify".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'ab05ff3b-f3e1-4441-9b43-ee9912e29e92']]">
         <assert id="EHF-ESPD-CT-R3301"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R3302"
                 test="normalize-space(cbc:Description) = 'Description'"
                 flag="fatal">Description MUST be "Description".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '5461b973-7067-457e-93cc-8338da2c3eef']]">
         <assert id="EHF-ESPD-CT-R3401"
                 test="@responseDataType = 'QUANTITY'"
                 flag="fatal">Response data type MUST be "QUANTITY".</assert>
         <assert id="EHF-ESPD-CT-R3402"
                 test="normalize-space(cbc:Description) = 'Ratio'"
                 flag="fatal">Description MUST be "Ratio".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'a92536ab-6783-40bb-a037-5d31f421fd85']]">
         <assert id="EHF-ESPD-CT-R3501"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R3502"
                 test="normalize-space(cbc:Description) = 'Recipients'"
                 flag="fatal">Description MUST be "Recipients".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '23a27c0e-c4f7-42cd-b0fd-a7cedfbf77a7']]">
         <assert id="EHF-ESPD-CT-R3601"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R3602"
                 test="normalize-space(cbc:Description) = 'Do you allow checks?'"
                 flag="fatal">Description MUST be "Do you allow checks?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '5aacceb3-280e-42f1-b2da-3d8ac7877fe9']]">
         <assert id="EHF-ESPD-CT-R3701"
                 test="@responseDataType = 'QUANTITY_YEAR'"
                 flag="fatal">Response data type MUST be "QUANTITY_YEAR".</assert>
         <assert id="EHF-ESPD-CT-R3702"
                 test="normalize-space(cbc:Description) = 'Year'"
                 flag="fatal">Description MUST be "Year".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '42037f41-53af-44df-b6b8-2395cee98087']]">
         <assert id="EHF-ESPD-CT-R3801"
                 test="@responseDataType = 'QUANTITY_INTEGER'"
                 flag="fatal">Response data type MUST be "QUANTITY_INTEGER".</assert>
         <assert id="EHF-ESPD-CT-R3802"
                 test="normalize-space(cbc:Description) = 'Number'"
                 flag="fatal">Description MUST be "Number".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '15778db8-0d84-42ba-931b-774c1b3d3f9f']]">
         <assert id="EHF-ESPD-CT-R3901"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R3902"
                 test="normalize-space(cbc:Description) = 'Please specify'"
                 flag="fatal">Description MUST be "Please specify".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'b9dec4cb-2f6f-47d7-a023-e9099b19b338']]">
         <assert id="EHF-ESPD-CT-R4001"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R4002"
                 test="normalize-space(cbc:Description) = 'If not, please explain why and state which other means of proof can be provided:'"
                 flag="fatal">Description MUST be "If not, please explain why and state which other means of proof can be provided:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '8c5d1e13-54f7-4895-a65c-b8e09253130c']]">
         <assert id="EHF-ESPD-CT-R4101"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R4102"
                 test="normalize-space(cbc:Description) = 'If not, please explain why and specify which other means of proof concerning the quality assurance scheme can be provided:'"
                 flag="fatal">Description MUST be "If not, please explain why and specify which other means of proof concerning the quality assurance scheme can be provided:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'b0aace10-fd73-46d1-ae78-289ee5cd42ca']]">
         <assert id="EHF-ESPD-CT-R4201"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R4202"
                 test="normalize-space(cbc:Description) = 'If not, please explain why and specify which other means of proof concerning the environmental management systems or standards can be provided:'"
                 flag="fatal">Description MUST be "If not, please explain why and specify which other means of proof concerning the environmental management systems or standards can be provided:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '7f18c64e-ae09-4646-9400-f3666d50af51']]">
         <assert id="EHF-ESPD-CT-R4301"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R4302"
                 test="normalize-space(cbc:Description) = 'Your answer'"
                 flag="fatal">Description MUST be "Your answer".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '4e552658-d532-4770-943b-b90efcc9788d']]">
         <assert id="EHF-ESPD-CT-R4401"
                 test="@responseDataType = 'PERCENTAGE'"
                 flag="fatal">Response data type MUST be "PERCENTAGE".</assert>
         <assert id="EHF-ESPD-CT-R4402"
                 test="normalize-space(cbc:Description) = 'What is the corresponding percentage of disabled or disadvantaged workers?'"
                 flag="fatal">Description MUST be "What is the corresponding percentage of disabled or disadvantaged workers?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'e01d0929-c7a9-455a-aaf9-e1f7cd966336']]">
         <assert id="EHF-ESPD-CT-R4501"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R4502"
                 test="normalize-space(cbc:Description) = 'If required, please provide details on whether the employees concerned belong to a specific category of disabled or disadvantaged workers?'"
                 flag="fatal">Description MUST be "If required, please provide details on whether the employees concerned belong to a specific category of disabled or disadvantaged workers?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '30064ad3-fc11-4579-8528-fdd0b9a5ba75']]">
         <assert id="EHF-ESPD-CT-R4601"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R4602"
                 test="normalize-space(cbc:Description) = 'a) Please provide the relevant registration or certification number, if applicable:'"
                 flag="fatal">Description MUST be "a) Please provide the relevant registration or certification number, if applicable:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'b3403349-cbc0-4d84-879e-fc0f2d90ecbd']]">
         <assert id="EHF-ESPD-CT-R4701"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R4702"
                 test="normalize-space(cbc:Description) = 'b) If the certificate of registration or certification is available electronically, please state:'"
                 flag="fatal">Description MUST be "b) If the certificate of registration or certification is available electronically, please state:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '792ff522-6f3f-4a62-ab6e-a8b272bc290e']]">
         <assert id="EHF-ESPD-CT-R4801"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R4802"
                 test="normalize-space(cbc:Description) = 'c) Please state the references on which the registration or certification is based, and, where applicable, the classification obtained in the official list:'"
                 flag="fatal">Description MUST be "c) Please state the references on which the registration or certification is based, and, where applicable, the classification obtained in the official list:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'd9996ef5-49f9-4cf8-a2f5-31c9f4efd894']]">
         <assert id="EHF-ESPD-CT-R4901"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R4902"
                 test="normalize-space(cbc:Description) = 'd) Does the registration or certification cover all of the required selection criteria?'"
                 flag="fatal">Description MUST be "d) Does the registration or certification cover all of the required selection criteria?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '0e71abd3-198e-49c5-8128-5708617bb191']]">
         <assert id="EHF-ESPD-CT-R5001"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R5002"
                 test="normalize-space(cbc:Description) = 'e) Will the economic operator be able to provide a certificate with regard to the payment of social security contributions and taxes or provide information enabling the contracting authority or contracting entity to obtaining it directly by accessing a national database in any Member State that is available free of charge?'"
                 flag="fatal">Description MUST be "e) Will the economic operator be able to provide a certificate with regard to the payment of social security contributions and taxes or provide information enabling the contracting authority or contracting entity to obtaining it directly by accessing a national database in any Member State that is available free of charge?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'caa72cea-5443-49fb-84ba-ab6c64427f77']]">
         <assert id="EHF-ESPD-CT-R5101"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R5102"
                 test="normalize-space(cbc:Description) = 'If the relevant documentation is available electronically, please indicate:'"
                 flag="fatal">Description MUST be "If the relevant documentation is available electronically, please indicate:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '907fd62b-02f1-452c-81a8-785bedb0c536']]">
         <assert id="EHF-ESPD-CT-R5201"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R5202"
                 test="normalize-space(cbc:Description) = 'a) Please indicate the role of the economic operator in the group (leader, responsible for specific tasks...):'"
                 flag="fatal">Description MUST be "a) Please indicate the role of the economic operator in the group (leader, responsible for specific tasks...):".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '7c267f95-a3a7-49ef-abd9-e121dcd641a9']]">
         <assert id="EHF-ESPD-CT-R5301"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R5302"
                 test="normalize-space(cbc:Description) = 'b) Please identify the other economic operators participating in the procurement procedure together:'"
                 flag="fatal">Description MUST be "b) Please identify the other economic operators participating in the procurement procedure together:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '96f38793-4469-4153-aba6-c613282cdbdc']]">
         <assert id="EHF-ESPD-CT-R5401"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R5402"
                 test="normalize-space(cbc:Description) = 'c) Where applicable, name of the participating group:'"
                 flag="fatal">Description MUST be "c) Where applicable, name of the participating group:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '999c7fe2-61cd-4e86-b76f-e280304dc8c9']]">
         <assert id="EHF-ESPD-CT-R5501"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R5502"
                 test="normalize-space(cbc:Description) = 'If yes and in so far as known, please list the proposed subcontractors:'"
                 flag="fatal">Description MUST be "If yes and in so far as known, please list the proposed subcontractors:".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '323f19b5-3308-4873-b2d1-767963cc81e9']]">
         <assert id="EHF-ESPD-CT-R5601"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R5602"
                 test="normalize-space(cbc:Description) = 'Please describe them'"
                 flag="fatal">Description MUST be "Please describe them".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '0622bbd1-7378-45e1-8fb9-25429740ac22']]">
         <assert id="EHF-ESPD-CT-R5701"
                 test="@responseDataType = 'INDICATOR'"
                 flag="fatal">Response data type MUST be "INDICATOR".</assert>
         <assert id="EHF-ESPD-CT-R5702"
                 test="normalize-space(cbc:Description) = 'Is this information available electronically?'"
                 flag="fatal">Description MUST be "Is this information available electronically?".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'ee1ee1cd-3791-4855-8b8b-28d4f4c5c007']]">
         <assert id="EHF-ESPD-CT-R5801"
                 test="@responseDataType = 'EVIDENCE_URL'"
                 flag="fatal">Response data type MUST be "EVIDENCE_URL".</assert>
         <assert id="EHF-ESPD-CT-R5802"
                 test="normalize-space(cbc:Description) = 'URL'"
                 flag="fatal">Description MUST be "URL".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = '1e55ff14-c643-4abc-91d7-2f4dfcdf2409']]">
         <assert id="EHF-ESPD-CT-R5901"
                 test="@responseDataType = 'CODE'"
                 flag="fatal">Response data type MUST be "CODE".</assert>
         <assert id="EHF-ESPD-CT-R5902"
                 test="normalize-space(cbc:Description) = 'Code'"
                 flag="fatal">Description MUST be "Code".</assert>
      </rule>
      <rule context="ccv:Requirement[cbc:ID[text() = 'd8e1e818-d67b-4bb9-9aeb-4c10943a8342']]">
         <assert id="EHF-ESPD-CT-R6001"
                 test="@responseDataType = 'DESCRIPTION'"
                 flag="fatal">Response data type MUST be "DESCRIPTION".</assert>
         <assert id="EHF-ESPD-CT-R6002"
                 test="normalize-space(cbc:Description) = 'Issuer'"
                 flag="fatal">Description MUST be "Issuer".</assert>
      </rule>
      <rule context="ccv:Criterion">
         <assert id="EHF-ESPD-CT-C0001" test="false()" flag="fatal">Invalid criterion.</assert>
      </rule>
      <rule context="ccv:RequirementGroup">
         <assert id="EHF-ESPD-CT-RG0001" test="false()" flag="fatal">Invalid requirement group.</assert>
      </rule>
      <rule context="ccv:Requirement">
         <assert id="EHF-ESPD-CT-R0001" test="false()" flag="fatal">Invalid requirement.</assert>
      </rule>
   </pattern>

</schema>
